package com.weiyoubot.client.basekt

import com.hannesdorfmann.mosby3.mvp.MvpBasePresenter
import com.hannesdorfmann.mosby3.mvp.lce.MvpLceView
import com.weiyoubot.client.model.loader.OnDataLoadListener

abstract class BaseLcePresenter<M, V : MvpLceView<M>> : MvpBasePresenter<V>() {

    /**
     * 由view调用的加载数据的方法
     *
     * @param pullToRefresh false代表首次加载
     * @param params        由view传递过来的参数
     */
    fun loadData(pullToRefresh: Boolean, params: MutableMap<String, Any>) {
        ifViewAttached { view ->
            view.showLoading(pullToRefresh)
            loadData(pullToRefresh, params, object : OnDataLoadListener {
                @Suppress("UNCHECKED_CAST")
                override fun onDataLoaded(data: Any) {
                    ifViewAttached {
                        it.setData(data as M)
                        it.showContent()
                    }
                }

                override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                    ifViewAttached {
                        it.showError(Throwable(errorMessage), pullToRefresh)
                    }
                }
            })
        }
    }

    /**
     * 子类重载的方法
     *
     * @param pullToRefresh false代表首次加载
     * @param params        由view传递过来的参数
     * @param listener      加载完成后的监听
     */
    protected abstract fun loadData(pullToRefresh: Boolean, params: MutableMap<String, Any>, listener: OnDataLoadListener)
}
