package com.weiyoubot.client.feature.account.adapter

import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import com.weiyoubot.client.R
import com.weiyoubot.client.common.utils.DateUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.feature.account.CouponConstant
import com.weiyoubot.client.model.bean.userdata.CouponInfo
import kotlinx.android.synthetic.main.coupon_item_view.view.*
import kotlinx.android.synthetic.main.coupon_select_empty_view.view.*
import kotlinx.android.synthetic.main.coupon_select_item_view.view.*
import java.text.DecimalFormat

class SelectCouponAdapter(var data: MutableList<CouponInfo>, var selectedId: String, var listener: OnSelectedCouponChanged) : RecyclerView.Adapter<SelectCouponAdapter.SelectCouponViewHolder>() {
    companion object {
        const val VIEW_TYPE_EMPTY = 0
        const val VIEW_TYPE_ITEM = 1
    }

    interface OnSelectedCouponChanged {
        fun selectedCouponChanged(cid: String, order_discount: Float)
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): SelectCouponViewHolder {
        return if (viewType == VIEW_TYPE_EMPTY) {
            SelectCouponViewHolderNone(
                    LayoutInflater.from(parent.context)
                            .inflate(R.layout.coupon_select_empty_view, parent, false)
            )
        } else {
            SelectCouponViewHolderItem(
                    LayoutInflater.from(parent.context)
                            .inflate(R.layout.coupon_select_item_view, parent, false)
            )
        }
    }

    override fun getItemCount() = data.size + 1

    override fun onBindViewHolder(holder: SelectCouponViewHolder, position: Int) {
        holder.bind(if (position > 0) data[position - 1] else CouponInfo())
    }

    override fun getItemViewType(position: Int): Int {
        return if (position == 0) VIEW_TYPE_EMPTY else VIEW_TYPE_ITEM
    }

    fun swapData(data: MutableList<CouponInfo>) {
        this.data = data
        notifyDataSetChanged()
    }

    abstract class SelectCouponViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
        abstract fun bind(item: CouponInfo)
    }

    inner class SelectCouponViewHolderNone(itemView: View) : SelectCouponViewHolder(itemView) {
        override fun bind(item: CouponInfo) = with(itemView) {
            selector_empty.setImageResource(if (selectedId.isEmpty()) R.drawable.checkbox_round_checked else R.drawable.checkbox_round_unchecked)
            setOnClickListener {
                if (selectedId.isNotEmpty()) {
                    selectedId = ""
                    notifyDataSetChanged()
                    listener.selectedCouponChanged("", 0f)
                }
            }
        }
    }

    inner class SelectCouponViewHolderItem(itemView: View) : SelectCouponViewHolder(itemView) {
        override fun bind(item: CouponInfo) = with(itemView) {
            coupon_valid_time.text = Utils.getString(R.string.coupon_type_validate_until, DateUtils.formatDate("yyyy-MM-dd", item.end * 1000))
            when (item.type) {
                CouponConstant.COUPON_TYPE_DISCOUNT -> {
                    coupon_type.setText(R.string.coupon_type_discount)
                    coupon_discount_prefix.visibility = View.VISIBLE
                    coupon_discount_suffix.visibility = View.GONE
                    coupon_discount.text = item.discount.toInt().toString()
                }
                CouponConstant.COUPON_TYPE_PERCENT -> {
                    coupon_type.setText(R.string.coupon_type_percent)
                    coupon_discount_prefix.visibility = View.GONE
                    coupon_discount_suffix.visibility = View.VISIBLE
                    coupon_discount.text = DecimalFormat("#.#").format(item.discount * 10)
                }
                CouponConstant.COUPON_TYPE_IMMEDIATE -> {
                    coupon_type.setText(R.string.coupon_type_immediate)
                    coupon_discount_prefix.visibility = View.VISIBLE
                    coupon_discount_suffix.visibility = View.GONE
                    coupon_discount.text = item.discount.toInt().toString()
                }
            }
            coupon_desc.text = item.desc

            selector.setImageResource(if (item.id == selectedId) R.drawable.checkbox_round_checked else R.drawable.checkbox_round_unchecked)
            if (item.order_discount == 0f) {
                with(coupon_view) {
                    for (it in mutableListOf<TextView>(coupon_type, coupon_valid_time, coupon_discount_prefix, coupon_discount, coupon_discount_suffix)) {
                        it.setTextColor(Utils.getColor(R.color.common_color_9a))
                    }
                    sub_line.setBackgroundColor(Utils.getColor(R.color.common_color_9a))
                }
                selector.alpha = 0.54f
                setOnClickListener(null)
            } else {
                with(coupon_view) {
                    for (it in mutableListOf<TextView>(coupon_type, coupon_valid_time, coupon_discount_prefix, coupon_discount, coupon_discount_suffix)) {
                        it.setTextColor(Utils.getColor(R.color.common_blue_color))
                    }
                    sub_line.setBackgroundColor(Utils.getColor(R.color.common_blue_color))
                }
                selector.alpha = 1f
                setOnClickListener {
                    selectedId = item.id
                    notifyDataSetChanged()
                    listener.selectedCouponChanged(item.id, item.order_discount)
                }
            }
        }
    }
}