package com.weiyoubot.client.feature.account.presenter

import android.content.Context
import com.hannesdorfmann.mosby3.mvp.MvpBasePresenter
import com.weiyoubot.client.R
import com.weiyoubot.client.common.helper.MQHelper
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.feature.account.view.AccountMvpView
import com.weiyoubot.client.feature.main.UserDataEvent
import com.weiyoubot.client.feature.main.UserDataHelper
import com.weiyoubot.client.model.api.ApiClient
import com.weiyoubot.client.model.loader.OnDataLoadListener
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe
import org.json.JSONException

/**
 * Created by root on 12/22/16.
 */
class AccountPresenter : MvpBasePresenter<AccountMvpView>() {

    fun loadUserData() {
        UserDataHelper.loadUserData()
    }

    fun pauseResumeAccount() {
        val isAccountPaused = UserDataHelper.isAccountPaused()
        val listener = object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached {
                    loadUserData()
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached {
                    UIUtils.showFailedToast(if (isAccountPaused) R.string.resume_failed else R.string.pause_failed, errorMessage)
                }
            }
        }
        try {
            if (isAccountPaused) {
                ApiClient.resumeAccount(listener)
            } else {
                ApiClient.pauseAccount(listener)
            }
        } catch (e: JSONException) {
            e.printStackTrace()
        }

    }

    fun deleteAccount(listener: OnDataLoadListener) {
        try {
            ApiClient.deleteAccount(listener)
        } catch (e: JSONException) {
            e.printStackTrace()
        }

    }

    fun startCustomerService(context: Context) {
        MQHelper.startConversation(context, "personal_account_center")
    }

    override fun attachView(view: AccountMvpView) {
        super.attachView(view)
        EventBus.getDefault().register(this)
    }

    override fun detachView() {
        super.detachView()
        EventBus.getDefault().unregister(this)
    }

    @Suppress("UNUSED_PARAMETER")
    @Subscribe
    fun onEvent(event: UserDataEvent) {
        ifViewAttached {
            it.updateView()
        }
    }
}
