package com.weiyoubot.client.feature.account.presenter

import android.app.Activity
import android.content.Context
import com.hannesdorfmann.mosby3.mvp.MvpBasePresenter
import com.weiyoubot.client.R
import com.weiyoubot.client.common.helper.MQHelper
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.feature.account.PaymentHelper
import com.weiyoubot.client.feature.account.PaymentPayEvent
import com.weiyoubot.client.feature.account.PaymentPriceEvent
import com.weiyoubot.client.feature.account.PaymentSubmitOrderEvent
import com.weiyoubot.client.feature.account.view.PaymentMvpView
import com.weiyoubot.client.model.bean.account.result.Order
import com.weiyoubot.client.model.bean.account.result.Price
import com.weiyoubot.client.model.loader.OnDataLoadListener
import kotlinx.android.synthetic.main.payment_perm_view.view.*
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe

/**
 * Created by root on 12/14/16.
 */
class PaymentPresenter : MvpBasePresenter<PaymentMvpView>() {

    fun platformPay(activity: Activity, payPlatform: Int, orderId: String, renew: Boolean, permId: Int, duration: Int, gids: List<String>) {
        PaymentHelper.platformPay(activity, payPlatform, orderId, renew, permId, duration, gids)
    }

    fun startCustomerService(context: Context) {
        MQHelper.startConversation(context, "order_create")
    }

    override fun attachView(view: PaymentMvpView) {
        super.attachView(view)
        EventBus.getDefault().register(this)
    }

    override fun detachView() {
        super.detachView()
        EventBus.getDefault().unregister(this)
    }

    @Subscribe
    fun onEvent(event: PaymentPriceEvent) {
        ifViewAttached {
            event.view.price.text = "..."
            PaymentHelper.calculatePrice(event.goodsDetails, object : OnDataLoadListener {
                override fun onDataLoaded(data: Any) {
                    ifViewAttached {
                        val price = data as Price
                        event.view.updatePriceDataSuccess(price.data)
                    }
                }

                override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                    ifViewAttached {
                        event.view.updatePriceDataFailed()
                    }
                }
            })
        }
    }

    @Subscribe
    fun onEvent(event: PaymentSubmitOrderEvent) {
        ifViewAttached {
            PaymentHelper.submitOrder(event.goodsDetails, event.totalPrice, event.cid, object : OnDataLoadListener {
                override fun onDataLoaded(data: Any) {
                    ifViewAttached {
                        val order = data as Order
                        it.submitOrderSuccess(event.goodsDetails, event.groupIds, event.groupNames, order.data)
                    }
                }

                override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                    ifViewAttached {
                        UIUtils.showFailedToast(R.string.payment_submit_order_failed_tips, errorMessage)
                    }
                }
            })
        }
    }

    @Subscribe
    fun onEvent(event: PaymentPayEvent) {
        ifViewAttached {
            it.platformPay(event.payPlatform, event.orderId, event.permId, event.duration, event.gids)
        }
    }
}
