package com.weiyoubot.client.feature.account.view

import android.os.Bundle
import android.support.v4.app.Fragment
import android.support.v7.app.AlertDialog
import android.view.View
import android.view.View.GONE
import android.view.View.VISIBLE
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.activity.BaseMvpActivity
import com.weiyoubot.client.common.utils.DateUtils
import com.weiyoubot.client.common.utils.PreferenceUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.utils.makeHtmlString
import com.weiyoubot.client.feature.account.PaymentConstant
import com.weiyoubot.client.feature.account.presenter.AccountPresenter
import com.weiyoubot.client.feature.main.UserDataHelper
import com.weiyoubot.client.model.loader.OnDataLoadListener
import kotlinx.android.synthetic.main.account_activity.*


/**
 * Created by root on 11/24/16.
 */
class AccountActivity : BaseMvpActivity<AccountMvpView, AccountPresenter>(), AccountMvpView {

    private lateinit var currentFragment: Fragment

    interface InitFragment {
        fun initView()
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.account_activity)
        customer_service.setOnClickListener {
            presenter.startCustomerService(this)
        }
        back.setOnClickListener {
            onBackPressed()
        }
        loadUserData()
        loadAccountPage()
        if (intent.getBooleanExtra(PaymentConstant.INTENT_KEY_FROM_START_PAY, false)) {
            AlertDialog.Builder(this).setTitle(R.string.dialog_title)
                    .setMessage(makeHtmlString(Utils.getString(R.string.has_balance_dialog_message)))
                    .setPositiveButton(R.string.ok) { _, _ ->
                        loadBalancePage()
                    }
                    .show()
        }
        close_tips.setOnClickListener {
            tips_bar.visibility = View.GONE
            if (currentFragment is AccountPermPaidFragment) {
                PreferenceUtils.setLastTimeCloseExpiringTips(System.currentTimeMillis())
            } else if (currentFragment is AccountPermFreeFragment) {
                PreferenceUtils.setLastTimeCloseExpiredTips(System.currentTimeMillis())
            }
        }
    }

    override fun createPresenter(): AccountPresenter {
        return AccountPresenter()
    }

    private fun loadAccountPage() {
        customer_service.visibility = VISIBLE
        currentFragment = AccountFragment()
        replaceFragment(Utils.getString(R.string.account), currentFragment)
        tips_bar.visibility = View.GONE
    }

    fun loadPaidGroupsPage() {
        customer_service.visibility = GONE
        currentFragment = AccountPermPaidFragment()
        replaceFragment(Utils.getString(R.string.account_perm_paid), currentFragment)
        if (UserDataHelper.hasExpiringGroup()) {
            val lastTimeCloseTips = PreferenceUtils.getLastTimeCloseExpiringTips()
            if (lastTimeCloseTips == 0L || System.currentTimeMillis() > DateUtils.getDayEndOfTime(lastTimeCloseTips)) {
                tips.setText(R.string.renew_tips_expiring)
                tips_bar.visibility = View.VISIBLE
            }
        }
    }

    fun loadFreeGroupsPage() {
        customer_service.visibility = GONE
        currentFragment = AccountPermFreeFragment()
        replaceFragment(Utils.getString(R.string.account_perm_free), currentFragment)
        if (UserDataHelper.hasExpiredGroup()) {
            val lastTimeCloseTips = PreferenceUtils.getLastTimeCloseExpiredTips()
            if (lastTimeCloseTips == 0L || System.currentTimeMillis() > DateUtils.getDayEndOfTime(lastTimeCloseTips)) {
                tips.setText(R.string.renew_tips_expired)
                tips_bar.visibility = View.VISIBLE
            }
        }
    }

    fun loadBalancePage() {
        customer_service.visibility = GONE
        currentFragment = AccountBalanceFragment()
        replaceFragment(Utils.getString(R.string.account_balance), currentFragment)
    }

    fun loadCouponPage() {
        customer_service.visibility = GONE
        currentFragment = AccountCouponFragment()
        replaceFragment(Utils.getString(R.string.coupon), currentFragment)
    }

    private fun loadUserData() {
        presenter.loadUserData()
    }

    private fun replaceFragment(title: String, fragment: Fragment) {
        title_text.text = title
        currentFragment = fragment
        supportFragmentManager.beginTransaction().replace(R.id.content_fragment_container, fragment).commitAllowingStateLoss()
    }

    fun pauseResumeAccount() {
        presenter.pauseResumeAccount()
    }

    fun deleteAccount(listener: OnDataLoadListener) {
        presenter.deleteAccount(listener)
    }

    fun suspend() {
        presenter
    }

    override fun onBackPressed() {
        if (currentFragment is AccountFragment) {
            finish()
        } else {
            loadAccountPage()
        }
    }

    override fun updateView() {
        if (::currentFragment.isInitialized) {
            (currentFragment as InitFragment).initView()
        }
    }
}
