package com.weiyoubot.client.feature.account.view

import android.content.pm.PackageManager
import android.os.Bundle
import android.support.v7.app.AlertDialog
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.fragment.BaseFragment
import com.weiyoubot.client.common.utils.LaunchUtils
import com.weiyoubot.client.common.utils.PackageUtils.getPackageName
import com.weiyoubot.client.common.utils.PreferenceUtils
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.feature.login.LoginConstant
import com.weiyoubot.client.feature.main.UserDataHelper
import com.weiyoubot.client.model.loader.OnDataLoadListener
import kotlinx.android.synthetic.main.account_fragment.*

/**
 * Created by root on 11/24/16.
 */
class AccountFragment : BaseFragment(), AccountActivity.InitFragment {

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        return inflater.inflate(R.layout.account_fragment, container, false)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        initView()
        try {
            val packageInfo = context.packageManager.getPackageInfo(getPackageName(), 0)
            version.text = Utils.getString(R.string.version, packageInfo.versionName, packageInfo.versionCode)
        } catch (e: PackageManager.NameNotFoundException) {
            e.printStackTrace()
        }
    }

    override fun initView() {
        tips.setText(if (UserDataHelper.isAccountPaused()) R.string.resume_tips else R.string.pause_tips)
        val accountCouponSize = UserDataHelper.getAccountCoupon()?.size ?: 0
        coupon_balance.text = Utils.getString(R.string.coupon_balance, accountCouponSize)
        suspend.setText(if (UserDataHelper.isAccountPaused()) R.string.resume else R.string.pause)
        suspend.setOnClickListener {
            AlertDialog.Builder(activity).setTitle(R.string.dialog_title)
                    .setMessage(tips.text)
                    .setPositiveButton(R.string.ok) { _, _ ->
                        (activity as AccountActivity).pauseResumeAccount()
                    }.setNegativeButton(R.string.cancel, null).show()
        }
        logout.setOnClickListener {
            PreferenceUtils.saveAccessToken("")
            UserDataHelper.setRobotInfo(null)
            LaunchUtils.startLoginActivity(LoginConstant.TYPE_LOGIN)
        }
        val deleteAccountListener = object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                UIUtils.showToast(R.string.delete_account_success)
                PreferenceUtils.saveAccessToken("")
                UserDataHelper.setRobotInfo(null)
                LaunchUtils.startLoginActivity(LoginConstant.TYPE_LOGIN)
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                UIUtils.showFailedToast(R.string.delete_account_failed, errorMessage)
            }
        }
        delete_account.setOnClickListener {
            AlertDialog.Builder(activity).setTitle(R.string.dialog_title)
                    .setMessage(R.string.delete_account_tips)
                    .setPositiveButton(R.string.ok) { _, _ ->
                        (activity as AccountActivity).deleteAccount(deleteAccountListener)
                    }.setNegativeButton(R.string.cancel, null).show()
        }
        paid_groups.setOnClickListener {
            (activity as AccountActivity).loadPaidGroupsPage()
        }
        free_groups.setOnClickListener {
            (activity as AccountActivity).loadFreeGroupsPage()
        }
        balance.setOnClickListener {
            (activity as AccountActivity).loadBalancePage()
        }
        coupon.setOnClickListener {
            (activity as AccountActivity).loadCouponPage()
        }
    }
}
