package com.weiyoubot.client.feature.account.view

import android.os.Bundle
import android.os.Parcelable
import android.view.View.GONE
import android.view.View.VISIBLE
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.activity.BaseMvpActivity
import com.weiyoubot.client.common.helper.UmengHelper
import com.weiyoubot.client.common.utils.ImageUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.view.slidingtab.SlidingTabViewPagerTab
import com.weiyoubot.client.feature.account.PaymentConstant
import com.weiyoubot.client.feature.account.PaymentTableImageEvent
import com.weiyoubot.client.feature.account.presenter.PaymentPresenter
import com.weiyoubot.client.feature.main.UserDataConstant
import com.weiyoubot.client.feature.main.UserDataHelper
import com.weiyoubot.client.feature.webview.UrlConstant
import com.weiyoubot.client.model.bean.account.params.GoodsDetail
import com.weiyoubot.client.model.bean.account.result.OrderData
import com.weiyoubot.client.model.bean.userdata.Group
import kotlinx.android.synthetic.main.activity_payment.*
import org.greenrobot.eventbus.EventBus
import java.util.*

/**
 * Created by root on 12/13/16.
 */
class PaymentActivity : BaseMvpActivity<PaymentMvpView, PaymentPresenter>(), PaymentMvpView {

    private var mPermId: Int = 0
    private var mRenew: Boolean = false
    private var mRids: MutableList<String> = mutableListOf()
    private var mGroups: MutableList<Group> = mutableListOf()
    private var mSelectedGroups: MutableList<Group> = mutableListOf()

    private val currentTabIndex: Int
        get() = when {
            UserDataHelper.isPermBasic(mPermId) -> 0
            mPermId == UserDataConstant.PERM_ADVANCED -> 1
            else -> 2
        }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        mPermId = intent.getIntExtra(UserDataConstant.INTENT_KEY_PERM_ID, UserDataConstant.PERM_ULTIMATE)
        if (UserDataHelper.isPermValid(mPermId)) {
            finish()
            return
        }

        setContentView(R.layout.activity_payment)

        mRenew = intent.getBooleanExtra(PaymentConstant.INTENT_KEY_RENEW, false)
        mRids = intent.getStringArrayListExtra(PaymentConstant.INTENT_KEY_RIDS) ?: mutableListOf()
        mGroups = intent.getParcelableArrayListExtra(PaymentConstant.INTENT_KEY_GROUPS) ?: mutableListOf()
        mSelectedGroups = intent.getParcelableArrayListExtra(PaymentConstant.INTENT_KEY_SELECTED_GROUPS) ?: mutableListOf()

        if (youCanPay()) {
            // 续费或升级或买换群券或机器人个人微信号
            when {
                mRenew -> UmengHelper.trackEvent(UmengHelper.EVENT_ENTRY_ORDER_PAGE_RENEW)
                UserDataHelper.isPermUpdate(mPermId) -> UmengHelper.trackEvent(UmengHelper.EVENT_ENTRY_ORDER_PAGE_UPDATE)
                UserDataHelper.isPermChangeGroupTicket(mPermId) -> UmengHelper.trackEvent(UmengHelper.EVENT_ENTRY_ORDER_PAGE_CHANGE_GROUPS)
                UserDataHelper.isPermRobotPrivate(mPermId) -> UmengHelper.trackEvent(UmengHelper.EVENT_ENTRY_ORDER_PAGE_ROBOT_PRIVATE)
            }
            perm_view.visibility = VISIBLE
            perm_view.initView(mPermId, mRenew, mRids, mGroups, mSelectedGroups)
            perm_view.type = PaymentConstant.PAYMENT_VIEW_TYPE_RENEW
            perm_view.start()
            sliding_tab_view.visibility = GONE
        } else {
            // 购买
            perm_view.visibility = GONE
            sliding_tab_view.visibility = VISIBLE
            val tabs = createPaymentTabs()
            sliding_tab_view.initViewPager(supportFragmentManager, tabs)
            sliding_tab_view.setOffscreenPageLimit(Utils.getListCount(tabs))
            val tabIndex = currentTabIndex
            sliding_tab_view.currentItem = tabIndex
            trackEntry(tabIndex)
            ImageUtils.loadImage(this, UrlConstant.PAYMENT_VERSION_IMAGE_URL) { bitmap ->
                if (bitmap != null) {
                    EventBus.getDefault().post(PaymentTableImageEvent(bitmap))
                }
            }
        }

        back.setOnClickListener { finish() }
        customer_service.setOnClickListener { startCustomerService() }
    }


    private fun trackEntry(tabIndex: Int) {
        when (tabIndex) {
            0 -> UmengHelper.trackEvent(UmengHelper.EVENT_ENTRY_ORDER_PAGE_STARTER)
            1 -> UmengHelper.trackEvent(UmengHelper.EVENT_ENTRY_ORDER_PAGE_PREMIUM)
            2 -> UmengHelper.trackEvent(UmengHelper.EVENT_ENTRY_ORDER_PAGE_ULTIMATE)
            3 -> UmengHelper.trackEvent(UmengHelper.EVENT_ENTRY_ORDER_PAGE_ENTERPRISE)
        }
    }

    private fun createPaymentTabs(): List<SlidingTabViewPagerTab> {
        val tabs = ArrayList<SlidingTabViewPagerTab>()

        var bundle = Bundle()
        val basicFragment = PaymentFragment()
        bundle.putInt(UserDataConstant.INTENT_KEY_PERM_ID, UserDataConstant.PERM_BASIC_1)
        bundle.putParcelableArrayList(PaymentConstant.INTENT_KEY_GROUPS, mGroups as ArrayList<Group>)
        bundle.putParcelableArrayList(PaymentConstant.INTENT_KEY_SELECTED_GROUPS, mSelectedGroups as ArrayList<out Parcelable>?)
        bundle.putString(PaymentConstant.INTENT_KEY_PAYMENT_VIEW_TYPE, PaymentConstant.PAYMENT_VIEW_TYPE_BASIC)
        basicFragment.arguments = bundle

        val advancedFragment = PaymentFragment()
        bundle = Bundle()
        bundle.putInt(UserDataConstant.INTENT_KEY_PERM_ID, UserDataConstant.PERM_ADVANCED)
        bundle.putParcelableArrayList(PaymentConstant.INTENT_KEY_GROUPS, mGroups as ArrayList<out Parcelable>?)
        bundle.putParcelableArrayList(PaymentConstant.INTENT_KEY_SELECTED_GROUPS, mSelectedGroups as ArrayList<out Parcelable>?)
        bundle.putString(PaymentConstant.INTENT_KEY_PAYMENT_VIEW_TYPE, PaymentConstant.PAYMENT_VIEW_TYPE_ADVANCED)
        advancedFragment.arguments = bundle

        val ultimateFragment = PaymentFragment()
        bundle = Bundle()
        bundle.putInt(UserDataConstant.INTENT_KEY_PERM_ID, UserDataConstant.PERM_ULTIMATE)
        bundle.putParcelableArrayList(PaymentConstant.INTENT_KEY_GROUPS, mGroups as ArrayList<out Parcelable>?)
        bundle.putParcelableArrayList(PaymentConstant.INTENT_KEY_SELECTED_GROUPS, mSelectedGroups as ArrayList<out Parcelable>?)
        bundle.putString(PaymentConstant.INTENT_KEY_PAYMENT_VIEW_TYPE, PaymentConstant.PAYMENT_VIEW_TYPE_ULTIMATE)
        ultimateFragment.arguments = bundle

        val enterpriseFragment = PaymentEnterpriseFragment()

        tabs.add(SlidingTabViewPagerTab(0, Utils.getString(R.string.perm_name_basic), basicFragment))
        tabs.add(SlidingTabViewPagerTab(1, Utils.getString(R.string.perm_name_advanced), advancedFragment))
        tabs.add(SlidingTabViewPagerTab(2, Utils.getString(R.string.perm_name_ultimate), ultimateFragment))
        tabs.add(SlidingTabViewPagerTab(3, Utils.getString(R.string.perm_name_enterprise), enterpriseFragment))
        return tabs
    }

    override fun createPresenter(): PaymentPresenter {
        return PaymentPresenter()
    }

    fun startCustomerService() {
        presenter.startCustomerService(this)
    }

    override fun submitOrderSuccess(goodsDetails: List<GoodsDetail>, groupIds: List<String>, groupNames: List<String>, orderData: OrderData) {
        perm_view.visibility = GONE
        sliding_tab_view.visibility = GONE
        perm_confirm_pay.visibility = VISIBLE
        if (Utils.getListCount(goodsDetails) == 1) {
            val goodsDetail = goodsDetails[0]
            perm_confirm_pay.initView(goodsDetail.id, mRenew, goodsDetail.count, goodsDetail.duration, groupIds, groupNames, orderData)
        } else if (Utils.getListCount(goodsDetails) > 1) {
            // 同时续费多个不同精简版的群
            var count = 0
            var duration = 0
            val gids = ArrayList<String>()
            for (goodsDetail in goodsDetails) {
                count += goodsDetail.count
                duration = goodsDetail.duration
                gids.addAll(goodsDetail.gids)
            }
            perm_confirm_pay.initView(UserDataConstant.PERM_BASIC_1, mRenew, count, duration, gids, groupNames, orderData)
        }
    }

    override fun platformPay(payPlatform: Int, orderId: String, permId: Int, duration: Int, gids: List<String>) {
        presenter.platformPay(this, payPlatform, orderId, mRenew, permId, duration, gids)
    }

    private fun youCanPay(): Boolean {
        // 续费或升级或买换群券或机器人个人微信号
        return mRenew || UserDataHelper.isPermUpdate(mPermId) || UserDataHelper.isPermChangeGroupTicket(mPermId) || UserDataHelper.isPermRobotPrivate(mPermId)
    }

    override fun onDestroy() {
        super.onDestroy()
        if (youCanPay()) {
            perm_view?.stop()
        }
    }
}
