package com.weiyoubot.client.feature.account.view

import android.content.Context
import android.content.Intent
import android.graphics.Color
import android.text.SpannableString
import android.text.Spanned
import android.text.TextUtils
import android.text.method.LinkMovementMethod
import android.text.style.ClickableSpan
import android.util.AttributeSet
import android.view.View
import android.widget.CheckBox
import android.widget.CompoundButton
import android.widget.LinearLayout
import android.widget.RadioGroup
import com.weiyoubot.client.R
import com.weiyoubot.client.common.clickablespan.WebClickableSpan
import com.weiyoubot.client.common.helper.UmengHelper
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.utils.setTextHTML
import com.weiyoubot.client.common.view.CountChangeView
import com.weiyoubot.client.feature.account.*
import com.weiyoubot.client.feature.main.UserDataConstant
import com.weiyoubot.client.feature.main.UserDataHelper
import com.weiyoubot.client.feature.webview.UrlConstant
import com.weiyoubot.client.model.bean.account.params.GoodsDetail
import com.weiyoubot.client.model.bean.account.result.PriceData
import com.weiyoubot.client.model.bean.userdata.CouponInfo
import com.weiyoubot.client.model.bean.userdata.Group
import kotlinx.android.synthetic.main.payment_perm_view.view.*
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe
import java.util.*

/**
 * Created by root on 12/13/16.
 */
class PaymentPermView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0)
    : LinearLayout(context, attrs, defStyleAttr), CountChangeView.OnCountChangeListener,
        RadioGroup.OnCheckedChangeListener, CompoundButton.OnCheckedChangeListener {

    private var mPermId: Int = 0
    private var mRenew: Boolean = false
    private var mRids: MutableList<String> = mutableListOf()
    private var mGroups = mutableListOf<Group>()
    private var mSelectedGroups = mutableListOf<Group>()
    private var priceData: PriceData = PriceData()
    var type: String = PaymentConstant.PAYMENT_VIEW_TYPE_ULTIMATE

    private val finalPermId: Int
        get() {
            if (UserDataHelper.isPermBasic(mPermId)) {
                when (feature_basic.checkedRadioButtonId) {
                    R.id.feature_basic_1 -> return UserDataConstant.PERM_BASIC_1
                    R.id.feature_basic_2 -> return UserDataConstant.PERM_BASIC_2
                    R.id.feature_basic_3 -> return UserDataConstant.PERM_BASIC_3
                    R.id.feature_basic_4 -> return UserDataConstant.PERM_BASIC_4
                }
            }
            return mPermId
        }

    private val duration: Int
        get() {
            val checkedId = duration_group.checkedRadioButtonId
            return when (checkedId) {
                R.id.duration_3day -> 1003
                R.id.duration_3 -> 3
                R.id.duration_6 -> 6
                else -> 12
            }
        }

    init {
        View.inflate(context, R.layout.payment_perm_view, this)
        orientation = LinearLayout.VERTICAL
        val padding = Utils.getDimen(R.dimen.card_content_padding)
        setPadding(padding, 0, padding, padding)
        setBackgroundColor(Utils.getColor(R.color.common_white_color_alpha_100))
        setOnclickListener()
    }

    fun initView(permId: Int, renew: Boolean, rids: MutableList<String>, groups: MutableList<Group>, selectedGroups: MutableList<Group>) {
        mPermId = permId
        mRenew = renew
        mRids = rids
        mGroups = groups
        if (selectedGroups.isNotEmpty()) {
            mSelectedGroups.addAll(selectedGroups)
        }

        val permInfo = UserDataHelper.getPermInfo(mPermId)
        when {
            mRenew -> {
                // 续费
                name.visibility = View.VISIBLE
                name.text = Utils.getString(R.string.perm_renew, UserDataHelper.getPermName(mPermId))
                feature.visibility = View.GONE
                feature_basic.visibility = View.GONE
                duration_3day.visibility = View.GONE
                duration_info.visibility = View.VISIBLE
                duration_group.check(R.id.duration_12)
                duration_group.setOnCheckedChangeListener(this)
                price_msg.text = if (permInfo == null) "" else permInfo.price
                buy_group_info.visibility = View.GONE
                update_renew_group_info.visibility = View.VISIBLE
                update_renew_group_label.setText(R.string.perm_group_renew)
                initUpdateRenewGroupContainer()
                tips.visibility = View.GONE
            }
            UserDataHelper.isPermUpdate(mPermId) -> {
                // 升级
                name.visibility = View.VISIBLE
                val from = Utils.getString(if (mPermId == UserDataConstant.PERM_ADVANCED_UPDATE_ULTIMATE) R.string.perm_name_advanced else R.string.perm_name_basic)
                val to = Utils.getString(if (mPermId == UserDataConstant.PERM_BASIC_UPDATE_ADVANCED) R.string.perm_name_advanced else R.string.perm_name_ultimate)
                name.text = Utils.getString(R.string.perm_update, from, to)
                feature.text = Utils.getString(R.string.perm_feature, getPermInfoFeatureMsg(if (mPermId == UserDataConstant.PERM_BASIC_UPDATE_ADVANCED) UserDataConstant.PERM_ADVANCED else UserDataConstant.PERM_ULTIMATE))
                feature_basic.visibility = View.GONE
                duration_info.visibility = View.GONE
                buy_group_info.visibility = View.GONE
                update_renew_group_info.visibility = View.VISIBLE
                update_renew_group_label.setText(R.string.perm_group_update)
                initUpdateRenewGroupContainer()
                tips.visibility = View.VISIBLE
                val tipsStr = Utils.getString(R.string.perm_update_tips)
                val spannableString = SpannableString(tipsStr)
                val span = WebClickableSpan(context, "", UrlConstant.PERM_UPDATE_URL, "")
                spannableString.setSpan(span, tipsStr.length - 4, tipsStr.length, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE)
                tips.text = spannableString
                tips.movementMethod = LinkMovementMethod.getInstance()
                tips.highlightColor = Color.TRANSPARENT
            }
            UserDataHelper.isPermChangeGroupTicket(mPermId) -> {
                // 购买换群券
                name.visibility = View.VISIBLE
                name.text = UserDataHelper.getPermName(mPermId)
                feature.text = Utils.getString(R.string.perm_feature, if (permInfo == null) "" else permInfo.featureMsg)
                feature_basic.visibility = View.GONE
                duration_info.visibility = View.GONE
                buy_group_info.visibility = View.VISIBLE
                count_change_view.count = 1
                count_change_view.setOnCountChangeListener(this)
                if (permInfo != null && !TextUtils.isEmpty(permInfo.discount)) {
                    discount.visibility = View.VISIBLE
                    discount.setTextHTML(permInfo.discount)
                }
                update_renew_group_info.visibility = View.GONE
                tips.visibility = View.GONE
            }
            UserDataHelper.isPermRobotPrivate(mPermId) -> {
                // 购买机器人个人微信号
                name.visibility = View.GONE
                val tips = Utils.getString(R.string.perm_feature_detail, if (permInfo == null) "" else permInfo.featureMsg)
                val span = WebClickableSpan(context, "", UrlConstant.PERM_DETAIL_URL_3, "")
                val spannableString = SpannableString(tips)
                spannableString.setSpan(span, tips.length - 4, tips.length, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE)
                feature.text = spannableString
                feature.movementMethod = LinkMovementMethod.getInstance()
                feature.highlightColor = Color.TRANSPARENT
                feature_basic.visibility = View.GONE
                duration_info.visibility = View.VISIBLE
                duration_group.check(R.id.duration_6)
                duration_group.setOnCheckedChangeListener(this)
                price_msg.text = if (permInfo == null) "" else permInfo.price
                buy_group_info.visibility = View.GONE
                update_renew_group_info.visibility = View.GONE
                this.tips.visibility = View.VISIBLE
                this.tips.setText(R.string.perm_robot_private_tips)
            }
            else -> {
                // 购买群的权限
                name.visibility = View.GONE
                duration_3day.visibility = View.GONE
                val tips: String
                val span: ClickableSpan
                if (UserDataHelper.isPermBasic(mPermId)) {
                    tips = Utils.getString(R.string.perm_feature_detail, "")
                    span = WebClickableSpan(context, "", UrlConstant.PERM_DETAIL_URL_1, UmengHelper.EVENT_SHOW_DETAIL_IN_STARTER_PAGE)
                    duration_3day.visibility = View.GONE
                    feature_basic.visibility = View.VISIBLE
                    feature_basic.check(R.id.feature_basic_3)
                    feature_basic.setOnCheckedChangeListener(this)
                    feature_basic_1.text = getPermInfoFeatureMsg(UserDataConstant.PERM_BASIC_1)
                    feature_basic_2.text = getPermInfoFeatureMsg(UserDataConstant.PERM_BASIC_2)
                    feature_basic_3.text = getPermInfoFeatureMsg(UserDataConstant.PERM_BASIC_3)
                    feature_basic_4.text = getPermInfoFeatureMsg(UserDataConstant.PERM_BASIC_4)
                } else {
                    tips = Utils.getString(R.string.perm_feature_detail, if (permInfo == null) "" else permInfo.featureMsg)
                    span = if (mPermId == UserDataConstant.PERM_ADVANCED) {
                        WebClickableSpan(context, "", UrlConstant.PERM_DETAIL_URL_1, UmengHelper.EVENT_SHOW_DETAIL_IN_PREMIUM_PAGE)
                    } else {
                        if(UserDataHelper.isThreeDayUltimate()){
                            duration_3day.visibility = View.VISIBLE
                        }
                        WebClickableSpan(context, "", UrlConstant.PERM_DETAIL_URL_2, UmengHelper.EVENT_SHOW_DETAIL_IN_ULTIMATE_PAGE)
                    }
                    feature_basic.visibility = View.GONE
                }
                val spannableString = SpannableString(tips)
                spannableString.setSpan(span, tips.length - 4, tips.length, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE)
                feature.text = spannableString
                feature.movementMethod = LinkMovementMethod.getInstance()
                feature.highlightColor = Color.TRANSPARENT
                duration_info.visibility = View.VISIBLE
                duration_group.check(R.id.duration_12)
                duration_group.setOnCheckedChangeListener(this)
                price_msg.text = if (permInfo == null) "" else permInfo.price
                buy_group_info.visibility = View.VISIBLE
                count_change_view.count = if (Utils.isListEmpty(mSelectedGroups)) 1 else Utils.getListCount(mSelectedGroups)
                count_change_view.setOnCountChangeListener(this)
                if (permInfo != null && !TextUtils.isEmpty(permInfo.discount)) {
                    discount.visibility = View.VISIBLE
                    discount.setTextHTML(permInfo.discount)
                }
                update_renew_group_info.visibility = View.GONE
                this.tips.visibility = View.GONE
            }
        }
        calculatePrice()
    }

    private fun initUpdateRenewGroupContainer() {
        update_renew_group_container.removeAllViews()
        if (mGroups.isNotEmpty()) {
            for (group in mGroups) {
                val view = View.inflate(context, R.layout.account_group_item_view, null)
                val checkBox = view.findViewById<View>(R.id.group) as CheckBox
                checkBox.tag = group
                checkBox.text = group.getName()
                checkBox.isChecked = mSelectedGroups.contains(group)
                checkBox.setOnCheckedChangeListener(this)
                update_renew_group_container.addView(checkBox)
            }
        }
    }

    private fun getPermInfoFeatureMsg(permId: Int): String {
        val permInfo = UserDataHelper.getPermInfo(permId)
        return if (permInfo != null && !TextUtils.isEmpty(permInfo.featureMsg)) {
            permInfo.featureMsg
        } else ""
    }

    override fun onCheckedChanged(group: RadioGroup, checkedId: Int) {
        calculatePrice()
    }

    override fun onCheckedChanged(buttonView: CompoundButton, isChecked: Boolean) {
        val group = buttonView.tag as Group
        if (isChecked) {
            mSelectedGroups.add(group)
        } else {
            mSelectedGroups.remove(group)
        }
        calculatePrice()
    }

    private fun setOnclickListener() {
        price.setOnClickListener { calculatePrice() }
        submit_order.setOnClickListener {
            trackSubmitOrder()
            try {
                if (priceData.totalFee > 0) {
                    EventBus.getDefault().post(PaymentSubmitOrderEvent(createGoodsDetails(), getGroupIds(mSelectedGroups), getGroupNames(mSelectedGroups),
                            priceData.totalFee - priceData.coupon_discount, priceData.selectedCid))
                } else {
                    UIUtils.showToast(R.string.perm_no_group_select_tips)
                }
            } catch (e: Exception) {
                UIUtils.showToast(R.string.payment_submit_order_no_price_tips)
            }

        }
        coupon_more.setOnClickListener {
            val intent = Intent(context, CouponSelectActivity::class.java)
            intent.putParcelableArrayListExtra(CouponConstant.COUPON_INTENT_KEY_COUPONS, priceData.coupons as ArrayList<CouponInfo>)
            intent.putExtra(CouponConstant.COUPON_INTENT_KEY_SELECTED_CID, priceData.selectedCid)
            intent.putExtra(PaymentConstant.INTENT_KEY_PAYMENT_VIEW_TYPE, type)
            context.startActivity(intent)
        }
    }

    private fun trackSubmitOrder() {
        when {
            UserDataHelper.isPermBasic(mPermId) -> UmengHelper.trackEvent(UmengHelper.EVENT_CREATE_ORDER_STARTER)
            mPermId == UserDataConstant.PERM_ADVANCED -> UmengHelper.trackEvent(UmengHelper.EVENT_CREATE_ORDER_PREMIUM)
            mPermId == UserDataConstant.PERM_ULTIMATE -> UmengHelper.trackEvent(UmengHelper.EVENT_CREATE_ORDER_ULTIMATE)
            UserDataHelper.isPermUpdate(mPermId) -> UmengHelper.trackEvent(UmengHelper.EVENT_CREATE_ORDER_UPDATE)
            UserDataHelper.isPermChangeGroupTicket(mPermId) -> UmengHelper.trackEvent(UmengHelper.EVENT_CREATE_ORDER_CHANGE_GROUPS)
            UserDataHelper.isPermRobotPrivate(mPermId) -> UmengHelper.trackEvent(UmengHelper.EVENT_CREATE_ORDER_ROBOT_PRIVATE)
        }
    }

    override fun onCountChanged(count: Int) {
        calculatePrice()
    }

    private fun calculatePrice() {
        EventBus.getDefault().post(PaymentPriceEvent(createGoodsDetails(), this))
    }

    private fun createGoodsDetails(): List<GoodsDetail> {
        val duration = duration
        val goodsDetails = ArrayList<GoodsDetail>()
        if (mRenew && UserDataHelper.isPermBasic(mPermId)) {
            // 续费精简版可能存在不同的permId的群
            val gidsBasic1 = ArrayList<String>()
            val gidsBasic2 = ArrayList<String>()
            val gidsBasic3 = ArrayList<String>()
            val gidsBasic4 = ArrayList<String>()
            for (group in mSelectedGroups) {
                when (UserDataHelper.getGroupPermId(group)) {
                    UserDataConstant.PERM_BASIC_1 -> gidsBasic1.add(group.gid)
                    UserDataConstant.PERM_BASIC_2 -> gidsBasic2.add(group.gid)
                    UserDataConstant.PERM_BASIC_3 -> gidsBasic3.add(group.gid)
                    UserDataConstant.PERM_BASIC_4 -> gidsBasic4.add(group.gid)
                }
            }
            if (!Utils.isListEmpty(gidsBasic1)) {
                goodsDetails.add(createGoodsDetail(UserDataConstant.PERM_BASIC_1, Utils.getListCount(gidsBasic1), duration, gidsBasic1))
            }
            if (!Utils.isListEmpty(gidsBasic2)) {
                goodsDetails.add(createGoodsDetail(UserDataConstant.PERM_BASIC_2, Utils.getListCount(gidsBasic2), duration, gidsBasic2))
            }
            if (!Utils.isListEmpty(gidsBasic3)) {
                goodsDetails.add(createGoodsDetail(UserDataConstant.PERM_BASIC_3, Utils.getListCount(gidsBasic3), duration, gidsBasic3))
            }
            if (!Utils.isListEmpty(gidsBasic4)) {
                goodsDetails.add(createGoodsDetail(UserDataConstant.PERM_BASIC_4, Utils.getListCount(gidsBasic4), duration, gidsBasic4))
            }
        } else if (UserDataHelper.isPermRobotPrivate(mPermId)) {
            goodsDetails.add(createGoodsDetail(finalPermId, 1, duration, mRids))
        } else {
            val count = if (mRenew || UserDataHelper.isPermUpdate(mPermId)) Utils.getListCount(mSelectedGroups) else count_change_view.count
            if (count > 0) {
                goodsDetails.add(createGoodsDetail(finalPermId, count, duration, getGroupIds(mSelectedGroups)))
            }
        }
        return goodsDetails
    }

    private fun createGoodsDetail(permId: Int, count: Int, duration: Int, ids: List<String>?): GoodsDetail {
        val goodsDetail = GoodsDetail()
        goodsDetail.id = permId
        goodsDetail.count = count
        goodsDetail.duration = duration
        if (mRenew || UserDataHelper.isPermUpdate(permId)) {
            // 续费和升级才需要带gids，购买不带而是付费成功后再选群
            goodsDetail.gids = ids
        } else if (UserDataHelper.isPermRobotPrivate(permId)) {
            // 购买机器人个人微信号需要带上rids
            goodsDetail.rids = ids
        }
        goodsDetail.renew = if (mRenew) 1 else 0
        return goodsDetail
    }

    private fun getGroupNames(groups: List<Group>): List<String> {
        val groupNames = ArrayList<String>()
        for (group in groups) {
            if (!TextUtils.isEmpty(group.name)) {
                groupNames.add(group.name)
            }
        }
        return groupNames
    }

    private fun getGroupIds(groups: List<Group>): List<String> {
        val gids = ArrayList<String>()
        for (group in groups) {
            if (!TextUtils.isEmpty(group.gid)) {
                gids.add(group.gid)
            }
        }
        return gids
    }

    fun updatePriceDataSuccess(priceData: PriceData) {
        this.priceData = priceData
        if (priceData.coupons.size > 0 && priceData.coupons[0].order_discount > 0) {
            priceData.selectedCid = priceData.coupons[0].id
        }
        price.isClickable = false
        updateCouponSelected()
    }

    fun updatePriceDataFailed() {
        this.priceData = PriceData()
        price.setText(R.string.payment_get_price_error)
        coupon_discount.setText(R.string.empty)
        price.isClickable = true
    }

    private fun updateCouponSelected() {
        var priceText = ""
        if (!TextUtils.isEmpty(priceData.des)) {
            priceText += " (" + priceData.des + ")"
        }
        price.setTextHTML(Utils.getString(R.string.payment_price, Utils.getTwoDecimalFloat(priceData.totalFee - priceData.coupon_discount), priceText))
        coupon_discount.text = if (priceData.coupon_discount > 0) Utils.getString(R.string.payment_coupon_price, priceData.coupon_discount) else Utils.getString(R.string.empty)
    }

    fun start() {
        EventBus.getDefault().register(this)
    }

    fun stop() {
        EventBus.getDefault().unregister(this)
    }

    @Subscribe
    fun onEvent(event: CouponSelectedEvent) {
        if (event.type == type) {
            priceData.selectedCid = event.selectedCid
            priceData.coupon_discount = event.coupon_discount
            updateCouponSelected()
        }
    }
}
