package com.weiyoubot.client.feature.main.content.complaint.presenter

import com.hannesdorfmann.mosby3.mvp.MvpBasePresenter
import com.weiyoubot.client.R
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.common.view.SwitchItemViewEvent
import com.weiyoubot.client.feature.main.content.complaint.ComplaintHelper
import com.weiyoubot.client.feature.main.content.complaint.view.ComplaintMvpView
import com.weiyoubot.client.model.bean.complaint.exit.ComplaintExit
import com.weiyoubot.client.model.bean.complaint.exit.Exit
import com.weiyoubot.client.model.bean.complaint.latest.ComplaintLatest
import com.weiyoubot.client.model.bean.complaint.latest.Latest
import com.weiyoubot.client.model.bean.complaint.suspect.ComplaintSuspect
import com.weiyoubot.client.model.loader.OnDataLoadListener

import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe

/**
 * Created by root on 11/16/16.
 */
class ComplaintPresenter : MvpBasePresenter<ComplaintMvpView>() {

    fun loadComplaintSuspect(gid: String) {
        ComplaintHelper.loadComplaintSuspect(gid, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    view.updateComplaintSuspect(data as ComplaintSuspect)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached { view ->
                    view.updateComplaintSuspect(ComplaintSuspect())
                }
            }
        })
    }

    fun loadComplaintExit(gid: String, day: Int) {
        ComplaintHelper.loadComplaintExit(gid, day, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    view.updateComplaintExit(data as ComplaintExit)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached { view ->
                    view.updateComplaintExit(ComplaintExit())
                }
            }
        })
    }

    fun loadComplaintLatest(gid: String) {
        ComplaintHelper.loadComplaintLatest(gid, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    view.updateComplaintLatest(data as ComplaintLatest)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached { view ->
                    view.updateComplaintLatest(ComplaintLatest())
                }
            }
        })
    }

    fun exitComplaint(gid: String, exit: Exit) {
        ComplaintHelper.exitComplaint(gid, exit, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    view.exitComplaintSuccess(exit)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached {
                    UIUtils.showFailedToast(R.string.complaint_failed, errorMessage)
                }
            }
        })
    }

    fun exitRepeal(gid: String, exit: Exit) {
        ComplaintHelper.exitRepeal(gid, exit, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    view.exitRepealSuccess(exit)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached {
                    UIUtils.showFailedToast(R.string.complaint_repeal_failed, errorMessage)
                }
            }
        })
    }

    fun latestComplaint(gid: String, latest: Latest) {
        ComplaintHelper.latestComplaint(gid, latest, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    view.latestComplaintSuccess(latest)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached {
                    UIUtils.showFailedToast(R.string.complaint_failed, errorMessage)
                }
            }
        })
    }

    fun latestRepeal(gid: String, latest: Latest) {
        ComplaintHelper.latestRepeal(gid, latest, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    view.latestRepealSuccess(latest)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached {
                    UIUtils.showFailedToast(R.string.complaint_repeal_failed, errorMessage)
                }
            }
        })
    }

    fun switchComplaint(gid: String, on: Boolean) {
        ComplaintHelper.switchComplaint(gid, if (on) 1 else 0, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    view.updateComplaintSwitchStatus(on)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached { view ->
                    view.updateComplaintSwitchStatus(!on)
                    UIUtils.showFailedToast(R.string.set_failed, errorMessage)
                }
            }
        })
    }

    fun getAction(checkedId: Int): String {
        return ComplaintHelper.getAction(checkedId)
    }

    override fun attachView(view: ComplaintMvpView) {
        super.attachView(view)
        EventBus.getDefault().register(this)
    }

    override fun detachView() {
        super.detachView()
        EventBus.getDefault().unregister(this)
    }

    @Subscribe
    fun onEvent(event: SwitchItemViewEvent) {
        ifViewAttached { view ->
            when (event.id) {
                R.id.complaint_switch_item_view -> view.complaintSwitchChanged(event.on)
                else -> {
                }
            }
        }
    }
}
