package com.weiyoubot.client.feature.main.content.complaint.view

import android.annotation.SuppressLint
import android.os.Bundle
import android.support.v7.app.AlertDialog
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.View.VISIBLE
import android.view.ViewGroup
import android.widget.TextView
import butterknife.BindView
import butterknife.ButterKnife
import butterknife.Unbinder
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.fragment.BaseMvpFragment
import com.weiyoubot.client.common.table.TableAdapter
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.view.SwitchItemView
import com.weiyoubot.client.common.view.TrialView
import com.weiyoubot.client.common.view.WrapRadioGroup
import com.weiyoubot.client.common.view.recyclerviewmanager.FullyLinearLayoutManager
import com.weiyoubot.client.feature.main.UserDataConstant
import com.weiyoubot.client.feature.main.content.TableHelper
import com.weiyoubot.client.feature.main.content.complaint.presenter.ComplaintPresenter
import com.weiyoubot.client.feature.main.menu.MenuConstant
import com.weiyoubot.client.model.bean.complaint.exit.ComplaintExit
import com.weiyoubot.client.model.bean.complaint.exit.Exit
import com.weiyoubot.client.model.bean.complaint.latest.ComplaintLatest
import com.weiyoubot.client.model.bean.complaint.latest.Latest
import com.weiyoubot.client.model.bean.complaint.suspect.ComplaintSuspect
import com.weiyoubot.client.model.bean.userdata.Group

/**
 * Created by root on 10/31/16.
 */
class ComplaintFragment : BaseMvpFragment<ComplaintMvpView, ComplaintPresenter>(), ComplaintMvpView {

    lateinit var mGid: String
    private lateinit var mComplaintSuspectTableAdapter: TableAdapter
    private lateinit var mComplaintExitTableAdapter: TableAdapter
    private lateinit var mComplaintLatestTableAdapter: TableAdapter

    private var mComplaintSuspect: ComplaintSuspect = ComplaintSuspect()
    private var mComplaintExit: ComplaintExit = ComplaintExit()
    private var mComplaintLatest: ComplaintLatest = ComplaintLatest()

    lateinit var unbinder: Unbinder

    @BindView(R.id.trial_view)
    lateinit var mTrialView: TrialView
    @BindView(R.id.complaint_suspect_table)
    lateinit var mComplaintSuspectTable: RecyclerView
    @BindView(R.id.complaint_suspect_no_id_members)
    lateinit var mComplaintSuspectNoIdMembers: TextView
    @BindView(R.id.complaint_exit_table)
    lateinit var mComplaintExitTable: RecyclerView
    @BindView(R.id.complaint_latest_table)
    lateinit var mComplaintLatestTable: RecyclerView
    @BindView(R.id.complaint_switch_item_view)
    lateinit var mComplaintSwitchItemView: SwitchItemView

    @SuppressLint("InflateParams")
    private val mComplaintExitTableItemClickListener = TableAdapter.OnTableItemClickListener { rowIndex, columnIndex ->
        if (mComplaintExit.data.isNotEmpty() && rowIndex > 0 && columnIndex == 1) {
            val exit = mComplaintExit.data[rowIndex - 1]
            if (exit.repeal == 1) {
                val view = LayoutInflater.from(activity).inflate(R.layout.complaint_dialog_view, null)
                val radioGroup = view.findViewById<View>(R.id.radio_group) as WrapRadioGroup
                radioGroup.check(R.id.complaint_ad)
                AlertDialog.Builder(context!!).setTitle(R.string.complaint).setView(view).setPositiveButton(R.string.ok) { _, _ ->
                    exit.action = presenter.getAction(radioGroup.checkedRadioButtonId)
                    presenter.exitComplaint(mGid, exit)
                }.setNegativeButton(R.string.cancel, null).show()
            } else {
                presenter.exitRepeal(mGid, exit)
            }
        }
    }

    @SuppressLint("InflateParams")
    private val mComplaintLatestTableItemClickListener = TableAdapter.OnTableItemClickListener { rowIndex, columnIndex ->
        if (mComplaintLatest.data.isNotEmpty() && rowIndex > 0 && columnIndex == 2) {
            val latest = mComplaintLatest.data[rowIndex - 1]
            if (latest.repeal == 1) {
                val view = LayoutInflater.from(activity).inflate(R.layout.complaint_dialog_view, null)
                val radioGroup = view.findViewById<View>(R.id.radio_group) as WrapRadioGroup
                radioGroup.check(R.id.complaint_ad)
                AlertDialog.Builder(context!!).setTitle(R.string.complaint).setView(view).setPositiveButton(R.string.ok) { _, _ ->
                    latest.action = presenter.getAction(radioGroup.checkedRadioButtonId)
                    presenter.latestComplaint(mGid, latest)
                }.setNegativeButton(R.string.cancel, null).show()
            } else {
                presenter.latestRepeal(mGid, latest)
            }
        }
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        val view = inflater.inflate(R.layout.complaint_fragment, container, false)
        unbinder = ButterKnife.bind(this, view)
        return view
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val group = arguments!!.getParcelable<Group>(MenuConstant.INTENT_KEY_GROUP)
        val trial = arguments!!.getBoolean(MenuConstant.INTENT_KEY_TRIAL)
        val permId = arguments!!.getInt(UserDataConstant.INTENT_KEY_PERM_ID)
        mGid = group!!.gid

        mTrialView.initView(group, trial, permId)

        mComplaintSuspectTableAdapter = TableAdapter(activity)
        mComplaintSuspectTable.layoutManager = FullyLinearLayoutManager(activity)
        mComplaintSuspectTable.adapter = mComplaintSuspectTableAdapter

        mComplaintExitTableAdapter = TableAdapter(activity)
        mComplaintExitTableAdapter.setOnTableItemClickListener(mComplaintExitTableItemClickListener)
        mComplaintExitTable.layoutManager = FullyLinearLayoutManager(activity)
        mComplaintExitTable.adapter = mComplaintExitTableAdapter

        mComplaintLatestTableAdapter = TableAdapter(activity)
        mComplaintLatestTableAdapter.setOnTableItemClickListener(mComplaintLatestTableItemClickListener)
        mComplaintLatestTable.layoutManager = FullyLinearLayoutManager(activity)
        mComplaintLatestTable.adapter = mComplaintLatestTableAdapter

        mComplaintSwitchItemView.setImageDescription(Utils.getString(R.string.complaint_latest_switch_description), R.drawable.emoji_dislike)

        loadComplaintSuspect()
        loadComplaintExit()
        loadComplaintLatest()
    }

    override fun createPresenter(): ComplaintPresenter {
        return ComplaintPresenter()
    }

    private fun loadComplaintSuspect() {
        presenter.loadComplaintSuspect(mGid)
    }

    private fun loadComplaintExit() {
        // 48小时内的数据，day传2
        presenter.loadComplaintExit(mGid, 2)
    }

    private fun loadComplaintLatest() {
        presenter.loadComplaintLatest(mGid)
    }

    override fun updateComplaintSuspect(data: ComplaintSuspect) {
        mComplaintSuspect = data.copy()
        if (mComplaintSuspect.noid_members.isNotEmpty()) {
            val builder = StringBuilder()
            for (member in mComplaintSuspect.noid_members) {
                builder.append(member).append(",")
            }
            if (builder.isNotEmpty()) {
                builder.deleteCharAt(builder.length - 1)
            }
            mComplaintSuspectNoIdMembers.visibility = VISIBLE
            mComplaintSuspectNoIdMembers.text = Utils.getString(R.string.complaint_suspect_no_id_members, builder)
        }
        mComplaintSuspectTableAdapter.data = TableHelper.createComplaintSuspectTableData(mComplaintSuspect.data)
        mComplaintSuspectTableAdapter.notifyDataSetChanged()
    }

    override fun updateComplaintExit(data: ComplaintExit) {
        mComplaintExit = data
        mComplaintExitTableAdapter.data = TableHelper.createComplaintExitTableData(mComplaintExit.data)
        mComplaintExitTableAdapter.notifyDataSetChanged()
    }

    override fun updateComplaintLatest(data: ComplaintLatest) {
        mComplaintLatest = data
        mComplaintLatestTableAdapter.data = TableHelper.createComplaintLatestTableData(mComplaintLatest.data)
        mComplaintLatestTableAdapter.notifyDataSetChanged()
        mComplaintSwitchItemView.setSwitchOn(mComplaintLatest.on_off == 1)
    }

    override fun complaintSwitchChanged(on: Boolean) {
        presenter.switchComplaint(mGid, on)
    }

    override fun updateComplaintSwitchStatus(on: Boolean) {
        mComplaintLatest.on_off = if (on) 1 else 0
        mComplaintSwitchItemView.setSwitchOn(on)
    }

    override fun exitComplaintSuccess(exit: Exit) {
        exit.repeal = 0
        mComplaintExitTableAdapter.data = TableHelper.createComplaintExitTableData(mComplaintExit.data)
        mComplaintExitTableAdapter.notifyDataSetChanged()
    }

    override fun exitRepealSuccess(exit: Exit) {
        exit.repeal = 1
        mComplaintExitTableAdapter.data = TableHelper.createComplaintExitTableData(mComplaintExit.data)
        mComplaintExitTableAdapter.notifyDataSetChanged()
    }

    override fun latestComplaintSuccess(latest: Latest) {
        latest.repeal = 0
        mComplaintLatestTableAdapter.data = TableHelper.createComplaintLatestTableData(mComplaintLatest.data)
        mComplaintLatestTableAdapter.notifyDataSetChanged()
    }

    override fun latestRepealSuccess(latest: Latest) {
        latest.repeal = 1
        mComplaintLatestTableAdapter.data = TableHelper.createComplaintLatestTableData(mComplaintLatest.data)
        mComplaintLatestTableAdapter.notifyDataSetChanged()
    }

    override fun onDestroyView() {
        super.onDestroyView()
        unbinder.unbind()
    }
}
