package com.weiyoubot.client.feature.main.content.kickout.presenter

import com.hannesdorfmann.mosby3.mvp.MvpBasePresenter
import com.weiyoubot.client.R
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.common.view.SwitchItemViewEvent
import com.weiyoubot.client.feature.main.content.kickout.KickOutChangeEvent
import com.weiyoubot.client.feature.main.content.kickout.view.KickOutMembersMvpView
import com.weiyoubot.client.model.api.ApiClient
import com.weiyoubot.client.model.bean.kickout.KickOutMembers
import com.weiyoubot.client.model.bean.kickout.KickOutSettings
import com.weiyoubot.client.model.loader.OnDataLoadListener

import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe
import org.json.JSONException

/**
 * Created by root on 11/15/16.
 */
class KickOutMembersPresenter : MvpBasePresenter<KickOutMembersMvpView>() {

    fun loadKickOutSettings(gid: String) {
        ApiClient.requestKickOutSettings(gid, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    view.updateKickOutSettings(data as KickOutSettings)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached { view ->
                    view.updateKickOutSettings(KickOutSettings())
                    if (errorCode == 4202) {
                        view.updateGroupOwnerTip(errorMessage)
                    }
                }
            }
        })
    }

    fun saveKickOutSettings(gid: String, kickOutSettings: KickOutSettings) {
        try {
            ApiClient.saveKickOutSettings(gid, kickOutSettings, object : OnDataLoadListener {
                override fun onDataLoaded(data: Any) {
                    ifViewAttached { view ->
                        view.updateKickOutSettings(kickOutSettings)
                    }
                }

                override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                    ifViewAttached {
                        UIUtils.showFailedToast(R.string.set_failed, errorMessage)
                    }
                }
            })
        } catch (e: JSONException) {
            e.printStackTrace()
        }

    }


    override fun attachView(view: KickOutMembersMvpView) {
        super.attachView(view)
        EventBus.getDefault().register(this)
    }

    override fun detachView() {
        super.detachView()
        EventBus.getDefault().unregister(this)
    }

    @Subscribe
    fun onEvent(event: SwitchItemViewEvent) {
        ifViewAttached { view ->
            when (event.id) {
                R.id.keyword_kick_out_toggle -> view.updateKeywordKickOutOnOff(event.on)
                R.id.scamper_kick_out_toggle -> view.updateScamperKickOutOnOff(event.on)
                R.id.normal_kick_out_toggle -> view.updateNormalKickOutOnOff(event.on)
                R.id.admin_kick_out_toggle -> view.updateAdminKickOutOnOff(event.on)
            }
        }
    }
}
