package com.weiyoubot.client.feature.main.content.kickout.view

import android.os.Bundle
import android.support.v7.app.AlertDialog
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import butterknife.BindView
import butterknife.ButterKnife
import butterknife.Unbinder
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.fragment.BaseMvpFragment
import com.weiyoubot.client.common.table.TableAdapter
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.view.TrialView
import com.weiyoubot.client.common.view.recyclerviewmanager.FullyLinearLayoutManager
import com.weiyoubot.client.feature.main.UserDataConstant
import com.weiyoubot.client.feature.main.content.TableHelper
import com.weiyoubot.client.feature.main.content.kickout.KickOutChangeEvent
import com.weiyoubot.client.feature.main.content.kickout.presenter.KickOutBlacklistPresenter
import com.weiyoubot.client.feature.main.menu.MenuConstant
import com.weiyoubot.client.model.bean.kickout.KickOutBlacklist
import com.weiyoubot.client.model.bean.userdata.Group
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe

/**
 * Created by pgao on 2018/3/24.
 */

class KickOutBlacklistFragment : BaseMvpFragment<KickOutBlacklistMvpView, KickOutBlacklistPresenter>(), KickOutBlacklistMvpView, TableAdapter.OnTableItemClickListener {

    private lateinit var mGid: String
    private lateinit var mKickOutBlacklistTableAdapter: TableAdapter
    private lateinit var mKickOutBlacklist: KickOutBlacklist
    private lateinit var unbinder: Unbinder

    @BindView(R.id.trial_view)
    lateinit var mTrialView: TrialView
    @BindView(R.id.kick_out_blacklist_table)
    lateinit var mKickOutBlacklistTable: RecyclerView

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        val view = inflater.inflate(R.layout.kick_out_blacklist_fragment, container, false)
        unbinder = ButterKnife.bind(this, view)
        EventBus.getDefault().register(this)
        return view
    }

    override fun onViewCreated(view: View?, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val group = arguments.getParcelable<Group>(MenuConstant.INTENT_KEY_GROUP)
        val trial = arguments.getBoolean(MenuConstant.INTENT_KEY_TRIAL)
        val permId = arguments.getInt(UserDataConstant.INTENT_KEY_PERM_ID)
        mGid = group!!.gid

        mTrialView.initView(group, trial, permId)

        mKickOutBlacklistTableAdapter = TableAdapter(activity)
        mKickOutBlacklistTableAdapter.data = TableHelper.createKickOutBlacklistTableData(listOf())
        mKickOutBlacklistTableAdapter.setOnTableItemClickListener(this)
        mKickOutBlacklistTable.layoutManager = FullyLinearLayoutManager(activity)
        mKickOutBlacklistTable.adapter = mKickOutBlacklistTableAdapter

        loadBlacklist()
    }

    override fun createPresenter(): KickOutBlacklistPresenter {
        return KickOutBlacklistPresenter()
    }

    private fun loadBlacklist() {
        presenter.loadKickOutBlacklist(mGid)
    }

    override fun onTableItemClick(rowIndex: Int, columnIndex: Int) {
        if (rowIndex > 0 && columnIndex > 0 && mKickOutBlacklist.blacklist.isNotEmpty()) {
            val (name, uid) = mKickOutBlacklist.blacklist[rowIndex - 1]
            if (columnIndex == 2) {
                AlertDialog.Builder(activity).setTitle(R.string.dialog_title)
                        .setMessage(Utils.getString(R.string.kick_out_confirm_remove_from_blacklist, name))
                        .setPositiveButton(R.string.ok) { _, _ -> presenter.deleteFromKickOutBlacklist(mGid, uid) }.setNegativeButton(R.string.cancel, null).show()
            }
        }
    }

    override fun onDestroyView() {
        super.onDestroyView()
        unbinder.unbind()
        EventBus.getDefault().unregister(this)
    }

    override fun updateKickOutBlacklist(data: KickOutBlacklist) {
        mKickOutBlacklist = data
        mKickOutBlacklistTableAdapter.data = TableHelper.createKickOutBlacklistTableData(mKickOutBlacklist.blacklist)
        mKickOutBlacklistTableAdapter.notifyDataSetChanged()
    }

    @Suppress("UNUSED_PARAMETER")
    @Subscribe
    fun onEvent(event: KickOutChangeEvent) {
        loadBlacklist()
    }
}
