package com.weiyoubot.client.feature.main.content.kickout.view

import android.os.Bundle
import android.support.v7.app.AlertDialog
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import butterknife.BindView
import butterknife.ButterKnife
import butterknife.Unbinder
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.fragment.BaseMvpFragment
import com.weiyoubot.client.common.table.TableAdapter
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.view.TrialView
import com.weiyoubot.client.common.view.recyclerviewmanager.FullyLinearLayoutManager
import com.weiyoubot.client.feature.main.UserDataConstant
import com.weiyoubot.client.feature.main.content.TableHelper
import com.weiyoubot.client.feature.main.content.kickout.KickOutChangeEvent
import com.weiyoubot.client.feature.main.content.kickout.presenter.KickOutRecordPresenter
import com.weiyoubot.client.feature.main.menu.MenuConstant
import com.weiyoubot.client.model.bean.kickout.KickOutMember
import com.weiyoubot.client.model.bean.kickout.KickOutMembers
import com.weiyoubot.client.model.bean.userdata.Group
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe


class KickOutRecordFragment : BaseMvpFragment<KickOutRecordMvpView, KickOutRecordPresenter>(), KickOutRecordMvpView, TableAdapter.OnTableItemClickListener {

    private lateinit var mGid: String
    private lateinit var mKickOutMemberTableAdapter: TableAdapter
    private var mKickOutMembers: KickOutMembers = KickOutMembers()
    private lateinit var unbinder: Unbinder

    @BindView(R.id.kick_out_member_table)
    lateinit var mKickOutMemberTable: RecyclerView

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        val view = inflater.inflate(R.layout.kick_out_record_fragment, container, false)
        unbinder = ButterKnife.bind(this, view)
        EventBus.getDefault().register(this)
        return view
    }

    override fun onViewCreated(view: View?, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val group = arguments.getParcelable<Group>(MenuConstant.INTENT_KEY_GROUP)
//        val trial = arguments.getBoolean(MenuConstant.INTENT_KEY_TRIAL)
        //val permId = arguments.getInt(UserDataConstant.INTENT_KEY_PERM_ID)
        mGid = group!!.gid

        //mTrialView.initView(group, trial, permId)
        mKickOutMemberTableAdapter = TableAdapter(activity)
        mKickOutMemberTableAdapter.data = TableHelper.createKickOutMemberTableData(listOf())
        mKickOutMemberTableAdapter.setOnTableItemClickListener { rowIndex, _ ->
            if (mKickOutMembers.kickOutMembers.size >= rowIndex && rowIndex > 0) {
                val kickOutMember = mKickOutMembers.kickOutMembers[rowIndex - 1]
                if (kickOutMember.inBlacklist == 0) {
                    AlertDialog.Builder(activity).setTitle(R.string.dialog_title)
                            .setMessage(Utils.getString(R.string.kick_out_confirm_add_to_blacklist, kickOutMember.nickname))
                            .setPositiveButton(R.string.ok) { _, _ -> presenter.addToKickOutBlacklist(mGid, kickOutMember.uid) }.setNegativeButton(R.string.cancel, null).show()
                }
            }
        }
        mKickOutMemberTable.layoutManager = FullyLinearLayoutManager(activity)
        mKickOutMemberTable.adapter = mKickOutMemberTableAdapter

        loadKickOutMembers()
    }


    private fun loadKickOutMembers() {
        presenter.loadKickOutMembers(mGid)
    }

    override fun createPresenter(): KickOutRecordPresenter {
        return KickOutRecordPresenter()
    }

    override fun onTableItemClick(rowIndex: Int, columnIndex: Int) {

    }

    override fun updateKickOutMembers(data: KickOutMembers) {
        mKickOutMembers = data
        mKickOutMemberTableAdapter.data = TableHelper.createKickOutMemberTableData(mKickOutMembers.kickOutMembers)
        mKickOutMemberTableAdapter.notifyDataSetChanged()
    }

    override fun onDestroyView() {
        super.onDestroyView()
        unbinder.unbind()
        EventBus.getDefault().unregister(this)
    }

    @Suppress("UNUSED_PARAMETER")
    @Subscribe
    fun onEvent(event: KickOutChangeEvent) {
    }
}
