package com.weiyoubot.client.feature.main.content.member

import com.weiyoubot.client.R
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.feature.main.UserDataHelper
import com.weiyoubot.client.feature.robots.RobotConstant
import com.weiyoubot.client.model.apikt.ApiClient
import com.weiyoubot.client.model.bean.member.Member
import com.weiyoubot.client.model.bean.userdata.Group
import com.weiyoubot.client.model.loader.OnDataLoadListener

import org.json.JSONException

import android.content.Context
import android.content.DialogInterface
import android.support.v7.app.AlertDialog

import java.util.ArrayList

/**
 * Created by root on 11/15/16.
 */
object MemberHelper {

    fun loadMemberInactive(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        ApiClient.requestMemberInactive(params, listener)
    }

    fun loadMemberInviter(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        ApiClient.requestMemberInviter(params, listener)
    }

    fun loadMemberAll(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        ApiClient.requestMemberAll(params, listener)
    }

    fun deleteMembers(context: Context, gid: String, selectMembers: List<Member>, entry: String, listener: OnDataLoadListener) {
        val usernames = ArrayList<String>()
        for ((username) in selectMembers) {
            usernames.add(username)
        }
        if (Utils.isListEmpty(usernames)) {
            UIUtils.showToast(R.string.member_delete_empty)
            return
        }
        AlertDialog.Builder(context)
                .setTitle(R.string.dialog_title)
                .setMessage(R.string.member_delete_confirm)
                .setPositiveButton(R.string.ok) { _, _ ->
                    try {
                        ApiClient.deleteMembers(gid, usernames, entry, listener)
                    } catch (e: JSONException) {
                        e.printStackTrace()
                    }
                }
                .setNegativeButton(R.string.cancel, null)
                .show()
    }

    fun modifyMemberLevel(gid: String, username: String, level: Int, listener: OnDataLoadListener) {
        try {
            ApiClient.modifyMemberLevel(gid, username, level, listener)
        } catch (e: JSONException) {
            e.printStackTrace()
        }

    }

    fun getSelectMembers(selects: BooleanArray, members: List<Member>): MutableList<Member> {
        val selectMembers = ArrayList<Member>()
        val memberCount = Utils.getListCount(members)
        for (i in 0 until memberCount) {
            if (selects[i + 1]) {
                selectMembers.add(members[i])
            }
        }
        return selectMembers
    }

    fun buildMemberNames(names: Array<String>): String {
        val builder = StringBuilder()
        for (name in names) {
            builder.append(name).append(";")
        }
        if (builder.isNotEmpty()) {
            builder.deleteCharAt(builder.length - 1)
        }
        return builder.toString()
    }

    /**
     * 当前用户能否在该群踢人
     *
     * @param group
     * @return
     */
    fun canKickOut(group: Group): Boolean {
        return group.robotType == RobotConstant.TYPE_PRIVATE && UserDataHelper.isAdmin(group)
    }
}
