package com.weiyoubot.client.feature.main.content.member.all.view

import android.annotation.SuppressLint
import android.os.Bundle
import android.support.v7.app.AlertDialog
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.View.GONE
import android.view.View.VISIBLE
import android.view.ViewGroup
import android.widget.Button
import android.widget.EditText
import android.widget.RadioGroup
import android.widget.ScrollView
import butterknife.BindView
import butterknife.ButterKnife
import butterknife.OnClick
import butterknife.Unbinder
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.fragment.BaseLceFragment
import com.weiyoubot.client.common.table.TableAdapter
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.view.TrialView
import com.weiyoubot.client.common.view.recyclerviewmanager.FullyLinearLayoutManager
import com.weiyoubot.client.feature.main.UserDataConstant
import com.weiyoubot.client.feature.main.content.TableHelper
import com.weiyoubot.client.feature.main.content.member.MemberHelper
import com.weiyoubot.client.feature.main.content.member.all.presenter.MemberAllPresenter
import com.weiyoubot.client.feature.main.menu.MenuConstant
import com.weiyoubot.client.model.api.ApiParamKeys
import com.weiyoubot.client.model.bean.member.Member
import com.weiyoubot.client.model.bean.member.all.MemberAll
import com.weiyoubot.client.model.bean.userdata.Group
import java.util.*

/**
 * Created by root on 11/4/16.
 */
class MemberAllFragment : BaseLceFragment<ScrollView, MemberAll, MemberAllMvpView, MemberAllPresenter>(), MemberAllMvpView, TableAdapter.OnTableItemClickListener {

    private var mCanKickOut: Boolean = false

    private lateinit var mGid: String
    private lateinit var mTableAdapter: TableAdapter
    private lateinit var mMemberAll: MemberAll
    private lateinit var mSearchMembers: List<Member>
    private lateinit var mSelects: BooleanArray
    private lateinit var unbinder: Unbinder

    @BindView(R.id.trial_view)
    lateinit var mTrialView: TrialView
    @BindView(R.id.username_input)
    lateinit var mUsernameInput: EditText
    @BindView(R.id.kick_out_batch)
    lateinit var mKickOutBatch: Button
    @BindView(R.id.member_table)
    lateinit var mMemberTable: RecyclerView

    private val searchMembers: List<Member>
        get() {
            val searchName = mUsernameInput.text.toString()
            val members = arrayListOf<Member>()
            for (member in mMemberAll.members) {
                val name = member.nickname
                if (name.contains(searchName) && member.remove != 1) {
                    members.add(member)
                }
            }
            return members
        }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        val view = inflater.inflate(R.layout.member_all_fragment, container, false)
        unbinder = ButterKnife.bind(this, view)
        return view
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val group = arguments!!.getParcelable<Group>(MenuConstant.INTENT_KEY_GROUP)
        val trial = arguments!!.getBoolean(MenuConstant.INTENT_KEY_TRIAL)
        val permId = arguments!!.getInt(UserDataConstant.INTENT_KEY_PERM_ID)
        mGid = group!!.gid
        mCanKickOut = MemberHelper.canKickOut(group)

        mTableAdapter = TableAdapter(activity)
        mTableAdapter.setOnTableItemClickListener(this)

        mTrialView.initView(group, trial, permId)
        mKickOutBatch.visibility = if (mCanKickOut) VISIBLE else GONE
        mMemberTable.layoutManager = FullyLinearLayoutManager(activity)
        mMemberTable.adapter = mTableAdapter

        loadData(false)
    }

    override fun createPresenter(): MemberAllPresenter {
        return MemberAllPresenter()
    }

    override fun loadData(pullToRefresh: Boolean) {
        val params = HashMap<String, Any>()
        params[ApiParamKeys.GID] = mGid
        presenter.loadData(pullToRefresh, params)
    }

    @OnClick(R.id.search, R.id.kick_out_batch)
    fun onClick(view: View) {
        when (view.id) {
            R.id.search -> setData(mMemberAll)
            R.id.kick_out_batch -> {
                val selectMembers = MemberHelper.getSelectMembers(mSelects, mSearchMembers)
                presenter.deleteMembers(context!!, mGid, selectMembers, ApiParamKeys.ENTRY_VALUE_MEMBER)
            }
        }
    }

    override fun setData(data: MemberAll) {
        mMemberAll = data
        mSearchMembers = searchMembers
        mSelects = BooleanArray(Utils.getListCount(mSearchMembers) + 1)
        mTableAdapter.data = TableHelper.createAllMemberTableData(mSearchMembers, mSelects, mCanKickOut, mMemberAll.modifyLevel)
        mTableAdapter.notifyDataSetChanged()
    }

    @SuppressLint("InflateParams")
    override fun onTableItemClick(rowIndex: Int, columnIndex: Int) {
        if (Utils.isListEmpty(mSearchMembers)) {
            return
        }
        if (columnIndex == 2) {
            mSelects[rowIndex] = !mSelects[rowIndex]
            if (rowIndex == 0) {
                for (i in 1 until mSelects.size) {
                    mSelects[i] = mSelects[0]
                }
            } else {
                var selectedAll = true
                for (i in 1 until mSelects.size) {
                    if (!mSelects[i]) {
                        selectedAll = false
                        break
                    }
                }
                mSelects[0] = selectedAll
            }
            mTableAdapter.data = TableHelper.createAllMemberTableData(mSearchMembers, mSelects, mCanKickOut, mMemberAll.modifyLevel)
            mTableAdapter.notifyDataSetChanged()
        } else if (mMemberAll.modifyLevel == 1 && rowIndex > 0 && columnIndex == 1) {
            val member = mSearchMembers[rowIndex - 1]
            if (member.level == UserDataConstant.LEVEL_GROUP_SENIOR_ADMIN) {
                return
            }
            val view = LayoutInflater.from(activity).inflate(R.layout.member_level_dialog_view, null)
            val radioGroup = view.findViewById(R.id.radio_group) as RadioGroup
            radioGroup.check(if (member.level == UserDataConstant.LEVEL_GROUP_ADMIN || member.level == UserDataConstant.LEVEL_GROUP_UNKNOWN_ADMIN) R.id.member_level_1 else R.id.member_level_2)
            AlertDialog.Builder(context!!).setView(view).setPositiveButton(R.string.ok) { _, _ ->
                val newLevel = if (radioGroup.checkedRadioButtonId == R.id.member_level_1) UserDataConstant.LEVEL_GROUP_ADMIN else UserDataConstant.LEVEL_GROUP_MEMBER
                if (member.level != newLevel) {
                    presenter.modifyMemberLevel(mGid, member, newLevel)
                }
            }.setNegativeButton(R.string.cancel, null).show()
        }
    }

    override fun deleteMembersSuccess(selectMembers: List<Member>) {
        mMemberAll.members.removeAll(selectMembers)
        setData(mMemberAll)
    }

    override fun modifyMemberLevelSuccess(member: Member, level: Int, code: String) {
        member.level = level
        mTableAdapter.data = TableHelper.createAllMemberTableData(mSearchMembers, mSelects, mCanKickOut, mMemberAll.modifyLevel)
        mTableAdapter.notifyDataSetChanged()
    }

    override fun onDestroyView() {
        super.onDestroyView()
        unbinder.unbind()
    }
}
