package com.weiyoubot.client.feature.main.content.member.inactive.view

import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.fragment.BaseLceFragment
import com.weiyoubot.client.common.table.TableAdapter
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.view.TrialView
import com.weiyoubot.client.common.view.recyclerviewmanager.FullyLinearLayoutManager
import com.weiyoubot.client.feature.main.UserDataConstant
import com.weiyoubot.client.feature.main.content.TableHelper
import com.weiyoubot.client.feature.main.content.member.MemberHelper
import com.weiyoubot.client.feature.main.content.member.inactive.presenter.MemberInactivePresenter
import com.weiyoubot.client.feature.main.menu.MenuConstant
import com.weiyoubot.client.model.api.ApiParamKeys
import com.weiyoubot.client.model.bean.member.Member
import com.weiyoubot.client.model.bean.member.inactive.MemberInactive
import com.weiyoubot.client.model.bean.userdata.Group

import android.os.Bundle
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import android.widget.EditText
import android.widget.ScrollView

import java.util.HashMap

import butterknife.BindView
import butterknife.ButterKnife
import butterknife.OnClick
import butterknife.Unbinder

import android.view.View.GONE
import android.view.View.VISIBLE

/**
 * Created by root on 11/4/16.
 */
class MemberInactiveFragment : BaseLceFragment<ScrollView, MemberInactive, MemberInactiveMvpView, MemberInactivePresenter>(), MemberInactiveMvpView, TableAdapter.OnTableItemClickListener {

    private lateinit var mGid: String
    private var mCanKickOut: Boolean = false
    private lateinit var mTableAdapter: TableAdapter
    private lateinit var mMemberInactive: MemberInactive
    private var mSelects: BooleanArray = booleanArrayOf()
    private lateinit var unbinder: Unbinder

    @BindView(R.id.trial_view)
    lateinit var mTrialView: TrialView
    @BindView(R.id.day_count_input)
    lateinit var mDayCountInput: EditText
    @BindView(R.id.kick_out_batch)
    lateinit var mKickOutBatch: Button
    @BindView(R.id.member_table)
    lateinit var mMemberTable: RecyclerView

    override fun onCreateView(inflater: LayoutInflater?, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        val view = inflater!!.inflate(R.layout.member_inactive_fragment, container, false)
        unbinder = ButterKnife.bind(this, view)
        return view
    }

    override fun onViewCreated(view: View?, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val group = arguments.getParcelable<Group>(MenuConstant.INTENT_KEY_GROUP)
        val trial = arguments.getBoolean(MenuConstant.INTENT_KEY_TRIAL)
        val permId = arguments.getInt(UserDataConstant.INTENT_KEY_PERM_ID)
        mGid = group!!.gid
        mCanKickOut = MemberHelper.canKickOut(group)

        mTableAdapter = TableAdapter(activity)
        mTableAdapter.setOnTableItemClickListener(this)

        mTrialView.initView(group, trial, permId)
        mKickOutBatch.visibility = if (mCanKickOut) VISIBLE else GONE
        mDayCountInput.setText("1")
        mMemberTable.layoutManager = FullyLinearLayoutManager(activity)
        mMemberTable.adapter = mTableAdapter

        loadData(false)
    }

    override fun createPresenter(): MemberInactivePresenter {
        return MemberInactivePresenter()
    }

    @OnClick(R.id.query, R.id.kick_out_batch)
    fun onClick(view: View) {
        when (view.id) {
            R.id.query -> loadData(true)
            R.id.kick_out_batch -> {
                val selectMembers = MemberHelper.getSelectMembers(mSelects, mMemberInactive.data)
                presenter.deleteMembers(activity, mGid, selectMembers, ApiParamKeys.ENTRY_VALUE_INACTIVE)
            }
        }
    }

    override fun deleteMembersSuccess(selectMembers: List<Member>) {
        mMemberInactive.data.removeAll(selectMembers)
        setData(mMemberInactive)
    }

    override fun loadData(pullToRefresh: Boolean) {
        val params = HashMap<String, Any>()
        params[ApiParamKeys.GID] = mGid
        try {
            val dayCount = Integer.parseInt(mDayCountInput.text.toString())
            params[ApiParamKeys.DAY] = dayCount
            presenter.loadData(pullToRefresh, params)
        } catch (e: Exception) {
            e.printStackTrace()
            UIUtils.showToast(R.string.member_inactive_day_input_error)
        }

    }

    override fun setData(data: MemberInactive) {
        mMemberInactive = data
        mSelects = BooleanArray(Utils.getListCount(mMemberInactive.data) + 1)
        mTableAdapter.data = TableHelper.createInactiveMemberTableData(mMemberInactive.data, mSelects, mCanKickOut)
        mTableAdapter.notifyDataSetChanged()
    }

    override fun onTableItemClick(rowIndex: Int, columnIndex: Int) {
        if (Utils.isListEmpty(mMemberInactive.data)) {
            return
        }
        if (columnIndex == 2) {
            mSelects[rowIndex] = !mSelects[rowIndex]
            if (rowIndex == 0) {
                for (i in 1 until mSelects.size) {
                    mSelects[i] = mSelects[0]
                }
            } else {
                var selectedAll = true
                for (i in 1 until mSelects.size) {
                    if (!mSelects[i]) {
                        selectedAll = false
                        break
                    }
                }
                mSelects[0] = selectedAll
            }
            mTableAdapter.data = TableHelper.createInactiveMemberTableData(mMemberInactive.data, mSelects, mCanKickOut)
            mTableAdapter.notifyDataSetChanged()
        }
    }

    override fun onDestroyView() {
        super.onDestroyView()
        unbinder.unbind()
    }
}
