package com.weiyoubot.client.feature.main.content.member.inviter.view

import android.app.DatePickerDialog
import android.os.Bundle
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ScrollView
import android.widget.TextView
import butterknife.BindView
import butterknife.ButterKnife
import butterknife.OnClick
import butterknife.Unbinder
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.fragment.BaseLceFragment
import com.weiyoubot.client.common.table.TableAdapter
import com.weiyoubot.client.common.utils.DateUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.view.TrialView
import com.weiyoubot.client.common.view.recyclerviewmanager.FullyLinearLayoutManager
import com.weiyoubot.client.feature.main.UserDataConstant
import com.weiyoubot.client.feature.main.content.TableHelper
import com.weiyoubot.client.feature.main.content.member.inviter.presenter.MemberInviterPresenter
import com.weiyoubot.client.feature.main.menu.MenuConstant
import com.weiyoubot.client.model.api.ApiParamKeys
import com.weiyoubot.client.model.bean.member.inviter.MemberInviter
import com.weiyoubot.client.model.bean.userdata.Group
import java.util.*

/**
 * Created by root on 11/4/16.
 */
class MemberInviterFragment : BaseLceFragment<ScrollView, MemberInviter, MemberInviterMvpView, MemberInviterPresenter>(), MemberInviterMvpView, TableAdapter.OnTableItemClickListener {

    private lateinit var mGid: String
    private var mStartTime: Long = 0 // 开始时间
    private var mEndTime: Long = 0  // 结束时间

    private lateinit var mTableAdapter: TableAdapter
    private lateinit var mMemberInviter: MemberInviter
    private lateinit var mExpends: BooleanArray
    private lateinit var unbinder: Unbinder

    @BindView(R.id.trial_view)
    lateinit var mTrialView: TrialView
    @BindView(R.id.start_date)
    lateinit var mStartDate: TextView
    @BindView(R.id.end_date)
    lateinit var mEndDate: TextView
    @BindView(R.id.member_table)
    lateinit var mMemberTable: RecyclerView

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        val view = inflater.inflate(R.layout.member_inviter_fragment, container, false)
        unbinder = ButterKnife.bind(this, view)
        return view
    }

    override fun onViewCreated(view: View?, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val group = arguments.getParcelable<Group>(MenuConstant.INTENT_KEY_GROUP)
        val trial = arguments.getBoolean(MenuConstant.INTENT_KEY_TRIAL)
        val permId = arguments.getInt(UserDataConstant.INTENT_KEY_PERM_ID)
        mGid = group!!.gid

        val today = DateUtils.getToadyTimeInMillis() / 1000 // 当天0点，以秒为单位
        mStartTime = today - 6 * DateUtils.ONE_DAY_SECONDS
        mStartDate.text = formatDate(mStartTime * 1000)
        mEndTime = today
        mEndDate.text = formatDate(mEndTime * 1000)

        mTableAdapter = TableAdapter(activity)
        mTableAdapter.setOnTableItemClickListener(this)

        mTrialView.initView(group, trial, permId)
        mMemberTable.layoutManager = FullyLinearLayoutManager(activity)
        mMemberTable.adapter = mTableAdapter

        loadData(false)
    }

    private fun formatDate(timeInMillis: Long): String {
        return DateUtils.formatDate("yyyy/MM/dd", timeInMillis)
    }

    override fun createPresenter(): MemberInviterPresenter {
        return MemberInviterPresenter()
    }

    @OnClick(R.id.start_date, R.id.end_date, R.id.query)
    fun onClick(view: View) {
        val calendar = DateUtils.getCalendar()
        when (view.id) {
            R.id.start_date -> {
                calendar.timeInMillis = mStartTime * 1000
                val startDatePickerDialog = DatePickerDialog(activity, DatePickerDialog.OnDateSetListener { _, year, monthOfYear, dayOfMonth ->
                    calendar.set(Calendar.YEAR, year)
                    calendar.set(Calendar.MONTH, monthOfYear)
                    calendar.set(Calendar.DAY_OF_MONTH, dayOfMonth)
                    mStartTime = calendar.timeInMillis / 1000
                    mStartDate.text = formatDate(mStartTime * 1000)

                    calendar.add(Calendar.MONTH, 1)
                    mEndTime = Math.max(mStartTime, mEndTime)
                    mEndTime = Math.min(mEndTime, calendar.timeInMillis / 1000)
                    mEndDate.text = formatDate(mEndTime * 1000)
                }, calendar.get(Calendar.YEAR), calendar.get(Calendar.MONTH), calendar.get(Calendar.DAY_OF_MONTH))
                // 最大日期为当天0点
                startDatePickerDialog.datePicker.maxDate = DateUtils.getToadyTimeInMillis()
                startDatePickerDialog.show()
            }
            R.id.end_date -> {
                calendar.timeInMillis = mEndTime * 1000
                val endDatePickerDialog = DatePickerDialog(activity, DatePickerDialog.OnDateSetListener { _, year, monthOfYear, dayOfMonth ->
                    calendar.set(Calendar.YEAR, year)
                    calendar.set(Calendar.MONTH, monthOfYear)
                    calendar.set(Calendar.DAY_OF_MONTH, dayOfMonth)
                    mEndTime = calendar.timeInMillis / 1000
                    mEndDate.text = formatDate(mEndTime * 1000)
                }, calendar.get(Calendar.YEAR), calendar.get(Calendar.MONTH), calendar.get(Calendar.DAY_OF_MONTH))
                // 最小日期为起始时间，最大日期为 当天0点或起始时间之后一个月 的最小值
                DateUtils.initEndDateMaxMinDate(endDatePickerDialog.datePicker, mStartTime * 1000, DateUtils.getToadyTimeInMillis())
                endDatePickerDialog.show()
            }
            R.id.query -> loadData(true)
        }
    }

    override fun loadData(pullToRefresh: Boolean) {
        val params = HashMap<String, Any>()
        params[ApiParamKeys.GID] = mGid
        params[ApiParamKeys.START] = DateUtils.toUTCTimeInSecond(mStartTime)
        params[ApiParamKeys.END] = DateUtils.toUTCTimeInSecond(mEndTime)
        presenter.loadData(pullToRefresh, params)
    }

    override fun setData(data: MemberInviter) {
        mMemberInviter = data
        mExpends = BooleanArray(Utils.getListCount(mMemberInviter.result))
        mTableAdapter.data = TableHelper.createInviterMemberTableData(mMemberInviter.result, mExpends)
        mTableAdapter.notifyDataSetChanged()
    }

    override fun onDestroyView() {
        super.onDestroyView()
        unbinder.unbind()
    }

    override fun onTableItemClick(rowIndex: Int, columnIndex: Int) {
        if (Utils.isListEmpty(mMemberInviter.result)) {
            return
        }
        if (rowIndex > 0 && (columnIndex == 1 || columnIndex == 2)) {
            mExpends[rowIndex - 1] = !mExpends[rowIndex - 1]
            mTableAdapter.data = TableHelper.createInviterMemberTableData(mMemberInviter.result, mExpends)
            mTableAdapter.notifyDataSetChanged()
        }
    }
}
