package com.weiyoubot.client.feature.main.content.reply.view

import android.annotation.SuppressLint
import android.content.Context
import android.content.Intent
import android.graphics.drawable.AnimationDrawable
import android.net.Uri
import android.support.v4.content.ContextCompat.startActivity
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.widget.LinearLayout
import com.weiyoubot.client.R
import com.weiyoubot.client.common.utils.ImageUtils
import com.weiyoubot.client.common.utils.MediaPlayerManager
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.feature.main.content.reply.ReplyConstant
import com.weiyoubot.client.feature.main.content.reply.edit.respedit.RespHelper
import com.weiyoubot.client.model.bean.reply.Resp
import kotlinx.android.synthetic.main.reply_resp_container_view.view.*
import kotlinx.android.synthetic.main.reply_resp_view.view.*
import java.io.IOException


/**
 * Created by root on 11/25/16.
 */
class ReplyRespContainerView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : LinearLayout(context, attrs, defStyleAttr) {

    private val mediaPlayerManager = MediaPlayerManager.INSTANCE
    private var playingDrawable: AnimationDrawable? = null

    val atBackChecked: Boolean
        get() = at_back.isChecked

    init {
        LayoutInflater.from(context).inflate(R.layout.reply_resp_container_view, this)
        orientation = LinearLayout.VERTICAL
        setBackgroundColor(Utils.getColor(R.color.common_color_ee))

        val addDrawableSize = Utils.getDimen(R.dimen.x24)
        val addDrawable = Utils.getDrawable(R.drawable.add)
        addDrawable.setBounds(0, 0, addDrawableSize, addDrawableSize)
        resp_add.setCompoundDrawables(addDrawable, null, null, null)
    }

    @SuppressLint("InflateParams", "SetTextI18n")
    @JvmOverloads
    fun initRespDisplayContainer(resps: List<Resp>, editable: Boolean, listener: View.OnClickListener?, respCountLimit: Int = 2) {
        resp_count_limit.text = Utils.getString(R.string.reply_resp_title, respCountLimit)
        val respCount = Utils.getListCount(resps)
        if (editable) {
            resp_add.visibility = View.VISIBLE
            resp_add.isEnabled = respCount < respCountLimit
            resp_add.alpha = if (respCount < respCountLimit) 1f else 0.54f
            resp_add.setOnClickListener(listener)
        } else {
            resp_add.visibility = View.GONE
        }
        resp_display_container.removeAllViews()
        for (i in 0 until respCount) {
            val resp = resps[i]
            val respView = LayoutInflater.from(context).inflate(R.layout.reply_resp_view, null)
            when (RespHelper.getRespType(resp)) {
                ReplyConstant.RESP_TYPE_TEXT -> {
                    respView.resp_text.visibility = View.VISIBLE
                    respView.resp_image.visibility = View.GONE
                    respView.resp_voice.visibility = View.GONE
                    respView.resp_card.visibility = View.GONE
                    respView.resp_video.visibility = View.GONE
                    respView.resp_text.setSingleLine(false)
                    respView.resp_text.text = resp.content
                }
                ReplyConstant.RESP_TYPE_PIC -> {
                    respView.resp_text.visibility = View.GONE
                    respView.resp_image.visibility = View.VISIBLE
                    respView.resp_voice.visibility = View.GONE
                    respView.resp_card.visibility = View.GONE
                    respView.resp_video.visibility = View.GONE
                    ImageUtils.setImage(context, respView.resp_image, resp.content)
                }
                ReplyConstant.RESP_TYPE_APP_MSG -> {
                    respView.resp_text.visibility = View.VISIBLE
                    respView.resp_image.visibility = View.GONE
                    respView.resp_voice.visibility = View.GONE
                    respView.resp_card.visibility = View.GONE
                    respView.resp_video.visibility = View.GONE
                    respView.resp_text.text = "(图文链接)" + resp.content
                }
                ReplyConstant.RESP_TYPE_MINI_PROGRAM -> {
                    respView.resp_text.visibility = View.VISIBLE
                    respView.resp_image.visibility = View.GONE
                    respView.resp_voice.visibility = View.GONE
                    respView.resp_card.visibility = View.GONE
                    respView.resp_video.visibility = View.GONE
                    respView.resp_text.text = "(小程序)" + resp.content
                }
                ReplyConstant.RESP_TYPE_APP_ATTACH -> {
                    respView.resp_text.visibility = View.VISIBLE
                    respView.resp_image.visibility = View.GONE
                    respView.resp_voice.visibility = View.GONE
                    respView.resp_card.visibility = View.GONE
                    respView.resp_video.visibility = View.GONE
                    respView.resp_text.text = "(文件)" + resp.content
                }
                ReplyConstant.RESP_TYPE_VOICE -> {
                    respView.resp_text.visibility = View.GONE
                    respView.resp_image.visibility = View.GONE
                    respView.resp_voice.visibility = View.VISIBLE
                    respView.resp_card.visibility = View.GONE
                    respView.resp_video.visibility = View.GONE
                    respView.resp_voice.voice_icon.setBackgroundResource(R.drawable.material_voice_icon_animation)
                    respView.size.text = resp.size.toString() + "″"
                    respView.title.text = resp.content
                    respView.resp_voice.voice_box.setOnClickListener { _ ->
                        val animationDrawable = respView.resp_voice.voice_icon.background as AnimationDrawable
                        if (animationDrawable.isRunning) {
                            animationDrawable.stop()
                            animationDrawable.selectDrawable(0)
                            mediaPlayerManager.stopMedia()
                        } else {
                            if (playingDrawable != null) {
                                playingDrawable!!.stop()
                                playingDrawable!!.selectDrawable(0)
                            }
                            animationDrawable.start()
                            playingDrawable = animationDrawable
                            try {
                                mediaPlayerManager.playMedia(resp.url) {
                                    if (playingDrawable != null) {
                                        playingDrawable!!.stop()
                                        playingDrawable!!.selectDrawable(0)
                                    }
                                }
                            } catch (e: IOException) {
                                e.printStackTrace()
                            }

                        }
                    }
                }
                ReplyConstant.RESP_TYPE_CARD -> {
                    respView.resp_text.visibility = View.GONE
                    respView.resp_image.visibility = View.GONE
                    respView.resp_voice.visibility = View.GONE
                    respView.resp_card.visibility = View.VISIBLE
                    respView.resp_video.visibility = View.GONE
                    respView.resp_card.type_image.setBackgroundResource(if (resp.cardType == ReplyConstant.CARD_PERSONAL) R.drawable.ic_card_person_photo else R.drawable.ic_card_subscription_photo)
                    respView.resp_card.name.text = resp.content
                    respView.resp_card.type.text = Utils.getString(if (resp.cardType == ReplyConstant.CARD_PERSONAL) R.string.reply_resp_edit_personal_card else R.string.reply_resp_edit_subscription_card)
                }
                ReplyConstant.RESP_TYPE_VIDEO -> {
                    respView.resp_text.visibility = View.GONE
                    respView.resp_image.visibility = View.GONE
                    respView.resp_voice.visibility = View.GONE
                    respView.resp_card.visibility = View.GONE
                    respView.resp_video.visibility = View.VISIBLE
                    ImageUtils.setImage(context, respView.resp_video.resp_video_image, resp.thumb)
                    respView.resp_video.play.setOnClickListener {
                        val intent = Intent(Intent.ACTION_VIEW)
                        intent.setDataAndType(Uri.parse(resp.url), "video/mp4")
                        startActivity(context, intent, null)
                    }
                }
                else -> {
                    respView.resp_text.visibility = View.VISIBLE
                    respView.resp_image.visibility = View.GONE
                    respView.resp_text.setSingleLine(false)
                    respView.resp_text.text = resp.content
                }
            }
            val actionContainer = respView.findViewById<View>(R.id.action_container)
            if (editable) {
                actionContainer.visibility = View.VISIBLE
                val respEditView = respView.findViewById<View>(R.id.resp_edit)
                respEditView.setTag(R.id.reply_tag_index, i)
                respEditView.setOnClickListener(listener)
                val respDeleteView = respView.findViewById<View>(R.id.resp_delete)
                respDeleteView.setTag(R.id.reply_tag_index, i)
                respDeleteView.setOnClickListener(listener)
            } else {
                actionContainer.visibility = View.GONE
            }
            respView.findViewById<View>(R.id.divider).visibility = if (i == respCount - 1) View.GONE else View.VISIBLE
            resp_display_container.addView(respView)
        }
    }

    fun enableAtBack(isAtBack: Boolean) {
        at_back.visibility = View.VISIBLE
        at_back.isChecked = isAtBack
    }
}
