package com.weiyoubot.client.feature.main.content.smartchat.presenter

import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.BaseLcePresenter
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.feature.main.content.smartchat.bean.SmartChatReply
import com.weiyoubot.client.feature.main.content.smartchat.view.SmartChatMvpView
import com.weiyoubot.client.model.api.ApiClient
import com.weiyoubot.client.model.api.ApiParamKeys
import com.weiyoubot.client.model.bean.settings.SmartChat
import com.weiyoubot.client.model.loader.OnDataLoadListener

import org.json.JSONException

/**
 * Created by root on 11/8/16.
 */
class SmartChatPresenter : BaseLcePresenter<SmartChat, SmartChatMvpView>() {

    override fun loadData(pullToRefresh: Boolean, params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        ApiClient.requestSmartChat(params, listener)
    }

    fun setSmartChat(gid: String, smartChatReply: SmartChatReply) {
        val smartChat = smartChatReply.newSmartChat
        try {
            ApiClient.setSmartChat(gid, smartChat.status, smartChat.startTime, smartChat.endTime, object : OnDataLoadListener {
                override fun onDataLoaded(data: Any) {
                    ifViewAttached { view ->
                        smartChatReply.expand = false
                        view.setSmartChatSuccess()
                    }
                }

                override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                    ifViewAttached {
                        var msgId = R.string.reply_save_failed
                        if (smartChatReply.oldSmartChat.status != smartChatReply.newSmartChat.status) {
                            msgId = if (smartChatReply.newSmartChat.status == 1) R.string.reply_switch_on_failed else R.string.reply_switch_off_failed
                            smartChatReply.newSmartChat.status = smartChatReply.oldSmartChat.status
                        }
                        UIUtils.showFailedToast(msgId, errorMessage)
                    }
                }
            })
        } catch (e: JSONException) {
            e.printStackTrace()
        }
    }

    fun syncReply(gid: String, grouping: Boolean) {
        try {
            ApiClient.syncReply(gid, grouping, ApiParamKeys.SYNC_TYPE_VALUE_SMARTCHAT, null, object : OnDataLoadListener {
                override fun onDataLoaded(data: Any) {
                    ifViewAttached { UIUtils.showToast(R.string.reply_sync_success) }
                }

                override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                    ifViewAttached { UIUtils.showFailedToast(R.string.reply_sync_failed, errorMessage) }
                }
            })
        } catch (e: JSONException) {
            e.printStackTrace()
        }

    }
}
