package com.weiyoubot.client.feature.main.content.smartchat.view

import android.app.TimePickerDialog
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.View.GONE
import android.view.View.VISIBLE
import android.view.ViewGroup
import android.widget.*
import butterknife.BindView
import butterknife.ButterKnife
import butterknife.OnClick
import butterknife.Unbinder
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.fragment.BaseLceFragment
import com.weiyoubot.client.common.utils.DateUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.utils.setTextHTML
import com.weiyoubot.client.common.view.TrialView
import com.weiyoubot.client.feature.main.UserDataConstant
import com.weiyoubot.client.feature.main.content.smartchat.bean.SmartChatReply
import com.weiyoubot.client.feature.main.content.smartchat.presenter.SmartChatPresenter
import com.weiyoubot.client.feature.main.menu.MenuConstant
import com.weiyoubot.client.model.api.ApiParamKeys
import com.weiyoubot.client.model.bean.settings.SmartChat
import com.weiyoubot.client.model.bean.userdata.Group
import java.util.*

/**
 * Created by root on 10/31/16.
 */
class SmartChatFragment : BaseLceFragment<ScrollView, SmartChat, SmartChatMvpView, SmartChatPresenter>(), SmartChatMvpView {

    private lateinit var mGid: String
    private lateinit var mSmartChatReply: SmartChatReply
    private lateinit var unbinder: Unbinder

    @BindView(R.id.trial_view)
    lateinit var mTrialView: TrialView
    @BindView(R.id.label)
    lateinit var mLabel: TextView
    @BindView(R.id.action_container)
    lateinit var mActionContainer: LinearLayout
    @BindView(R.id.switch_view)
    lateinit var mSwitchView: ImageView
    @BindView(R.id.edit)
    lateinit var mEdit: ImageView
    @BindView(R.id.delete)
    lateinit var mDelete: ImageView
    @BindView(R.id.edit_container)
    lateinit var mEditContainer: LinearLayout
    @BindView(R.id.start_time)
    lateinit var mStartTime: TextView
    @BindView(R.id.end_time)
    lateinit var mEndTime: TextView
    @BindView(R.id.open_button)
    lateinit var mOpenButton: Button
    @BindView(R.id.delete_button)
    lateinit var mDeleteButton: Button
    @BindView(R.id.time)
    lateinit var mTime: TextView
    @BindView(R.id.description)
    lateinit var mDescription: TextView
    @BindView(R.id.sync_layout)
    lateinit var mSyncLayout: LinearLayout

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        val view = inflater.inflate(R.layout.smart_chat_fragment, container, false)
        unbinder = ButterKnife.bind(this, view)
        return view
    }

    override fun onViewCreated(view: View?, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val group = arguments.getParcelable<Group>(MenuConstant.INTENT_KEY_GROUP)
        val trial = arguments.getBoolean(MenuConstant.INTENT_KEY_TRIAL)
        val permId = arguments.getInt(UserDataConstant.INTENT_KEY_PERM_ID)
        mGid = group!!.gid

        mTrialView.initView(group, trial, permId)

        mLabel.setText(R.string.smart_chat_title)
        mDelete.visibility = GONE
        mDeleteButton.visibility = GONE
        mDescription.setTextHTML(Utils.getString(R.string.smart_chat_description))

        loadData(false)
    }

    override fun createPresenter(): SmartChatPresenter {
        return SmartChatPresenter()
    }

    override fun loadData(pullToRefresh: Boolean) {
        val params = HashMap<String, Any>()
        params[ApiParamKeys.GID] = mGid
        presenter.loadData(pullToRefresh, params)
    }

    override fun setData(data: SmartChat) {
        mSmartChatReply = SmartChatReply(oldSmartChat = data, newSmartChat = data.copy())
        updateView()
    }

    private fun updateView() {
        mActionContainer.visibility = if (mSmartChatReply.expand) GONE else VISIBLE
        mSwitchView.setImageResource(if (mSmartChatReply.newSmartChat.status == 1) R.drawable.switch_round_on else R.drawable.switch_round_off)
        mEditContainer.visibility = if (mSmartChatReply.expand) VISIBLE else GONE
        mStartTime.text = DateUtils.formatTime(mSmartChatReply.newSmartChat.startTime)
        mEndTime.text = DateUtils.formatTime(mSmartChatReply.newSmartChat.endTime)
        mOpenButton.visibility = if (mSmartChatReply.newSmartChat.status == 1) GONE else VISIBLE
        mTime.visibility = if (mSmartChatReply.expand) GONE else VISIBLE
        mSyncLayout.visibility = if (mSmartChatReply.expand) GONE else VISIBLE
        mTime.text = Utils.getString(R.string.smart_chat_detail, DateUtils.formatTime(mSmartChatReply.newSmartChat.startTime), DateUtils.formatTime(mSmartChatReply.newSmartChat.endTime))
    }

    @OnClick(R.id.switch_view, R.id.edit, R.id.start_time_select, R.id.end_time_select, R.id.open_button, R.id.save_button, R.id.cancel_button, R.id.sync_grouping, R.id.sync)
    fun onClick(view: View) {
        when (view.id) {
            R.id.switch_view -> {
                mSmartChatReply.newSmartChat.status = if (mSmartChatReply.newSmartChat.status == 1) 0 else 1
                presenter.setSmartChat(mGid, mSmartChatReply)
            }
            R.id.edit -> {
                mSmartChatReply.expand = true
                updateView()
            }
            R.id.start_time_select -> {
                val startTime = DateUtils.formatTime(mSmartChatReply.newSmartChat.startTime)
                val startTimeSplit = startTime.split(":".toRegex()).dropLastWhile { it.isEmpty() }.toTypedArray()
                val startTimePickerDialog = TimePickerDialog(context, TimePickerDialog.OnTimeSetListener { _, hourOfDay, minute ->
                    mSmartChatReply.newSmartChat.startTime = DateUtils.getTimeInSecond(hourOfDay, minute)
                    mStartTime.text = DateUtils.formatTime(mSmartChatReply.newSmartChat.startTime)

                    mSmartChatReply.newSmartChat.endTime = Math.max(mSmartChatReply.newSmartChat.startTime, mSmartChatReply.newSmartChat.endTime)
                    mEndTime.text = DateUtils.formatTime(mSmartChatReply.newSmartChat.endTime)
                }, Integer.valueOf(startTimeSplit[0]), Integer.valueOf(startTimeSplit[1]), true)
                startTimePickerDialog.show()
            }
            R.id.end_time_select -> {
                val endTime = DateUtils.formatTime(mSmartChatReply.newSmartChat.endTime)
                val endTimeSplit = endTime.split(":".toRegex()).dropLastWhile { it.isEmpty() }.toTypedArray()
                val endTimePickerDialog = TimePickerDialog(context, TimePickerDialog.OnTimeSetListener { _, hourOfDay, minute ->
                    mSmartChatReply.newSmartChat.endTime = Math.max(mSmartChatReply.newSmartChat.startTime, DateUtils.getTimeInSecond(hourOfDay, minute))
                    mEndTime.text = DateUtils.formatTime(mSmartChatReply.newSmartChat.endTime)
                }, Integer.valueOf(endTimeSplit[0]), Integer.valueOf(endTimeSplit[1]), true)
                endTimePickerDialog.show()
            }
            R.id.open_button -> {
                mSmartChatReply.newSmartChat.status = 1
                presenter.setSmartChat(mGid, mSmartChatReply)
            }
            R.id.save_button -> presenter.setSmartChat(mGid, mSmartChatReply)
            R.id.cancel_button -> {
                mSmartChatReply.newSmartChat = mSmartChatReply.oldSmartChat.copy()
                mSmartChatReply.expand = false
                updateView()
            }
            R.id.sync_grouping -> presenter.syncReply(mGid, true)
            R.id.sync -> presenter.syncReply(mGid, false)
        }
    }

    override fun setSmartChatSuccess() {
        mSmartChatReply.oldSmartChat = mSmartChatReply.newSmartChat.copy()
        updateView()
    }

    override fun onDestroyView() {
        super.onDestroyView()
        unbinder.unbind()
    }
}
