package com.weiyoubot.client.feature.main.content.statistics

import android.content.Context
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.util.TypedValue
import android.widget.TextView
import com.github.mikephil.charting.charts.HorizontalBarChart
import com.github.mikephil.charting.components.XAxis
import com.github.mikephil.charting.data.BarData
import com.github.mikephil.charting.data.BarDataSet
import com.github.mikephil.charting.data.BarEntry
import com.github.mikephil.charting.formatter.IAxisValueFormatter
import com.github.mikephil.charting.formatter.IValueFormatter
import com.github.mikephil.charting.interfaces.datasets.IBarDataSet
import com.weiyoubot.client.R
import com.weiyoubot.client.common.utils.DateUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.view.WrapLinearLayout
import com.weiyoubot.client.model.bean.statistics.all.HealthDetail
import com.weiyoubot.client.model.bean.statistics.all.Type
import com.weiyoubot.client.model.bean.statistics.history.ChartData
import com.weiyoubot.client.model.bean.statistics.history.PointData
import lecho.lib.hellocharts.model.*
import lecho.lib.hellocharts.view.ColumnChartView
import lecho.lib.hellocharts.view.LineChartView
import lecho.lib.hellocharts.view.PieChartView
import java.util.*

/**
 * Created by root on 11/3/16.
 */
object ChartHelper {

    private var mLastHealthEntryX = -1 // 用于获取体检中的水平柱状图的label

    private val mColorResIds = Utils.getResIdsFromArray(R.array.pie_chart_colors)
    private val mTextColor = Utils.getColor(R.color.common_color_9a)
    private val mTextSize = Utils.getDimen(R.dimen.x24)
    private val mLegendColorBlockSize = Utils.getDimen(R.dimen.x24)
    private val mLegendColorBlockPadding = Utils.getDimen(R.dimen.x8)

    fun initAllHealthPieChart(score: Float, pieChartView: PieChartView) {
        val sliceValues = ArrayList<SliceValue>()
        sliceValues.add(SliceValue(score, Utils.getColor(R.color.common_blue_color)))
        sliceValues.add(SliceValue(100 - score, Utils.getColor(R.color.common_blue_color_alpha_60)))

        val pieChartData = PieChartData()
        pieChartData.values = sliceValues
        pieChartData.slicesSpacing = 0
        pieChartData.setHasCenterCircle(true)
        pieChartData.centerCircleColor = Utils.getColor(R.color.common_blue_color_alpha_40)
        pieChartData.centerCircleScale = 0.87f
        pieChartData.centerText1 = score.toInt().toString()
        pieChartData.centerText1Color = Color.WHITE
        pieChartData.centerText1FontSize = Utils.getDimen(R.dimen.x70)

        pieChartView.pieChartData = pieChartData
        pieChartView.isChartRotationEnabled = false
        pieChartView.setChartRotation(-90, false)
        pieChartView.isValueTouchEnabled = false
    }

    fun initAllHealthHorizontalBarChart(healthDetails: List<HealthDetail>, horizontalBarChart: HorizontalBarChart) {
        val barEntries = ArrayList<BarEntry>()
        val healthDetailCount = Utils.getListCount(healthDetails)
        for (i in 0 until healthDetailCount) {
            // 之所以是healthDetailCount - 1 - i是为了将前面的数据显示在表格上端，所以取的时候要倒过来
            val healthDetail = healthDetails[healthDetailCount - 1 - i]
            // 每条数据分成两段绘制：实际分数 和 总分-实际分数
            val barEntry = BarEntry(i.toFloat(), floatArrayOf(healthDetail.score, healthDetail.fscore - healthDetail.score), Utils.getString(R.string.statistics_health_horizontal_bar_chart_label, healthDetail.score.toInt(), healthDetail.fscore.toInt()))
            barEntries.add(barEntry)
        }
        val barDataSet = BarDataSet(barEntries, null)
        // 两段的对应颜色
        barDataSet.setColors(Utils.getColor(R.color.common_blue_color), Utils.getColor(R.color.common_color_ee))
        barDataSet.valueTextColor = mTextColor
        barDataSet.valueFormatter = IValueFormatter { _, entry, _, _ ->
            // 第一段数据不返回label，第二段才返回
            if (entry.x == mLastHealthEntryX.toFloat()) {
                return@IValueFormatter entry.data.toString()
            }
            mLastHealthEntryX = entry.x.toInt()
            ""
        }
        val barDataSets = ArrayList<IBarDataSet>()
        barDataSets.add(barDataSet)
        val barData = BarData(barDataSets)
        barData.barWidth = 0.25f
        horizontalBarChart.data = barData

        val xAxis = horizontalBarChart.xAxis
        xAxis.setDrawAxisLine(false)
        xAxis.setDrawGridLines(false)
        xAxis.position = XAxis.XAxisPosition.BOTTOM
        xAxis.labelCount = healthDetailCount
        xAxis.textColor = mTextColor
        xAxis.valueFormatter = IAxisValueFormatter { value, _ ->
            // 之所以是healthDetailCount - 1 - i是为了将前面的数据显示在表格上端，所以取的时候要倒过来
            healthDetails[healthDetailCount - 1 - value.toInt()].name
        }

        val axisLeft = horizontalBarChart.axisLeft
        axisLeft.isEnabled = false
        // 虽然禁止了，但首尾坐标还是要跟axisRight设置成一样的，否则绘制的位置有问题
        axisLeft.axisMinimum = 0f
        axisLeft.axisMaximum = 25f

        val axisRight = horizontalBarChart.axisRight
        axisRight.axisMinimum = 0f
        axisRight.axisMaximum = 25f
        axisRight.granularity = 5f
        axisRight.textColor = mTextColor

        horizontalBarChart.description = null
        horizontalBarChart.setTouchEnabled(false)
        horizontalBarChart.legend.isEnabled = false
    }

    fun initAllTypesPieChart(context: Context, types: List<Type>, legendContainer: WrapLinearLayout, pieChartView: PieChartView) {
        val sliceValues = ArrayList<SliceValue>()
        legendContainer.removeAllViews()
        val typeCount = Utils.getListCount(types)
        for (i in 0 until typeCount) {
            val type = types[i]
            val color = Utils.getColor(mColorResIds[i])

            // 添加图例
            val legendView = TextView(context)
            legendView.text = type.type
            val colorBlock = ColorDrawable(color)
            colorBlock.setBounds(0, 0, mLegendColorBlockSize, mLegendColorBlockSize)
            legendView.setCompoundDrawables(colorBlock, null, null, null)
            legendView.compoundDrawablePadding = mLegendColorBlockPadding
            legendView.setTextColor(mTextColor)
            legendView.setTextSize(TypedValue.COMPLEX_UNIT_PX, mTextSize.toFloat())
            legendContainer.addView(legendView)

            if (type.percentage == 0f) {
                continue
            }

            // 添加饼图数据
            val sliceValue = SliceValue()
            sliceValue.setLabel(Utils.getPercentageText(type.percentage))
            sliceValue.value = type.percentage
            sliceValue.color = color
            sliceValues.add(sliceValue)
        }
        if (Utils.isListEmpty(sliceValues)) {
            val value = SliceValue()
            value.setLabel(Utils.getString(R.string.data_empty))
            value.value = 100f
            value.color = Utils.getColor(mColorResIds[0])
            sliceValues.add(value)
        }

        val pieChartData = PieChartData()
        pieChartData.values = sliceValues
        pieChartData.setHasLabels(true)
        pieChartData.isValueLabelBackgroundEnabled = false
        pieChartView.pieChartData = pieChartData
        pieChartView.isChartRotationEnabled = false
        pieChartView.setChartRotation(-90, false)
        pieChartView.isValueSelectionEnabled = true
        pieChartView.isZoomEnabled = false
        pieChartView.isScrollEnabled = false
    }

    /**
     * 活跃时段的柱状图
     *
     * @param activeTime
     * @param columnChartView
     */
    fun initActiveTimeColumnChart(activeTime: IntArray, columnChartView: ColumnChartView) {
        val activeTimeCount = activeTime.size
        val columns = ArrayList<Column>()
        val axisXValues = ArrayList<AxisValue>()
        val axisYValues = ArrayList<AxisValue>()
        var top = Integer.MIN_VALUE
        for (i in 0 until activeTimeCount) {
            val value = activeTime[i]
            top = Math.max(top, value)
            val values = ArrayList<SubcolumnValue>()
            val subColumnValue = SubcolumnValue(value.toFloat()).setColor(Utils.getColor(R.color.common_blue_color))
            subColumnValue.setLabel(String.format("%02d", i) + ":00" + "-" + String.format("%02d", i + 1) + ":00 " + value)
            values.add(subColumnValue)
            val column = Column(values)
            column.setHasLabelsOnlyForSelected(true)
            columns.add(column)
            axisXValues.add(AxisValue(i.toFloat()).setLabel(String.format("%02d", i) + ":00"))
        }
        if (top == 0) {
            axisYValues.add(AxisValue(0f).setLabel(0.toString()))
        } else {
            for (i in 0..top) {
                axisYValues.add(AxisValue(i.toFloat()).setLabel(i.toString()))
            }
        }
        val columnChartData = ColumnChartData(columns)
        columnChartData.axisYLeft = Axis().setValues(axisYValues).setHasLines(true)
        columnChartData.axisXBottom = Axis().setValues(axisXValues).setHasTiltedLabels(true)
        columnChartView.columnChartData = columnChartData
        columnChartView.isValueSelectionEnabled = true
        columnChartView.isZoomEnabled = false
        columnChartView.isScrollEnabled = false
        columnChartView.currentViewport.left = 0f
        columnChartView.currentViewport.right = (activeTimeCount + 4).toFloat()
        columnChartView.currentViewport.top = (top + 1).toFloat()
        columnChartView.currentViewport.bottom = 0f
    }

    /**
     * 折线图
     *
     * @param context
     * @param chartData
     * @param legendContainer
     * @param lineChartView
     * @param type
     */
    fun initLineChart(context: Context, chartData: ChartData, legendContainer: WrapLinearLayout, lineChartView: LineChartView, type: Int) {
        val dates = chartData.dates
        val lineDatas = chartData.data
        val lineCount = Utils.getListCount(lineDatas)
        val lines = ArrayList<Line>()
        var top = Integer.MIN_VALUE
        var bottom = Integer.MAX_VALUE
        legendContainer.removeAllViews()
        for (i in 0 until lineCount) {
            val lineData = lineDatas[i]
            val color = Utils.getColor(mColorResIds[i])

            // 添加图例
            val legendView = TextView(context)
            legendView.text = lineData.name
            val colorBlock = ColorDrawable(color)
            colorBlock.setBounds(0, 0, mLegendColorBlockSize, mLegendColorBlockSize)
            legendView.setCompoundDrawables(colorBlock, null, null, null)
            legendView.compoundDrawablePadding = mLegendColorBlockPadding
            legendView.setTextColor(mTextColor)
            legendView.setTextSize(TypedValue.COMPLEX_UNIT_PX, mTextSize.toFloat())
            legendContainer.addView(legendView)

            val pointValues = ArrayList<PointValue>()
            val pointDatas = lineData.data
            val pointCount = Utils.getListCount(pointDatas)
            for (j in 0 until pointCount) {
                val pointData = pointDatas[j]
                val value = getPointValue(pointData, type)
                top = Math.max(top, value)
                bottom = Math.min(bottom, value)
                val pointValue = PointValue(dates.indexOf(pointData.date).toFloat(), value.toFloat())
                pointValue.setLabel(DateUtils.formatDate("MM/dd", pointData.date * 1000) + " " + lineData.name + ":" + value)
                pointValues.add(pointValue)
            }
            val line = Line(pointValues).setColor(color).setHasLabelsOnlyForSelected(true)
            lines.add(line)
        }
        val lineChartData = LineChartData().setLines(lines)

        val axisXValues = ArrayList<AxisValue>()
        val dateCount = Utils.getListCount(dates)
        for (i in 0 until dateCount) {
            axisXValues.add(AxisValue(i.toFloat()).setLabel(DateUtils.formatDate("MM/dd", dates[i] * 1000)))
        }
        lineChartData.axisXBottom = Axis().setValues(axisXValues).setHasTiltedLabels(true)

        val axisYValues = ArrayList<AxisValue>()
        if (bottom == top) {
            axisYValues.add(AxisValue(bottom.toFloat()).setLabel(bottom.toString()))
        } else {
            for (i in bottom..top) {
                axisYValues.add(AxisValue(i.toFloat()).setLabel(i.toString()))
            }
        }
        lineChartData.axisYLeft = Axis().setValues(axisYValues).setHasLines(true)
        lineChartView.lineChartData = lineChartData
        lineChartView.isValueSelectionEnabled = true
        lineChartView.isZoomEnabled = false
        lineChartView.isScrollEnabled = false
        lineChartView.currentViewport.left = -1f
        lineChartView.currentViewport.right = (dateCount + 1).toFloat()
        lineChartView.currentViewport.top = (top + 1).toFloat()
        lineChartView.currentViewport.bottom = (bottom - 1).toFloat()
    }

    /**
     * 根据不同的表格类型在PointData中取不同的字段作为值
     *
     * @param pointData
     * @param type
     * @return
     */
    private fun getPointValue(pointData: PointData, type: Int): Int {
        return when (type) {
            ChartConstant.CHART_TYPE_HISTORY_HEALTH -> Math.round(pointData.value)
            ChartConstant.CHART_TYPE_HISTORY_MESSAGE -> pointData.count
            ChartConstant.CHART_TYPE_HISTORY_USER -> pointData.count
            else -> 0
        }
    }
}
