package com.weiyoubot.client.feature.main.content.statistics

import com.weiyoubot.client.R
import com.weiyoubot.client.base.fragment.BaseFragment
import com.weiyoubot.client.common.dialog.PaymentGuideDialog
import com.weiyoubot.client.common.helper.UmengHelper
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.view.slidingtab.SlidingTabView
import com.weiyoubot.client.common.view.slidingtab.SlidingTabViewPagerTab
import com.weiyoubot.client.feature.main.UserDataConstant
import com.weiyoubot.client.feature.main.UserDataHelper
import com.weiyoubot.client.feature.main.content.statistics.all.view.StatisticsAllFragment
import com.weiyoubot.client.feature.main.content.statistics.history.view.StatisticsHistoryFragment
import com.weiyoubot.client.feature.main.menu.MenuConstant
import com.weiyoubot.client.model.bean.userdata.Group
import com.weiyoubot.client.model.bean.userdata.PermInfo

import android.os.Bundle
import android.support.v4.view.ViewPager
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup

import java.util.ArrayList

/**
 * Created by root on 10/31/16.
 */
class StatisticsFragment : BaseFragment() {

    private var mGroup: Group? = null
    private var mTrial: Boolean = false
    private var mPermId: Int = 0
    private var mGroupPermId: Int = 0
    private var mGroupPermInfo: PermInfo? = null
    private var mCanUseFeature: Boolean = false
    private var mFeaturePermName: String? = null

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        return SlidingTabView(activity)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        mGroup = arguments.getParcelable(MenuConstant.INTENT_KEY_GROUP)
        mTrial = arguments.getBoolean(MenuConstant.INTENT_KEY_TRIAL)
        mPermId = arguments.getInt(UserDataConstant.INTENT_KEY_PERM_ID)
        mGroupPermId = UserDataHelper.getGroupPermId(mGroup!!)
        mGroupPermInfo = UserDataHelper.getPermInfo(mGroupPermId)
        mCanUseFeature = UserDataHelper.isPermInfoHasFeature(mGroupPermInfo, UserDataConstant.FEATURE_STATISTICS)
        initPermIdAndFeaturePermName()


        val tabs = createStatisticsTabs()
        val slidingTabView = view as SlidingTabView
        slidingTabView.initViewPager(childFragmentManager, tabs)
        slidingTabView.setOffscreenPageLimit(Utils.getListCount(tabs))

        if (!mCanUseFeature && !mTrial) {
            // 群的付费权限能使用的功能不包含该本功能，且不在试用期，则只能使用部分功能，即展示第一个tab的早安和overview
            slidingTabView.addOnPageChangeListener(object : ViewPager.OnPageChangeListener {
                override fun onPageScrolled(position: Int, positionOffset: Float, positionOffsetPixels: Int) {}

                override fun onPageSelected(position: Int) {
                    if (position != 0) {
                        showPayDialog()
                        slidingTabView.currentItem = 0
                    }
                }

                override fun onPageScrollStateChanged(state: Int) {}
            })
        }
    }

    private fun initPermIdAndFeaturePermName() {
        val featurePermInfo = UserDataHelper.getFeaturePermInfo(UserDataConstant.FEATURE_STATISTICS)
        val featurePermId = featurePermInfo?.id ?: UserDataConstant.PERM_ULTIMATE
        if (mGroupPermId == UserDataConstant.PERM_FREE) {
            mPermId = featurePermId
        } else if (UserDataHelper.isPermBasic(mGroupPermId)) {
            if (featurePermId == UserDataConstant.PERM_ADVANCED) {
                mPermId = UserDataConstant.PERM_BASIC_UPDATE_ADVANCED
            } else if (featurePermId == UserDataConstant.PERM_ULTIMATE) {
                mPermId = UserDataConstant.PERM_BASIC_UPDATE_ULTIMATE
            }
        } else if (mGroupPermId == UserDataConstant.PERM_ADVANCED) {
            if (featurePermId == UserDataConstant.PERM_ULTIMATE) {
                mPermId = UserDataConstant.PERM_ADVANCED_UPDATE_ULTIMATE
            }
        }
        mFeaturePermName = UserDataHelper.getPermName(featurePermId)
    }

    private fun createStatisticsTabs(): List<SlidingTabViewPagerTab> {
        val needShowTrial = !mCanUseFeature && mTrial

        val todayFragment = StatisticsAllFragment()
        var bundle = Bundle(arguments)
        bundle.putBoolean(MenuConstant.INTENT_KEY_YESTERDAY, false)
        bundle.putBoolean(MenuConstant.INTENT_KEY_TRIAL, needShowTrial)
        bundle.putInt(UserDataConstant.INTENT_KEY_PERM_ID, mPermId)
        todayFragment.arguments = bundle

        val yesterdayFragment = StatisticsAllFragment()
        bundle = Bundle(arguments)
        bundle.putBoolean(MenuConstant.INTENT_KEY_YESTERDAY, true)
        bundle.putBoolean(MenuConstant.INTENT_KEY_TRIAL, needShowTrial)
        bundle.putInt(UserDataConstant.INTENT_KEY_PERM_ID, mPermId)
        yesterdayFragment.arguments = bundle

        val historyFragment = StatisticsHistoryFragment()
        bundle = Bundle(arguments)
        bundle.putBoolean(MenuConstant.INTENT_KEY_TRIAL, needShowTrial)
        bundle.putInt(UserDataConstant.INTENT_KEY_PERM_ID, mPermId)
        historyFragment.arguments = bundle

        val tabs = ArrayList<SlidingTabViewPagerTab>()
        tabs.add(SlidingTabViewPagerTab(0, getString(R.string.statistics_today), todayFragment))
        tabs.add(SlidingTabViewPagerTab(1, getString(R.string.statistics_yesterday), yesterdayFragment))
        tabs.add(SlidingTabViewPagerTab(2, getString(R.string.statistics_history), historyFragment))
        return tabs
    }

    private fun showPayDialog() {
        val dialog = PaymentGuideDialog(context)
        dialog.setTitle(R.string.payment_guide_dialog_title)
        dialog.setMessage(Utils.getString(R.string.payment_guide_dialog_message_feature, mFeaturePermName))
        dialog.setLeftButton(R.string.payment_guide_dialog_left_button) {
            UmengHelper.trackEvent(UmengHelper.EVENT_PAY_NOTICE_DIALOG_CLICK_PAY_BTN)
            UserDataHelper.startPay(context, mPermId, mGroup)
            dialog.dismiss()
        }
        dialog.show()
    }
}
