package com.weiyoubot.client.feature.main.content.statistics.all.adapter

import android.content.Context
import android.support.v7.widget.RecyclerView
import android.widget.Button
import android.widget.TextView
import com.github.mikephil.charting.charts.HorizontalBarChart
import com.hannesdorfmann.annotatedadapter.annotation.ViewField
import com.hannesdorfmann.annotatedadapter.annotation.ViewType
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.AnnotatedAdapter
import com.weiyoubot.client.common.table.TableAdapter
import com.weiyoubot.client.common.utils.DateUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.utils.setTextHTML
import com.weiyoubot.client.common.view.SwitchItemView
import com.weiyoubot.client.common.view.TrialView
import com.weiyoubot.client.common.view.WrapLinearLayout
import com.weiyoubot.client.common.view.recyclerviewmanager.FullyGridLayoutManager
import com.weiyoubot.client.common.view.recyclerviewmanager.FullyLinearLayoutManager
import com.weiyoubot.client.common.view.recycleviewdecoration.OverviewItemDecoration
import com.weiyoubot.client.feature.main.content.TableHelper
import com.weiyoubot.client.feature.main.content.statistics.ChartHelper
import com.weiyoubot.client.feature.main.content.statistics.adapter.OverviewAdapter
import com.weiyoubot.client.model.bean.statistics.all.StatisticsAll
import com.weiyoubot.client.model.bean.userdata.Group
import lecho.lib.hellocharts.view.ColumnChartView
import lecho.lib.hellocharts.view.PieChartView

/**
 * Created by root on 11/1/16.
 */
class StatisticsAllAdapter(
        context: Context,
        private val mGroup: Group,
        private val mTrial: Boolean,
        private val mPermId: Int,
        private val mIsYesterday: Boolean,
        private val mIsAdmin: Boolean,
        private val mOnExitMemberTableItemClickListener: TableAdapter.OnTableItemClickListener,
        private val mOnSyncListener: OnSyncListener
) : AnnotatedAdapter<StatisticsAll>(context), StatisticsAllAdapterBinder {
    override lateinit var data: StatisticsAll

    companion object {
        @ViewType(
                layout = R.layout.trial_item_view,
                views = [
                    ViewField(id = R.id.trial_view, name = "trialView", type = TrialView::class)
                ])
        const val VIEW_TYPE_ITEM_TRIAL = 0

        @ViewType(
                layout = R.layout.statistics_all_diagnostic_send_view,
                views = [
                    ViewField(id = R.id.diagnostic_send_switch_item_view, name = "diagnosticSendSwitchItemView", type = SwitchItemView::class),
                    ViewField(id = R.id.sync_grouping, name = "syncGrouping", type = Button::class),
                    ViewField(id = R.id.sync, name = "sync", type = Button::class)
                ])
        const val VIEW_TYPE_DIAGNOSTIC_SEND = 1

        @ViewType(
                layout = R.layout.statistics_all_health_view,
                views = [
                    ViewField(id = R.id.pie_chart_view, name = "pieChartView", type = PieChartView::class),
                    ViewField(id = R.id.group_name, name = "groupName", type = TextView::class),
                    ViewField(id = R.id.average, name = "average", type = TextView::class),
                    ViewField(id = R.id.diagnostic_time, name = "diagnosticTime", type = TextView::class),
                    ViewField(id = R.id.horizontal_bar_chart, name = "horizontalBarChart", type = HorizontalBarChart::class)
                ])
        const val VIEW_TYPE_HEALTH = 2

        @ViewType(
                layout = R.layout.statistics_overview_view,
                views = [
                    ViewField(id = R.id.recycler_view, name = "recyclerView", type = RecyclerView::class)
                ])
        const val VIEW_TYPE_OVERVIEW = 3

        @ViewType(
                layout = R.layout.statistics_keywords_view,
                views = [
                    ViewField(id = R.id.keyword_table, name = "keywordTable", type = RecyclerView::class)
                ])
        const val VIEW_TYPE_KEYWORDS = 4

        @ViewType(
                layout = R.layout.statistics_all_message_view,
                views = [
                    ViewField(id = R.id.pie_chart_view, name = "pieChartView", type = PieChartView::class),
                    ViewField(id = R.id.legend_container, name = "legendContainer", type = WrapLinearLayout::class),
                    ViewField(id = R.id.average, name = "average", type = TextView::class),
                    ViewField(id = R.id.type_table, name = "typeTable", type = RecyclerView::class)
                ])
        const val VIEW_TYPE_MESSAGE = 5

        @ViewType(
                layout = R.layout.statistics_all_user_view,
                views = [
                    ViewField(id = R.id.pie_chart_view, name = "pieChartView", type = PieChartView::class),
                    ViewField(id = R.id.legend_container, name = "legendContainer", type = WrapLinearLayout::class),
                    ViewField(id = R.id.average, name = "average", type = TextView::class),
                    ViewField(id = R.id.type_table, name = "typeTable", type = RecyclerView::class),
                    ViewField(id = R.id.enter_member_table, name = "enterMemberTable", type = RecyclerView::class),
                    ViewField(id = R.id.exit_member_table, name = "exitMemberTable", type = RecyclerView::class)
                ])
        const val VIEW_TYPE_USER = 6

        @ViewType(
                layout = R.layout.statistics_all_active_time_view,
                views = [
                    ViewField(id = R.id.column_chart_view, name = "columnChartView", type = ColumnChartView::class),
                    ViewField(id = R.id.average, name = "average", type = TextView::class),
                    ViewField(id = R.id.time_table, name = "timeTable", type = RecyclerView::class)
                ])
        const val VIEW_TYPE_ACTIVE_TIME = 7
    }

    private var mDiagnosticSend: Boolean = false
    private val mOverviewItemDecoration = OverviewItemDecoration()

    private val trialCount: Int
        get() = if (shouldShowTrial()) 1 else 0

    interface OnSyncListener {
        fun doSync(groupping: Boolean)
    }

    fun setDiagnosticSend(diagnosticSend: Boolean) {
        mDiagnosticSend = diagnosticSend
        notifyDataSetChanged()
    }

    override fun getItemCount(): Int {
        return trialCount + if (mIsYesterday) 6 else if (mIsAdmin) 4 else 3
    }

    private fun shouldShowTrial(): Boolean {
        return mTrial || mGroup.isExpiring
    }

    override fun getItemViewType(position: Int): Int {
        if (shouldShowTrial() && position == 0) {
            return VIEW_TYPE_ITEM_TRIAL
        }
        if (mIsYesterday) {
            when (position - trialCount) {
                0 -> return VIEW_TYPE_HEALTH
                1 -> return VIEW_TYPE_OVERVIEW
                2 -> return VIEW_TYPE_KEYWORDS
                3 -> return VIEW_TYPE_MESSAGE
                4 -> return VIEW_TYPE_USER
                5 -> return VIEW_TYPE_ACTIVE_TIME
                else -> {
                }
            }
        } else {
            if (mIsAdmin) {
                when (position - trialCount) {
                    0 -> return VIEW_TYPE_DIAGNOSTIC_SEND
                    1 -> return VIEW_TYPE_OVERVIEW
                    2 -> return VIEW_TYPE_MESSAGE
                    3 -> return VIEW_TYPE_USER
                    else -> {
                    }
                }
            } else {
                when (position - trialCount) {
                    0 -> return VIEW_TYPE_OVERVIEW
                    1 -> return VIEW_TYPE_MESSAGE
                    2 -> return VIEW_TYPE_USER
                    else -> {
                    }
                }
            }
        }
        return -1
    }

    override fun bindViewHolder(vh: StatisticsAllAdapterHolders.VIEW_TYPE_ITEM_TRIALViewHolder, position: Int) {
        vh.trialView.initView(mGroup, mTrial, mPermId)
    }

    override fun bindViewHolder(vh: StatisticsAllAdapterHolders.VIEW_TYPE_DIAGNOSTIC_SENDViewHolder, position: Int) {
        vh.diagnosticSendSwitchItemView.setSwitchOn(mDiagnosticSend)
        vh.sync.setOnClickListener {
            mOnSyncListener.doSync(false)
        }
        vh.syncGrouping.setOnClickListener {
            mOnSyncListener.doSync(true)
        }
    }

    override fun bindViewHolder(vh: StatisticsAllAdapterHolders.VIEW_TYPE_HEALTHViewHolder, position: Int) {
        ChartHelper.initAllHealthPieChart(data.health.score, vh.pieChartView)

        vh.groupName.setTextHTML(Utils.getString(R.string.statistics_health_group_name, data.name))
        vh.average.setTextHTML(Utils.getString(R.string.statistics_health_average, Math.round(data.health.average)))
        val diagnosticTime = DateUtils.formatDate(Utils.getString(R.string.statistics_health_diagnostic_time_format), System.currentTimeMillis() - DateUtils.ONE_DAY_MILLISECONDS)
        vh.diagnosticTime.setTextHTML(Utils.getString(R.string.statistics_health_diagnostic_time, diagnosticTime))

        ChartHelper.initAllHealthHorizontalBarChart(data.health.details, vh.horizontalBarChart)
    }

    override fun bindViewHolder(vh: StatisticsAllAdapterHolders.VIEW_TYPE_OVERVIEWViewHolder, position: Int) {
        vh.recyclerView.layoutManager = FullyGridLayoutManager(mContext, 3)
        vh.recyclerView.removeItemDecoration(mOverviewItemDecoration)
        vh.recyclerView.addItemDecoration(mOverviewItemDecoration)
        val adapter = OverviewAdapter(mContext, true)
        adapter.data = data.overview
        vh.recyclerView.adapter = adapter
    }

    override fun bindViewHolder(vh: StatisticsAllAdapterHolders.VIEW_TYPE_KEYWORDSViewHolder, position: Int) {
        vh.keywordTable.layoutManager = FullyLinearLayoutManager(mContext)
        val keywordTableAdapter = TableAdapter(mContext)
        keywordTableAdapter.data = TableHelper.createKeywordTableData(data.keywords)
        vh.keywordTable.adapter = keywordTableAdapter
    }

    override fun bindViewHolder(vh: StatisticsAllAdapterHolders.VIEW_TYPE_MESSAGEViewHolder, position: Int) {
        val types = data.message.types

        ChartHelper.initAllTypesPieChart(mContext, types, vh.legendContainer, vh.pieChartView)
        vh.average.text = mContext.getString(R.string.statistics_message_average, Utils.getPercentageText(data.message.average))

        vh.typeTable.layoutManager = FullyLinearLayoutManager(mContext)
        val typeTableAdapter = TableAdapter(mContext)
        typeTableAdapter.data = TableHelper.createTypeTableData(types)
        vh.typeTable.adapter = typeTableAdapter
    }

    override fun bindViewHolder(vh: StatisticsAllAdapterHolders.VIEW_TYPE_USERViewHolder, position: Int) {
        val types = data.user.types

        ChartHelper.initAllTypesPieChart(mContext, types, vh.legendContainer, vh.pieChartView)
        vh.average.text = mContext.getString(R.string.statistics_user_average, Utils.getPercentageText(data.user.average))

        vh.typeTable.layoutManager = FullyLinearLayoutManager(mContext)
        val typeTableAdapter = TableAdapter(mContext)
        typeTableAdapter.data = TableHelper.createTypeTableData(types)
        vh.typeTable.adapter = typeTableAdapter

        vh.enterMemberTable.layoutManager = FullyLinearLayoutManager(mContext)
        val enterMemberTableAdapter = TableAdapter(mContext)
        enterMemberTableAdapter.data = TableHelper.createEnterMemberTableData(data.user.enterMembers)
        vh.enterMemberTable.adapter = enterMemberTableAdapter

        vh.exitMemberTable.layoutManager = FullyLinearLayoutManager(mContext)
        val exitMemberTableAdapter = TableAdapter(mContext)
        exitMemberTableAdapter.data = TableHelper.createExitMemberTableData(data.user.exitMembers, mIsAdmin)
        if (mIsAdmin) {
            exitMemberTableAdapter.setOnTableItemClickListener(mOnExitMemberTableItemClickListener)
        }
        vh.exitMemberTable.adapter = exitMemberTableAdapter
    }

    override fun bindViewHolder(vh: StatisticsAllAdapterHolders.VIEW_TYPE_ACTIVE_TIMEViewHolder, position: Int) {
        val builder = StringBuilder()

        ChartHelper.initActiveTimeColumnChart(data.activeTime.seg, vh.columnChartView)

        val averages = data.activeTime.average
        for (average in averages) {
            builder.append(average).append("，")
        }
        if (builder.isNotEmpty()) {
            builder.deleteCharAt(builder.length - 1)
        }
        vh.average.text = mContext.getString(R.string.statistics_active_time_average, builder)

        vh.timeTable.layoutManager = FullyLinearLayoutManager(mContext)
        val timeTableAdapter = TableAdapter(mContext)
        timeTableAdapter.data = TableHelper.createTimeTableData(data.activeTime.seg)
        vh.timeTable.adapter = timeTableAdapter
    }
}
