package com.weiyoubot.client.feature.main.content.statistics.all.presenter

import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.BaseLcePresenter
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.common.view.SwitchItemViewEvent
import com.weiyoubot.client.feature.main.content.complaint.ComplaintHelper
import com.weiyoubot.client.feature.main.content.statistics.all.view.StatisticsAllMvpView
import com.weiyoubot.client.model.api.ApiParamKeys
import com.weiyoubot.client.model.apikt.ApiClient
import com.weiyoubot.client.model.bean.complaint.exit.ComplaintExit
import com.weiyoubot.client.model.bean.complaint.exit.Exit
import com.weiyoubot.client.model.bean.settings.DiagnosticSend
import com.weiyoubot.client.model.bean.statistics.all.StatisticsAll
import com.weiyoubot.client.model.loader.OnDataLoadListener

import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe
import org.json.JSONException

/**
 * Created by root on 11/1/16.
 */
class StatisticsAllPresenter : BaseLcePresenter<StatisticsAll, StatisticsAllMvpView>() {

    override fun loadData(pullToRefresh: Boolean, params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        ApiClient.requestStatisticsAll(params, listener)
    }

    fun loadComplaintExit(gid: String, day: Int) {
        ComplaintHelper.loadComplaintExit(gid, day, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    val complaintExit = data as ComplaintExit
                    view.updateComplaintExit(complaintExit)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {}
        })
    }

    fun exitComplaint(gid: String, exit: Exit) {
        ComplaintHelper.exitComplaint(gid, exit, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    view.exitComplaintSuccess(exit)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached {
                    UIUtils.showFailedToast(R.string.complaint_failed, errorMessage)
                }
            }
        })
    }

    fun exitRepeal(gid: String, exit: Exit) {
        ComplaintHelper.exitRepeal(gid, exit, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    view.exitRepealSuccess(exit)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached {
                    UIUtils.showFailedToast(R.string.complaint_repeal_failed, errorMessage)
                }
            }
        })
    }

    fun getAction(checkedId: Int): String {
        return ComplaintHelper.getAction(checkedId)
    }

    fun loadDiagnosticSend(gid: String) {
        ApiClient.requestDiagnosticSend(gid, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    val diagnosticSend = data as DiagnosticSend
                    view.updateDiagnosticSend(diagnosticSend.status == 1)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {}
        })
    }

    fun setDiagnosticSend(gid: String, on: Boolean) {
        try {
            ApiClient.setDiagnosticSend(gid, if (on) 1 else 0, object : OnDataLoadListener {
                override fun onDataLoaded(data: Any) {
                    ifViewAttached { view ->
                        view.updateDiagnosticSend(on)
                    }
                }

                override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                    ifViewAttached { view ->
                        view.updateDiagnosticSend(!on)
                        UIUtils.showFailedToast(R.string.set_failed, errorMessage)
                    }
                }
            })
        } catch (e: JSONException) {
            e.printStackTrace()
        }

    }

    fun syncReply(gid: String, grouping: Boolean) {
        try {
            com.weiyoubot.client.model.api.ApiClient.syncReply(gid, grouping, ApiParamKeys.SYNC_TYPE_VALUE_MORNING, null, object : OnDataLoadListener {
                override fun onDataLoaded(data: Any) {
                    ifViewAttached { UIUtils.showToast(R.string.reply_sync_success) }
                }

                override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                    ifViewAttached { UIUtils.showFailedToast(R.string.reply_sync_failed, errorMessage) }
                }
            })
        } catch (e: JSONException) {
            e.printStackTrace()
        }

    }

    override fun attachView(view: StatisticsAllMvpView) {
        super.attachView(view)
        EventBus.getDefault().register(this)
    }

    override fun detachView() {
        super.detachView()
        EventBus.getDefault().unregister(this)
    }

    @Subscribe
    fun onEvent(event: SwitchItemViewEvent) {
        ifViewAttached { view ->
            when (event.id) {
                R.id.diagnostic_send_switch_item_view -> view.diagnosticSendSwitchChanged(event.on)
                else -> {
                }
            }
        }
    }
}
