package com.weiyoubot.client.feature.main.content.statistics.all.view

import android.annotation.SuppressLint
import android.os.Bundle
import android.support.v7.app.AlertDialog
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.fragment.BaseLceFragment
import com.weiyoubot.client.common.table.TableAdapter
import com.weiyoubot.client.common.utils.DateUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.view.WrapRadioGroup
import com.weiyoubot.client.common.view.recycleviewdecoration.CardItemDecoration
import com.weiyoubot.client.feature.main.UserDataConstant
import com.weiyoubot.client.feature.main.UserDataHelper
import com.weiyoubot.client.feature.main.content.statistics.all.adapter.StatisticsAllAdapter
import com.weiyoubot.client.feature.main.content.statistics.all.presenter.StatisticsAllPresenter
import com.weiyoubot.client.feature.main.menu.MenuConstant
import com.weiyoubot.client.model.apikt.ApiParamKeys
import com.weiyoubot.client.model.bean.complaint.exit.ComplaintExit
import com.weiyoubot.client.model.bean.complaint.exit.Exit
import com.weiyoubot.client.model.bean.statistics.all.StatisticsAll
import com.weiyoubot.client.model.bean.userdata.Group
import java.util.*

/**
 * Created by root on 11/1/16.
 */
class StatisticsAllFragment : BaseLceFragment<RecyclerView, StatisticsAll, StatisticsAllMvpView, StatisticsAllPresenter>(), StatisticsAllMvpView {

    lateinit var mGid: String
    private var mIsAdmin: Boolean = false
    private var mIsYesterday: Boolean = false
    private var mDate: Long = 0

    private lateinit var mAdapter: StatisticsAllAdapter

    private lateinit var mStatisticsAll: StatisticsAll
    private var mDiagnosticSendOn: Boolean = false

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        return inflater.inflate(R.layout.lce_fragment, container, false)
    }

    @SuppressLint("InflateParams")
    override fun onViewCreated(view: View?, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val group = arguments.getParcelable<Group>(MenuConstant.INTENT_KEY_GROUP)
        val trial = arguments.getBoolean(MenuConstant.INTENT_KEY_TRIAL)
        val permId = arguments.getInt(UserDataConstant.INTENT_KEY_PERM_ID)
        mGid = group!!.gid
        mIsAdmin = UserDataHelper.isAdmin(group)
        mIsYesterday = arguments.getBoolean(MenuConstant.INTENT_KEY_YESTERDAY)
        mDate = if (mIsYesterday) {
            // 昨天0点
            DateUtils.getToadyTimeInMillis() / 1000 - DateUtils.ONE_DAY_SECONDS
        } else {
            // 当天0点
            DateUtils.getToadyTimeInMillis() / 1000
        }

        mAdapter = StatisticsAllAdapter(activity, group, trial, permId, mIsYesterday, mIsAdmin, TableAdapter.OnTableItemClickListener { rowIndex, columnIndex ->
            val exitMembers = mStatisticsAll.user.exitMembers
            if (Utils.isListEmpty(exitMembers)) {
                return@OnTableItemClickListener
            }
            if (rowIndex > 0 && columnIndex == 1) {
                val exitMember = exitMembers[rowIndex - 1]
                if (exitMember.repeal == 1) {
                    val dialogView = LayoutInflater.from(activity).inflate(R.layout.complaint_dialog_view, null)
                    val radioGroup = dialogView.findViewById<View>(R.id.radio_group) as WrapRadioGroup
                    radioGroup.check(R.id.complaint_ad)
                    AlertDialog.Builder(activity).setTitle(R.string.complaint).setView(dialogView).setPositiveButton(R.string.ok) { _, _ ->
                        exitMember.action = presenter.getAction(radioGroup.checkedRadioButtonId)
                        presenter.exitComplaint(mGid, exitMember)
                    }.setNegativeButton(R.string.cancel, null).show()
                } else {
                    presenter.exitRepeal(mGid, exitMember)
                }
            }
        }, object : StatisticsAllAdapter.OnSyncListener {
            override fun doSync(groupping: Boolean) {
                presenter.syncReply(mGid, groupping)
            }
        })

        contentView.layoutManager = LinearLayoutManager(activity)
        contentView.addItemDecoration(CardItemDecoration())
        contentView.adapter = mAdapter

        loadData(false)
    }

    override fun exitComplaintSuccess(exit: Exit) {
        exit.repeal = 0
        mAdapter.data = mStatisticsAll
        mAdapter.notifyDataSetChanged()
    }

    override fun exitRepealSuccess(exit: Exit) {
        exit.repeal = 1
        mAdapter.data = mStatisticsAll
        mAdapter.notifyDataSetChanged()
    }

    override fun createPresenter(): StatisticsAllPresenter {
        return StatisticsAllPresenter()
    }

    override fun loadData(pullToRefresh: Boolean) {
        val params = HashMap<String, Any>()
        params[ApiParamKeys.GID] = mGid
        params[ApiParamKeys.DATE] = DateUtils.toUTCTimeInSecond(mDate)
        presenter.loadData(pullToRefresh, params)
    }

    override fun setData(data: StatisticsAll) {
        // 先显示所有的统计数据
        mStatisticsAll = data
        mAdapter.data = mStatisticsAll
        mAdapter.notifyDataSetChanged()
        if (mStatisticsAll.user.exitMembers.isNotEmpty()) {
            // 如果离群用户不为空，再去请求离群用户的数据并更新离群用户表
            presenter.loadComplaintExit(mGid, if (mIsYesterday) 1 else 0)
        }
        if (!mIsYesterday && mIsAdmin) {
            loadDiagnosticSend()
        }
    }

    override fun updateComplaintExit(complaintExit: ComplaintExit) {
        mStatisticsAll.user.exitMembers = complaintExit.data
        mAdapter.data = mStatisticsAll
        mAdapter.notifyDataSetChanged()
    }

    private fun loadDiagnosticSend() {
        presenter.loadDiagnosticSend(mGid)
    }

    override fun diagnosticSendSwitchChanged(on: Boolean) {
        if (!mIsYesterday && mIsAdmin) {
            presenter.setDiagnosticSend(mGid, on)
        }
    }

    override fun updateDiagnosticSend(on: Boolean) {
        mDiagnosticSendOn = on
        mAdapter.setDiagnosticSend(mDiagnosticSendOn)
    }
}
