package com.weiyoubot.client.feature.main.content.statistics.history.adapter

import android.app.DatePickerDialog
import android.content.Context
import android.support.v7.widget.RecyclerView
import android.view.View
import android.widget.Button
import android.widget.TextView
import com.hannesdorfmann.annotatedadapter.annotation.ViewField
import com.hannesdorfmann.annotatedadapter.annotation.ViewType
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.AnnotatedAdapter
import com.weiyoubot.client.common.table.TableAdapter
import com.weiyoubot.client.common.utils.DateUtils
import com.weiyoubot.client.common.view.TrialView
import com.weiyoubot.client.common.view.WrapLinearLayout
import com.weiyoubot.client.common.view.recyclerviewmanager.FullyGridLayoutManager
import com.weiyoubot.client.common.view.recyclerviewmanager.FullyLinearLayoutManager
import com.weiyoubot.client.common.view.recycleviewdecoration.OverviewItemDecoration
import com.weiyoubot.client.feature.main.content.TableHelper
import com.weiyoubot.client.feature.main.content.statistics.ChartConstant
import com.weiyoubot.client.feature.main.content.statistics.ChartHelper
import com.weiyoubot.client.feature.main.content.statistics.adapter.OverviewAdapter
import com.weiyoubot.client.model.bean.statistics.history.StatisticsHistory
import com.weiyoubot.client.model.bean.userdata.Group
import lecho.lib.hellocharts.view.ColumnChartView
import lecho.lib.hellocharts.view.LineChartView
import java.util.*

/**
 * Created by root on 11/3/16.
 */
class StatisticsHistoryAdapter(
        context: Context,
        private val mGroup: Group,
        private val mTrial: Boolean,
        private val mPermId: Int,
        private val mOnQueryClickListener: OnQueryClickListener
) : AnnotatedAdapter<StatisticsHistory>(context), StatisticsHistoryAdapterBinder, View.OnClickListener {
    override lateinit var data: StatisticsHistory

    companion object {
        @ViewType(
                layout = R.layout.trial_item_view,
                views = [
                    ViewField(id = R.id.trial_view, name = "trialView", type = TrialView::class)
                ])
        const val VIEW_TYPE_ITEM_TRIAL = 0

        @ViewType(
                layout = R.layout.statistics_history_date_view,
                views = [
                    ViewField(id = R.id.start_date, name = "startDate", type = TextView::class),
                    ViewField(id = R.id.end_date, name = "endDate", type = TextView::class),
                    ViewField(id = R.id.query, name = "query", type = Button::class)
                ])
        const val VIEW_TYPE_DATE = 1

        @ViewType(
                layout = R.layout.statistics_overview_view,
                views = [
                    ViewField(id = R.id.recycler_view, name = "recyclerView", type = RecyclerView::class)
                ])
        const val VIEW_TYPE_OVERVIEW = 2

        @ViewType(
                layout = R.layout.statistics_history_health_view,
                views = [
                    ViewField(id = R.id.line_chart_view, name = "lineChartView", type = LineChartView::class),
                    ViewField(id = R.id.legend_container, name = "legendContainer", type = WrapLinearLayout::class)
                ])
        const val VIEW_TYPE_HEALTH = 3

        @ViewType(
                layout = R.layout.statistics_history_message_view,
                views = [
                    ViewField(id = R.id.line_chart_view, name = "lineChartView", type = LineChartView::class),
                    ViewField(id = R.id.legend_container, name = "legendContainer", type = WrapLinearLayout::class)
                ])
        const val VIEW_TYPE_MESSAGE = 4

        @ViewType(
                layout = R.layout.statistics_history_active_time_view,
                views = [
                    ViewField(id = R.id.column_chart_view, name = "columnChartView", type = ColumnChartView::class)
                ])
        const val VIEW_TYPE_ACTIVE_TIME = 5

        @ViewType(
                layout = R.layout.statistics_keywords_view,
                views = [
                    ViewField(id = R.id.keyword_table, name = "keywordTable", type = RecyclerView::class)
                ])
        const val VIEW_TYPE_KEYWORDS = 6

        @ViewType(
                layout = R.layout.statistics_history_user_view,
                views = [
                    ViewField(id = R.id.line_chart_view, name = "lineChartView", type = LineChartView::class),
                    ViewField(id = R.id.legend_container, name = "legendContainer", type = WrapLinearLayout::class),
                    ViewField(id = R.id.active_member_table, name = "activeMemberTable", type = RecyclerView::class),
                    ViewField(id = R.id.enter_member_table, name = "enterMemberTable", type = RecyclerView::class),
                    ViewField(id = R.id.exit_member_table, name = "exitMemberTable", type = RecyclerView::class)
                ])
        const val VIEW_TYPE_USER = 7
    }

    var startTime: Long = 0
        private set // 开始时间
    var endTime: Long = 0
        private set  // 结束时间
    private val mOverviewItemDecoration = OverviewItemDecoration()

    private val trialCount: Int
        get() = if (shouldShowTrial()) 1 else 0

    interface OnQueryClickListener {
        fun onQueryClick()
    }

    init {
        val today = DateUtils.getToadyTimeInMillis() / 1000 // 当天0点，以秒为单位
        startTime = today - 7 * DateUtils.ONE_DAY_SECONDS
        endTime = today - DateUtils.ONE_DAY_SECONDS
    }

    override fun getItemCount(): Int {
        return trialCount + 7
    }

    private fun shouldShowTrial(): Boolean {
        return mTrial || mGroup.isExpiring
    }

    override fun getItemViewType(position: Int): Int {
        return if (shouldShowTrial()) position else position + 1
    }

    override fun bindViewHolder(vh: StatisticsHistoryAdapterHolders.VIEW_TYPE_ITEM_TRIALViewHolder, position: Int) {
        vh.trialView.initView(mGroup, mTrial, mPermId)
    }

    override fun bindViewHolder(vh: StatisticsHistoryAdapterHolders.VIEW_TYPE_DATEViewHolder, position: Int) {
        vh.startDate.text = formatDate(startTime * 1000)
        vh.startDate.setOnClickListener(this)
        vh.endDate.text = formatDate(endTime * 1000)
        vh.endDate.setOnClickListener(this)
        vh.query.setOnClickListener(this)
    }

    private fun formatDate(timeInMillis: Long): String {
        val calendar = DateUtils.getCalendar()
        calendar.timeInMillis = timeInMillis
        val dayOfWeek = calendar.get(Calendar.DAY_OF_WEEK)
        return DateUtils.formatDate("yyyy/MM/dd", timeInMillis) + "\n" + DateUtils.getWeekday(dayOfWeek)
    }

    override fun bindViewHolder(vh: StatisticsHistoryAdapterHolders.VIEW_TYPE_OVERVIEWViewHolder, position: Int) {
        vh.recyclerView.layoutManager = FullyGridLayoutManager(mContext, 3)
        vh.recyclerView.removeItemDecoration(mOverviewItemDecoration)
        vh.recyclerView.addItemDecoration(mOverviewItemDecoration)
        val adapter = OverviewAdapter(mContext, false)
        adapter.data = data.overview
        vh.recyclerView.adapter = adapter
    }

    override fun bindViewHolder(vh: StatisticsHistoryAdapterHolders.VIEW_TYPE_HEALTHViewHolder, position: Int) {
        ChartHelper.initLineChart(mContext, data.health, vh.legendContainer, vh.lineChartView, ChartConstant.CHART_TYPE_HISTORY_HEALTH)
    }

    override fun bindViewHolder(vh: StatisticsHistoryAdapterHolders.VIEW_TYPE_MESSAGEViewHolder, position: Int) {
        ChartHelper.initLineChart(mContext, data.message, vh.legendContainer, vh.lineChartView, ChartConstant.CHART_TYPE_HISTORY_MESSAGE)
    }

    override fun bindViewHolder(vh: StatisticsHistoryAdapterHolders.VIEW_TYPE_ACTIVE_TIMEViewHolder, position: Int) {
        ChartHelper.initActiveTimeColumnChart(data.activeTime, vh.columnChartView)
    }

    override fun bindViewHolder(vh: StatisticsHistoryAdapterHolders.VIEW_TYPE_KEYWORDSViewHolder, position: Int) {
        vh.keywordTable.layoutManager = FullyLinearLayoutManager(mContext)
        val keywordTableAdapter = TableAdapter(mContext)
        keywordTableAdapter.data = TableHelper.createKeywordTableData(data.keywords)
        vh.keywordTable.adapter = keywordTableAdapter
    }

    override fun bindViewHolder(vh: StatisticsHistoryAdapterHolders.VIEW_TYPE_USERViewHolder, position: Int) {
        ChartHelper.initLineChart(mContext, data.user, vh.legendContainer, vh.lineChartView, ChartConstant.CHART_TYPE_HISTORY_USER)

        vh.activeMemberTable.layoutManager = FullyLinearLayoutManager(mContext)
        val activeMemberTableAdapter = TableAdapter(mContext)
        activeMemberTableAdapter.data = TableHelper.createActiveMemberTableData(data.activeMembers)
        vh.activeMemberTable.adapter = activeMemberTableAdapter

        vh.enterMemberTable.layoutManager = FullyLinearLayoutManager(mContext)
        val enterMemberTableAdapter = TableAdapter(mContext)
        enterMemberTableAdapter.data = TableHelper.createEnterMemberTableData(data.enterMembers)
        vh.enterMemberTable.adapter = enterMemberTableAdapter

        vh.exitMemberTable.layoutManager = FullyLinearLayoutManager(mContext)
        val exitMemberTableAdapter = TableAdapter(mContext)
        exitMemberTableAdapter.data = TableHelper.createExitMemberTableData(data.exitMembers, false)
        vh.exitMemberTable.adapter = exitMemberTableAdapter
    }

    override fun onClick(v: View) {
        val calendar = DateUtils.getCalendar()
        when (v.id) {
            R.id.start_date -> {
                calendar.timeInMillis = startTime * 1000
                val startDatePickerDialog = DatePickerDialog(mContext, DatePickerDialog.OnDateSetListener { _, year, monthOfYear, dayOfMonth ->
                    calendar.set(Calendar.YEAR, year)
                    calendar.set(Calendar.MONTH, monthOfYear)
                    calendar.set(Calendar.DAY_OF_MONTH, dayOfMonth)
                    startTime = calendar.timeInMillis / 1000

                    calendar.add(Calendar.MONTH, 1)
                    endTime = Math.max(startTime, endTime)
                    endTime = Math.min(endTime, calendar.timeInMillis / 1000)

                    this@StatisticsHistoryAdapter.notifyDataSetChanged()
                }, calendar.get(Calendar.YEAR), calendar.get(Calendar.MONTH), calendar.get(Calendar.DAY_OF_MONTH))
                // 最大日期为昨天0点
                startDatePickerDialog.datePicker.maxDate = DateUtils.getToadyTimeInMillis() - DateUtils.ONE_DAY_MILLISECONDS
                startDatePickerDialog.show()
            }
            R.id.end_date -> {
                calendar.timeInMillis = endTime * 1000
                val endDatePickerDialog = DatePickerDialog(mContext, DatePickerDialog.OnDateSetListener { _, year, monthOfYear, dayOfMonth ->
                    calendar.set(Calendar.YEAR, year)
                    calendar.set(Calendar.MONTH, monthOfYear)
                    calendar.set(Calendar.DAY_OF_MONTH, dayOfMonth)
                    endTime = calendar.timeInMillis / 1000

                    this@StatisticsHistoryAdapter.notifyDataSetChanged()
                }, calendar.get(Calendar.YEAR), calendar.get(Calendar.MONTH), calendar.get(Calendar.DAY_OF_MONTH))
                // 最小日期为起始时间，最大日期为 昨天0点或起始时间之后一个月 的最小值
                DateUtils.initEndDateMaxMinDate(endDatePickerDialog.datePicker, startTime * 1000, DateUtils.getToadyTimeInMillis() - DateUtils.ONE_DAY_MILLISECONDS)
                endDatePickerDialog.show()
            }
            R.id.query -> mOnQueryClickListener.onQueryClick()
            else -> {
            }
        }
    }
}
