package com.weiyoubot.client.feature.massmessage.adapter

import android.content.Context
import android.text.TextUtils
import android.view.View
import android.view.View.GONE
import android.view.View.VISIBLE
import android.widget.CheckBox
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.TextView
import com.hannesdorfmann.annotatedadapter.annotation.ViewField
import com.hannesdorfmann.annotatedadapter.annotation.ViewType
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.AnnotatedAdapter
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.model.bean.massmessage.MassMessageGroupData
import com.weiyoubot.client.model.bean.massmessage.MassMessageGroupInfo

/**
 * Created by root on 6/28/17.
 */
class MassMessageEditAdapterTypeGroup(context: Context)
    : AnnotatedAdapter<MassMessageGroupData>(context), MassMessageEditAdapterTypeGroupBinder, View.OnClickListener {
    companion object {
        @ViewType(
                layout = R.layout.mass_message_edit_group_header_view,
                views = [
                    ViewField(id = R.id.select_all, name = "selectAll", type = CheckBox::class)
                ])
        const val VIEW_TYPE_ITEM_HEADER = 0

        @ViewType(
                layout = R.layout.mass_message_edit_group_item_view,
                views = [ViewField(id = R.id.group, name = "group", type = LinearLayout::class),
                    ViewField(id = R.id.checkbox, name = "checkbox", type = CheckBox::class),
                    ViewField(id = R.id.icon, name = "icon", type = ImageView::class),
                    ViewField(id = R.id.text, name = "text", type = TextView::class)
                ])
        const val VIEW_TYPE_ITEM_GROUP = 1

        @ViewType(
                layout = R.layout.empty_item_view,
                views = [
                    ViewField(id = R.id.empty, name = "empty", type = TextView::class)
                ])
        const val VIEW_TYPE_ITEM_EMPTY = 2

        @ViewType(
                layout = R.layout.mass_message_edit_group_footer_view,
                views = [
                    ViewField(id = R.id.tips, name = "tips", type = TextView::class)
                ])
        const val VIEW_TYPE_ITEM_FOOTER = 3
    }

    override var data: MassMessageGroupData = MassMessageGroupData()
        set(value) {
            mAllGroupInfos.clear()
            mSelectedGroupInfos.clear()
            if (!Utils.isListEmpty(value.grouping)) {
                mAllGroupInfos.addAll(value.grouping)
            }
            if (!Utils.isListEmpty(value.groups)) {
                mAllGroupInfos.addAll(value.groups)
            }
            for (groupInfo in mAllGroupInfos) {
                if (groupInfo.status == 1) {
                    mSelectedGroupInfos.add(groupInfo)
                }
            }
        }

    private val mAllGroupInfos = mutableListOf<MassMessageGroupInfo>()
    internal val mSelectedGroupInfos = mutableListOf<MassMessageGroupInfo>()

    fun reset() {
        mSelectedGroupInfos.clear()
        notifyDataSetChanged()
    }

    override fun getItemCount(): Int {
        val groupCount = mAllGroupInfos.size
        return if (groupCount == 0) 3 else groupCount + 2
    }

    override fun getItemViewType(position: Int): Int {
        if (position == 0) {
            return VIEW_TYPE_ITEM_HEADER
        }
        if (position == itemCount - 1) {
            return VIEW_TYPE_ITEM_FOOTER
        }
        return if (Utils.isListEmpty(mAllGroupInfos)) {
            VIEW_TYPE_ITEM_EMPTY
        } else VIEW_TYPE_ITEM_GROUP
    }

    override fun bindViewHolder(vh: MassMessageEditAdapterTypeGroupHolders.VIEW_TYPE_ITEM_HEADERViewHolder, position: Int) {
        vh.selectAll.visibility = VISIBLE
        vh.selectAll.isChecked = mAllGroupInfos.isNotEmpty() && mAllGroupInfos.size == mSelectedGroupInfos.size
        vh.selectAll.setOnClickListener(this)
    }

    override fun bindViewHolder(vh: MassMessageEditAdapterTypeGroupHolders.VIEW_TYPE_ITEM_GROUPViewHolder, position: Int) {
        val groupInfo = mAllGroupInfos[position - 1]
        vh.text.text = groupInfo.groupName
        vh.checkbox.isChecked = mSelectedGroupInfos.contains(groupInfo)
        vh.icon.visibility = if (TextUtils.isEmpty(groupInfo.ggid)) GONE else VISIBLE
        vh.group.tag = groupInfo
        vh.group.setOnClickListener(this)
    }

    override fun bindViewHolder(vh: MassMessageEditAdapterTypeGroupHolders.VIEW_TYPE_ITEM_EMPTYViewHolder, position: Int) {
        vh.empty.setText(R.string.empty)
    }

    override fun bindViewHolder(vh: MassMessageEditAdapterTypeGroupHolders.VIEW_TYPE_ITEM_FOOTERViewHolder, position: Int) {

    }

    override fun onClick(v: View) {
        when (v.id) {
            R.id.select_all -> {
                mSelectedGroupInfos.clear()
                if ((v as CheckBox).isChecked) {
                    mSelectedGroupInfos.addAll(mAllGroupInfos)
                }
                notifyDataSetChanged()
            }
            R.id.group -> {
                val groupInfo = v.tag as MassMessageGroupInfo
                if (mSelectedGroupInfos.contains(groupInfo)) {
                    mSelectedGroupInfos.remove(groupInfo)
                } else {
                    mSelectedGroupInfos.add(groupInfo)
                }
                notifyDataSetChanged()
            }
        }
    }
}
