package com.weiyoubot.client.feature.massmessage.adapter

import android.content.Context
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import com.hannesdorfmann.annotatedadapter.annotation.ViewField
import com.hannesdorfmann.annotatedadapter.annotation.ViewType
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.AnnotatedAdapter
import com.weiyoubot.client.feature.massmessage.MassMessageConstant
import com.weiyoubot.client.model.bean.massmessage.MassMessageFriendData
import com.weiyoubot.client.model.bean.massmessage.MassMessageFriendGrouping
import com.weiyoubot.client.model.bean.massmessage.MassMessageFriendLabel

/**
 * Created by root on 6/28/17.
 */
class MassMessageEditAdapterTypePrivate(context: Context, private var friendsDeleteListener: FriendsDeleteListener)
    : AnnotatedAdapter<MassMessageFriendData>(context), MassMessageEditAdapterTypePrivateBinder, View.OnClickListener {
    companion object {
        @ViewType(
                layout = R.layout.mass_message_edit_friends_groups,
                views = [ViewField(id = R.id.group_name, name = "groupName", type = TextView::class),
                    ViewField(id = R.id.delete, name = "delete", type = ImageView::class)
                ])
        const val VIEW_TYPE_ITEM = 0
    }

    interface FriendsDeleteListener {
        fun onFriendsDeleted(cids: MutableSet<String>)
    }

    override var data: MassMessageFriendData = MassMessageFriendData()

    override fun getItemCount(): Int {
        return if (data.friendListType == MassMessageConstant.MASS_PRIVATE_FRIENDS_MODE_GROUPING) {
            data.friendGrouping.size
        } else {
            data.friendLabelClass.size
        }
    }

    override fun getItemViewType(position: Int): Int {
        return 0
    }

    override fun bindViewHolder(vh: MassMessageEditAdapterTypePrivateHolders.VIEW_TYPE_ITEMViewHolder, position: Int) {
        if (data.friendListType == MassMessageConstant.MASS_PRIVATE_FRIENDS_MODE_GROUPING) {
            val msg = "${data.friendGrouping[position].groupingName}(${data.friendGrouping[position].list.size})"
            vh.groupName.text = msg
            vh.delete.tag = data.friendGrouping[position]
        } else {
            val msg = "${data.friendLabelClass[position].labelName}(${data.friendLabelClass[position].list.size})"
            vh.groupName.text = msg
            vh.delete.tag = data.friendLabelClass[position]
        }
        vh.delete.setOnClickListener(this)
    }

    override fun onClick(v: View) {
        when (v.id) {
            R.id.delete -> {
                val cids = mutableSetOf<String>()
                if (data.friendListType == MassMessageConstant.MASS_PRIVATE_FRIENDS_MODE_GROUPING) {
                    for (contact in (v.tag as MassMessageFriendGrouping).list) {
                        cids.add(contact.cid)
                    }
                } else {
                    for (contact in (v.tag as MassMessageFriendLabel).list) {
                        cids.add(contact.cid)
                    }
                }
                friendsDeleteListener.onFriendsDeleted(cids)
            }
        }
    }
}
