package com.weiyoubot.client.feature.massmessage.adapter

import android.content.Context
import android.support.v7.app.AlertDialog
import android.text.TextUtils
import android.view.View
import android.widget.Button
import android.widget.ImageView
import android.widget.TextView
import com.hannesdorfmann.annotatedadapter.annotation.ViewField
import com.hannesdorfmann.annotatedadapter.annotation.ViewType
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.AnnotatedAdapter
import com.weiyoubot.client.common.utils.DateUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.model.bean.massmessage.MassMessageList
import com.weiyoubot.client.model.bean.massmessage.MassMessageListData
import java.util.*

/**
 * Created by root on 6/28/17.
 */
class MassMessageListAdapter(context: Context, private val mMassMessageListListener: MassMessageListListener)
    : AnnotatedAdapter<MassMessageList>(context), MassMessageListAdapterBinder, View.OnClickListener {
    companion object {
        @ViewType(
                layout = R.layout.mass_message_add_button,
                views = [
                    ViewField(id = R.id.add, name = "add", type = Button::class)
                ])
        const val VIEW_TYPE_ADD = 0

        @ViewType(
                layout = R.layout.three_row_action_container_view,
                views = [
                    ViewField(id = R.id.title, name = "title", type = TextView::class),
                    ViewField(id = R.id.label1, name = "label1", type = TextView::class),
                    ViewField(id = R.id.label2, name = "label2", type = TextView::class),
                    ViewField(id = R.id.switch_view, name = "switchView", type = ImageView::class),
                    ViewField(id = R.id.edit, name = "edit", type = ImageView::class),
                    ViewField(id = R.id.delete, name = "delete", type = ImageView::class)
                ])
        const val VIEW_TYPE_ITEM = 1
    }

    override lateinit var data: MassMessageList

    interface MassMessageListListener {
        fun addNewMassMessage()

        fun onSwitchOnOff(massMessageListData: MassMessageListData)

        fun onEdit(massMessageListData: MassMessageListData)

        fun onDelete(massMessageListData: MassMessageListData)
    }

    override fun getItemCount(): Int {
        return if (Utils.isListEmpty(data.data)) 1 else Utils.getListCount(data.data) + 1
    }

    override fun getItemViewType(position: Int): Int {
        return if (position == 0) VIEW_TYPE_ADD else VIEW_TYPE_ITEM
    }

    override fun bindViewHolder(vh: MassMessageListAdapterHolders.VIEW_TYPE_ADDViewHolder, position: Int) {
        vh.add.setOnClickListener(this)
    }

    override fun bindViewHolder(vh: MassMessageListAdapterHolders.VIEW_TYPE_ITEMViewHolder, position: Int) {
        val massMessageData = data.data[position - 1]
        vh.title.text = massMessageData.title
        val str1 = "发送时间: " + DateUtils.formatDate("HH:mm", massMessageData.trigger.timestamp * 1000)
        vh.label1.text = str1
        if (TextUtils.isEmpty(massMessageData.trigger.date)) {
            val str2 = "重复时间: " + makeRepeatTime(massMessageData)
            vh.label2.text = str2
        } else {
            val str3 = "发送日期: " + DateUtils.formatDate("yyyy-MM-dd", massMessageData.trigger.timestamp * 1000)
            vh.label2.text = str3
        }
        vh.switchView.setImageResource(if (massMessageData.status == 1) R.drawable.switch_round_on else R.drawable.switch_round_off)
        vh.switchView.tag = massMessageData
        vh.switchView.setOnClickListener(this)
        vh.edit.tag = massMessageData
        vh.edit.setOnClickListener(this)
        vh.delete.tag = massMessageData
        vh.delete.setOnClickListener(this)
    }

    override fun onClick(v: View) {
        val massMessageData = v.tag as MassMessageListData?
        when (v.id) {
            R.id.add -> mMassMessageListListener.addNewMassMessage()
            R.id.switch_view -> mMassMessageListListener.onSwitchOnOff(massMessageData!!)
            R.id.edit -> mMassMessageListListener.onEdit(massMessageData!!)
            R.id.delete -> AlertDialog.Builder(mContext).setTitle(R.string.dialog_title).setMessage(R.string.mass_message_delete_confirm)
                    .setPositiveButton(R.string.ok) { _, _ -> mMassMessageListListener.onDelete(massMessageData!!) }.setNegativeButton(R.string.cancel, null).show()
        }
    }

    private fun makeRepeatTime(massMessageListData: MassMessageListData): String {
        val days = massMessageListData.trigger.wkday.split(",".toRegex()).dropLastWhile { it.isEmpty() }.toTypedArray()
        val wkdays = ArrayList<String>()
        for (day in days) {
            when (day) {
                "1" -> wkdays.add("周一")
                "2" -> wkdays.add("周二")
                "3" -> wkdays.add("周三")
                "4" -> wkdays.add("周四")
                "5" -> wkdays.add("周五")
                "6" -> wkdays.add("周六")
                "7" -> wkdays.add("周日")
            }
        }
        return Utils.joinString(wkdays, "、")
    }
}
