package com.weiyoubot.client.feature.massmessage.adapter

import android.content.Context
import android.support.v7.widget.RecyclerView
import android.text.Html
import android.text.TextUtils
import android.view.View
import android.view.View.GONE
import android.view.View.VISIBLE
import android.widget.Button
import android.widget.TextView
import com.hannesdorfmann.annotatedadapter.annotation.ViewField
import com.hannesdorfmann.annotatedadapter.annotation.ViewType
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.AnnotatedAdapter
import com.weiyoubot.client.common.utils.DateUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.utils.setTextHTML
import com.weiyoubot.client.common.view.recyclerviewmanager.FullyLinearLayoutManager
import com.weiyoubot.client.feature.main.content.reply.view.ReplyRespContainerView
import com.weiyoubot.client.feature.massmessage.MassMessageConstant
import com.weiyoubot.client.model.bean.massmessage.MassMessageRecordDataTypeGroup
import com.weiyoubot.client.model.bean.massmessage.MassMessageRecordTypeGroup

/**
 * Created by root on 6/28/17.
 */
class MassMessageRecordAdapterTypeGroup(context: Context, private val mMassMessageRecordListener: MassMessageRecordListener)
    : AnnotatedAdapter<MassMessageRecordTypeGroup>(context), MassMessageRecordAdapterTypeGroupBinder, View.OnClickListener {
    companion object {
        @ViewType(
                layout = R.layout.empty_item_view,
                views = [ViewField(id = R.id.empty, name = "empty", type = TextView::class)
                ])
        const val VIEW_TYPE_ITEM_EMPTY = 0

        @ViewType(
                layout = R.layout.mass_message_record_item_view,
                views = [ViewField(id = R.id.time, name = "time", type = TextView::class),
                    ViewField(id = R.id.status, name = "status", type = TextView::class),
                    ViewField(id = R.id.resp_container, name = "respContainer", type = ReplyRespContainerView::class),
                    ViewField(id = R.id.group_container, name = "groupContainer", type = RecyclerView::class),
                    ViewField(id = R.id.button1, name = "button1", type = Button::class),
                    ViewField(id = R.id.delete, name = "delete", type = Button::class),
                    ViewField(id = R.id.failed_tips, name = "failedTips", type = TextView::class),
                    ViewField(id = R.id.mass_title, name = "massTitle", type = TextView::class)])
        const val VIEW_TYPE_ITEM = 1
    }

    override lateinit var data: MassMessageRecordTypeGroup

    interface MassMessageRecordListener {
        fun edit(massMessageListData: MassMessageRecordDataTypeGroup)

        fun refresh(massMessageListData: MassMessageRecordDataTypeGroup)

        fun resend(massMessageListData: MassMessageRecordDataTypeGroup)

        fun delete(massMessageListData: MassMessageRecordDataTypeGroup)
    }

    override fun getItemCount(): Int {
        return if (Utils.isListEmpty(data.data)) 1 else Utils.getListCount(data.data)
    }

    override fun getItemViewType(position: Int): Int {
        return if (position == 0 && (Utils.isListEmpty(data.data))) {
            VIEW_TYPE_ITEM_EMPTY
        } else VIEW_TYPE_ITEM
    }

    override fun bindViewHolder(vh: MassMessageRecordAdapterTypeGroupHolders.VIEW_TYPE_ITEM_EMPTYViewHolder, position: Int) {
        vh.empty.setText(R.string.mass_message_empty)
    }

    override fun bindViewHolder(vh: MassMessageRecordAdapterTypeGroupHolders.VIEW_TYPE_ITEMViewHolder, position: Int) {
        val massMessageDetailData: MassMessageRecordDataTypeGroup = data.data[position]
        vh.massTitle.text = massMessageDetailData.title
        vh.time.text = DateUtils.formatDate("yyyy-MM-dd HH:mm", massMessageDetailData.time * 1000)
        vh.respContainer.initRespDisplayContainer(massMessageDetailData.resp, false, null)
        vh.groupContainer.layoutManager = FullyLinearLayoutManager(mContext)

        val mMassMessageRecordGroupAdapter = MassMessageRecordGroupAdapter(mContext)
        vh.groupContainer.adapter = mMassMessageRecordGroupAdapter
        mMassMessageRecordGroupAdapter.data = massMessageDetailData.groups
        mMassMessageRecordGroupAdapter.notifyDataSetChanged()
        if (!TextUtils.isEmpty(massMessageDetailData.reason)) {
            vh.failedTips.visibility = VISIBLE
            vh.failedTips.setTextHTML(Utils.getString(R.string.mass_message_group_send_failed_tips, massMessageDetailData.reason), Html.ImageGetter {
                val size = Utils.getDimen(R.dimen.x32)
                val drawable = Utils.getDrawable(R.drawable.warning_round_red)
                drawable.setBounds(0, 0, size, size)
                drawable
            }, null)
        } else {
            vh.failedTips.visibility = GONE
        }
        vh.delete.tag = massMessageDetailData
        vh.delete.setOnClickListener(this)
        updateStatus(massMessageDetailData.status, vh.status, vh.button1)
        vh.button1.tag = massMessageDetailData
        vh.button1.setOnClickListener(this)
    }

    private fun updateStatus(status: Int, statusView: TextView, button: Button) {
        when (status) {
            MassMessageConstant.STATUS_NOT_SEND -> {
                statusView.setText(R.string.mass_message_status_0)
                button.visibility = VISIBLE
                button.setText(R.string.edit)
            }
            MassMessageConstant.STATUS_SENDING -> {
                statusView.setText(R.string.mass_message_status_1)
                button.visibility = VISIBLE
                button.setText(R.string.refresh)
            }
            MassMessageConstant.STATUS_SEND_SUCCESS -> {
                statusView.setText(R.string.mass_message_status_3)
                button.visibility = GONE
            }
            MassMessageConstant.STATUS_SEND_FAILED_PART -> {
                statusView.setText(R.string.mass_message_status_4)
                button.visibility = VISIBLE
                button.setText(R.string.mass_message_resend)
            }
            MassMessageConstant.STATUS_SEND_FAILED_ALL -> {
                statusView.setText(R.string.mass_message_status_5)
                button.visibility = VISIBLE
                button.setText(R.string.mass_message_resend)
            }
        }
    }

    override fun onClick(v: View) {
        val massMessageData = v.tag as MassMessageRecordDataTypeGroup
        when (v.id) {
            R.id.button1 -> when (massMessageData.status) {
                MassMessageConstant.STATUS_NOT_SEND -> mMassMessageRecordListener.edit(massMessageData)
                MassMessageConstant.STATUS_SENDING -> mMassMessageRecordListener.refresh(massMessageData)
                MassMessageConstant.STATUS_SEND_FAILED_PART, MassMessageConstant.STATUS_SEND_FAILED_ALL -> mMassMessageRecordListener.resend(massMessageData)
            }
            R.id.delete -> mMassMessageRecordListener.delete(massMessageData)
        }
    }
}
