package com.weiyoubot.client.feature.massmessage.adapter

import android.content.Context
import android.view.View
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.TextView
import com.hannesdorfmann.annotatedadapter.annotation.ViewField
import com.hannesdorfmann.annotatedadapter.annotation.ViewType
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.AnnotatedAdapter
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.feature.massmessage.MassMessageConstant
import com.weiyoubot.client.model.bean.massmessage.MassMessageGroupInfo
import java.util.*

/**
 * Created by root on 6/30/17.
 */
class MassMessageRecordGroupAdapter(context: Context)
    : AnnotatedAdapter<List<MassMessageGroupInfo>>(context), MassMessageRecordGroupAdapterBinder, View.OnClickListener {
    companion object {

        @ViewType(
                layout = R.layout.mass_message_record_group_header_view,
                views = [
                    ViewField(id = R.id.header, name = "header", type = TextView::class)
                ])
        const val VIEW_TYPE_ITEM_HEADER = 0

        @ViewType(layout = R.layout.mass_message_record_group_item_view,
                views = [
                    ViewField(id = R.id.group_name, name = "groupName", type = TextView::class)
                ])
        const val VIEW_TYPE_ITEM_GROUP = 1

        @ViewType(
                layout = R.layout.mass_message_record_group_footer_view,
                views = [
                    ViewField(id = R.id.expand, name = "expand", type = LinearLayout::class),
                    ViewField(id = R.id.text, name = "text", type = TextView::class),
                    ViewField(id = R.id.arrow, name = "arrow", type = ImageView::class)
                ])
        const val VIEW_TYPE_ITEM_FOOTER = 2
    }

    override var data: List<MassMessageGroupInfo> = listOf()
        set(value) {
            mNotSendGroupInfos.clear()
            mSendingGroupInfos.clear()
            mSendFailedGroupInfos.clear()
            mSendSuccessGroupInfos.clear()
            mNotSendExpanded = false
            mSendingExpanded = false
            mSendFailedExpanded = false
            mSendSuccessExpanded = false
            for (groupInfo in value) {
                when (groupInfo.status) {
                    MassMessageConstant.STATUS_NOT_SEND -> mNotSendGroupInfos.add(groupInfo)
                    MassMessageConstant.STATUS_SENDING -> mSendingGroupInfos.add(groupInfo)
                    MassMessageConstant.STATUS_SEND_FAILED -> mSendFailedGroupInfos.add(groupInfo)
                    MassMessageConstant.STATUS_SEND_SUCCESS -> mSendSuccessGroupInfos.add(groupInfo)
                }
            }
        }

    private val mNotSendGroupInfos = ArrayList<MassMessageGroupInfo>()
    private val mSendingGroupInfos = ArrayList<MassMessageGroupInfo>()
    private val mSendFailedGroupInfos = ArrayList<MassMessageGroupInfo>()
    private val mSendSuccessGroupInfos = ArrayList<MassMessageGroupInfo>()

    private var mNotSendExpanded: Boolean = false
    private var mSendingExpanded: Boolean = false
    private var mSendFailedExpanded: Boolean = false
    private var mSendSuccessExpanded: Boolean = false

    private var mNotSendCount: Int = 0
    private var mSendingCount: Int = 0
    private var mSendFailedCount: Int = 0
    private var mSendSuccessCount: Int = 0

    private var mNotSendHeaderPosition: Int = 0
    private var mSendingHeaderPosition: Int = 0
    private var mSendFailedHeaderPosition: Int = 0
    private var mSendSuccessHeaderPosition: Int = 0

    private val notSendCount: Int
        get() = notSendGroupInfosCount + notSendHeaderCount + notSendFooterCount

    private val notSendGroupInfosCount: Int
        get() {
            val count = Utils.getListCount(mNotSendGroupInfos)
            return if (mNotSendExpanded) count else Math.min(count, 3)
        }

    private val notSendHeaderCount: Int
        get() = if (Utils.isListEmpty(mNotSendGroupInfos)) 0 else 1

    private val notSendFooterCount: Int
        get() = if (Utils.getListCount(mNotSendGroupInfos) > 3) 1 else 0

    private val sendingCount: Int
        get() = sendingGroupInfosCount + sendingHeaderCount + sendingFooterCount

    private val sendingGroupInfosCount: Int
        get() {
            val count = Utils.getListCount(mSendingGroupInfos)
            return if (mSendingExpanded) count else Math.min(count, 3)
        }

    private val sendingHeaderCount: Int
        get() = if (Utils.isListEmpty(mSendingGroupInfos)) 0 else 1

    private val sendingFooterCount: Int
        get() = if (Utils.getListCount(mSendingGroupInfos) > 3) 1 else 0

    private val sendFailedCount: Int
        get() = sendFailedGroupInfosCount + sendFailedHeaderCount + sendFailedFooterCount

    private val sendFailedGroupInfosCount: Int
        get() {
            val count = Utils.getListCount(mSendFailedGroupInfos)
            return if (mSendFailedExpanded) count else Math.min(count, 3)
        }

    private val sendFailedHeaderCount: Int
        get() = if (Utils.isListEmpty(mSendFailedGroupInfos)) 0 else 1

    private val sendFailedFooterCount: Int
        get() = if (Utils.getListCount(mSendFailedGroupInfos) > 3) 1 else 0

    private val sendSuccessCount: Int
        get() = sendSuccessGroupInfosCount + sendSuccessHeaderCount + sendSuccessFooterCount

    private val sendSuccessGroupInfosCount: Int
        get() {
            val count = Utils.getListCount(mSendSuccessGroupInfos)
            return if (mSendSuccessExpanded) count else Math.min(count, 3)
        }

    private val sendSuccessHeaderCount: Int
        get() = if (Utils.isListEmpty(mSendSuccessGroupInfos)) 0 else 1

    private val sendSuccessFooterCount: Int
        get() = if (Utils.getListCount(mSendSuccessGroupInfos) > 3) 1 else 0

    override fun getItemCount(): Int {
        initCountAndHeaderPosition()
        return mNotSendCount + mSendingCount + mSendFailedCount + mSendSuccessCount
    }

    private fun initCountAndHeaderPosition() {
        mNotSendCount = notSendCount
        mSendingCount = sendingCount
        mSendFailedCount = sendFailedCount
        mSendSuccessCount = sendSuccessCount
        mNotSendHeaderPosition = -1
        mSendingHeaderPosition = -1
        mSendFailedHeaderPosition = -1
        mSendSuccessHeaderPosition = -1

        if (mNotSendCount > 0) {
            mNotSendHeaderPosition = 0
        }
        if (mSendingCount > 0) {
            mSendingHeaderPosition = if (mNotSendHeaderPosition != -1) {
                mNotSendHeaderPosition + mNotSendCount
            } else {
                0
            }
        }
        if (mSendFailedCount > 0) {
            mSendFailedHeaderPosition = when {
                mSendingHeaderPosition != -1 -> mSendingHeaderPosition + mSendingCount
                mNotSendHeaderPosition != -1 -> mNotSendHeaderPosition + mNotSendCount
                else -> 0
            }
        }
        if (mSendSuccessCount > 0) {
            mSendSuccessHeaderPosition = when {
                mSendFailedHeaderPosition != -1 -> mSendFailedHeaderPosition + mSendFailedCount
                mSendingHeaderPosition != -1 -> mSendingHeaderPosition + mSendingCount
                mNotSendHeaderPosition != -1 -> mNotSendHeaderPosition + mNotSendCount
                else -> 0
            }
        }
    }

    override fun getItemViewType(position: Int): Int {
        if (position == mNotSendHeaderPosition
                || position == mSendingHeaderPosition
                || position == mSendFailedHeaderPosition
                || position == mSendSuccessHeaderPosition) {
            return VIEW_TYPE_ITEM_HEADER
        }
        return if (notSendFooterCount > 0 && position == mNotSendHeaderPosition + mNotSendCount - 1
                || sendingFooterCount > 0 && position == mSendingHeaderPosition + mSendingCount - 1
                || sendFailedFooterCount > 0 && position == mSendFailedHeaderPosition + mSendFailedCount - 1
                || sendSuccessFooterCount > 0 && position == mSendSuccessHeaderPosition + mSendSuccessCount - 1) {
            VIEW_TYPE_ITEM_FOOTER
        } else VIEW_TYPE_ITEM_GROUP
    }

    override fun bindViewHolder(vh: MassMessageRecordGroupAdapterHolders.VIEW_TYPE_ITEM_HEADERViewHolder, position: Int) {
        when (position) {
            mNotSendHeaderPosition -> vh.header.text = Utils.getString(R.string.mass_message_not_send_groups, Utils.getListCount(mNotSendGroupInfos))
            mSendingHeaderPosition -> vh.header.text = Utils.getString(R.string.mass_message_sending_groups, Utils.getListCount(mSendingGroupInfos))
            mSendFailedHeaderPosition -> vh.header.text = Utils.getString(R.string.mass_message_send_failed_groups, Utils.getListCount(mSendFailedGroupInfos))
            mSendSuccessHeaderPosition -> vh.header.text = Utils.getString(R.string.mass_message_send_success_groups, Utils.getListCount(mSendSuccessGroupInfos))
        }
    }

    override fun bindViewHolder(vh: MassMessageRecordGroupAdapterHolders.VIEW_TYPE_ITEM_GROUPViewHolder, position: Int) {
        var groupInfo: MassMessageGroupInfo? = null
        if (mNotSendHeaderPosition != -1 && position > mNotSendHeaderPosition && position <= mNotSendHeaderPosition + notSendGroupInfosCount) {
            groupInfo = mNotSendGroupInfos[position - mNotSendHeaderPosition - 1]
        } else if (mSendingHeaderPosition != -1 && position > mSendingHeaderPosition && position <= mSendingHeaderPosition + sendingGroupInfosCount) {
            groupInfo = mSendingGroupInfos[position - mSendingHeaderPosition - 1]
        } else if (mSendFailedHeaderPosition != -1 && position > mSendFailedHeaderPosition && position <= mSendFailedHeaderPosition + sendFailedGroupInfosCount) {
            groupInfo = mSendFailedGroupInfos[position - mSendFailedHeaderPosition - 1]
        } else if (mSendSuccessHeaderPosition != -1 && position > mSendSuccessHeaderPosition && position <= mSendSuccessHeaderPosition + sendSuccessGroupInfosCount) {
            groupInfo = mSendSuccessGroupInfos[position - mSendSuccessHeaderPosition - 1]
        }
        if (groupInfo != null) {
            vh.groupName.text = groupInfo.groupName
        }
    }

    override fun bindViewHolder(vh: MassMessageRecordGroupAdapterHolders.VIEW_TYPE_ITEM_FOOTERViewHolder, position: Int) {
        var expand = false
        var type = -1
        if (notSendFooterCount > 0 && position == mNotSendHeaderPosition + mNotSendCount - 1) {
            expand = mNotSendExpanded
            type = 0
        } else if (sendingFooterCount > 0 && position == mSendingHeaderPosition + mSendingCount - 1) {
            expand = mSendingExpanded
            type = 1
        } else if (sendFailedFooterCount > 0 && position == mSendFailedHeaderPosition + mSendFailedCount - 1) {
            expand = mSendFailedExpanded
            type = 2
        } else if (sendSuccessFooterCount > 0 && position == mSendSuccessHeaderPosition + mSendSuccessCount - 1) {
            expand = mSendSuccessExpanded
            type = 3
        }
        vh.expand.tag = type
        vh.expand.setOnClickListener(this)
        vh.text.setText(if (expand) R.string.mass_message_collapse else R.string.mass_message_expand)
        vh.arrow.setImageResource(if (expand) R.drawable.arrow_up else R.drawable.arrow_down)
    }

    override fun onClick(v: View) {
        if (v.id == R.id.expand) {
            val type = v.tag as Int
            when (type) {
                0 -> mNotSendExpanded = !mNotSendExpanded
                1 -> mSendingExpanded = !mSendingExpanded
                2 -> mSendFailedExpanded = !mSendFailedExpanded
                3 -> mSendSuccessExpanded = !mSendSuccessExpanded
            }
            notifyDataSetChanged()
        }
    }
}
