package com.weiyoubot.client.feature.massmessage.adapter

import android.annotation.SuppressLint
import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.BaseExpandableListAdapter
import android.widget.CheckBox
import com.weiyoubot.client.R
import com.weiyoubot.client.feature.massmessage.view.SelectChangedListener
import com.weiyoubot.client.model.bean.massmessage.MassMessageFriendGrouping
import com.weiyoubot.client.model.bean.massmessage.MassMessageFriendInfo
import kotlinx.android.synthetic.main.mass_message_friends_group.view.*
import kotlinx.android.synthetic.main.mass_message_friends_group_item.view.*

/**
 * Created by root on 11/7/16.
 */
class MassMessageSelectFriendsGroupingAdapter(private val mContext: Context, private val selectChangedListener: SelectChangedListener) : BaseExpandableListAdapter() {
    var data: MutableList<MassMessageFriendGrouping> = mutableListOf()

    override fun getGroupCount(): Int {
        return data.size
    }

    override fun getChildrenCount(groupPosition: Int): Int {
        return data[groupPosition].list.size
    }

    override fun getGroup(groupPosition: Int): MassMessageFriendGrouping {
        return data[groupPosition]
    }

    override fun getChild(groupPosition: Int, childPosition: Int): MassMessageFriendInfo {
        return getGroup(groupPosition).list[childPosition]
    }

    override fun getGroupId(groupPosition: Int): Long {
        return groupPosition.toLong()
    }

    override fun getChildId(groupPosition: Int, childPosition: Int): Long {
        return (groupPosition * 10000 + childPosition).toLong()
    }

    override fun hasStableIds(): Boolean {
        return false
    }

    @SuppressLint("InflateParams")
    override fun getGroupView(groupPosition: Int, isExpanded: Boolean, convertView: View?, parent: ViewGroup): View {
        val convertViewNew = convertView
                ?: LayoutInflater.from(mContext).inflate(R.layout.mass_message_friends_group, null)
        val groupInfo = getGroup(groupPosition)
        var selectedCount = 0
        for (contact in groupInfo.list) {
            if (contact.status == 1) {
                selectedCount += 1
            }
        }
        convertViewNew.select_all.isChecked = selectedCount == getChildrenCount(groupPosition)
        val selectMsg = "${getGroup(groupPosition).groupingName} ($selectedCount/${getGroup(groupPosition).list.size})"
        convertViewNew.group_name.text = selectMsg
        convertViewNew.expand.setImageResource(if (isExpanded) R.drawable.arrow_up else R.drawable.arrow_down)
        convertViewNew.select_all.tag = groupPosition
        convertViewNew.select_all.setOnClickListener {
            val position = it.tag as Int
            val isChecked = (it as CheckBox).isChecked
            val contactIds = mutableListOf<String>()
            for (contact in getGroup(position).list) {
                if ((contact.status == 0) == isChecked) {
                    contactIds.add(contact.cid)
                }
            }
            selectChangedListener.onSelectChanged(contactIds, isChecked)
        }
        convertViewNew.group_container.setOnClickListener {
            selectChangedListener.changeGroupExpand(groupPosition, !isExpanded)
        }
        return convertViewNew
    }

    @SuppressLint("InflateParams")
    override fun getChildView(groupPosition: Int, childPosition: Int, isLastChild: Boolean, convertView: View?, parent: ViewGroup): View {
        val convertViewNew = convertView
                ?: LayoutInflater.from(mContext).inflate(R.layout.mass_message_friends_group_item, null)
        val contactInfo = getChild(groupPosition, childPosition)
        convertViewNew.selected.setOnCheckedChangeListener(null)
        convertViewNew.selected.isChecked = contactInfo.status == 1
        convertViewNew.selected.tag = contactInfo.cid
        convertViewNew.selected.setOnCheckedChangeListener { view, isChecked ->
            val cid = view.tag as String
            selectChangedListener.onSelectChanged(mutableListOf(cid), isChecked)
        }
        convertViewNew.contact.text = contactInfo.name
        return convertViewNew
    }

    override fun isChildSelectable(groupPosition: Int, childPosition: Int): Boolean {
        return true
    }
}
