package com.weiyoubot.client.feature.massmessage.presenter

import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.BaseLcePresenter
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.feature.massmessage.view.MassMessageEditMvpViewTypeGroup
import com.weiyoubot.client.model.apikt.ApiClient
import com.weiyoubot.client.model.bean.massmessage.MassMessageDetailDataTypeGroup
import com.weiyoubot.client.model.bean.massmessage.MassMessageDetailTypeGroup
import com.weiyoubot.client.model.bean.massmessage.MassMessageGroup
import com.weiyoubot.client.model.bean.massmessage.MassMessageGroupData
import com.weiyoubot.client.model.loader.OnDataLoadListener
import org.json.JSONException

/**
 * Created by root on 6/27/17.
 */
class MassMessageEditPresenterTypeGroup : BaseLcePresenter<MassMessageDetailTypeGroup, MassMessageEditMvpViewTypeGroup>() {
    override fun loadData(pullToRefresh: Boolean, params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        ApiClient.requestMassMessageDetail(params, listener)
    }

    fun loadMassMessageGroup() {
        ApiClient.requestMassMessageGroup(object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    val data1 = data as MassMessageGroup
                    view.updateMassMessageGroup(data1.data)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached { view ->
                    view.updateMassMessageGroup(MassMessageGroupData())
                }
            }
        })
    }

    fun saveMassMessage(isAdd: Boolean, massMessageDetailData: MassMessageDetailDataTypeGroup) {
        val listener = object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    view.saveMassMessageSuccess()
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached { view ->
                    view.saveMassMessageFailed()
                    UIUtils.showFailedToast(R.string.mass_message_save_failed, errorMessage)
                }
            }
        }
        try {
            if (isAdd) {
                // 新建
                ApiClient.saveMassMessage(massMessageDetailData, listener)
            } else {
                // 编辑
                ApiClient.modifyMassMessage(massMessageDetailData, listener)
            }
        } catch (e: JSONException) {
            e.printStackTrace()
        }
    }

    fun deleteMassMessage(massMessageDetailData: MassMessageDetailDataTypeGroup) {
        try {
            ApiClient.deleteMassMessage(massMessageDetailData.mmid, 0, 1, object : OnDataLoadListener {
                override fun onDataLoaded(data: Any) {
                    ifViewAttached { view ->
                        view.deleteMassMessageSuccess(massMessageDetailData)
                    }
                }

                override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                    ifViewAttached {
                        UIUtils.showFailedToast(R.string.mass_message_delete_failed, errorMessage)
                    }
                }
            })
        } catch (e: JSONException) {
            e.printStackTrace()
        }
    }
}
