package com.weiyoubot.client.feature.massmessage.presenter

import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.BaseLcePresenter
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.feature.massmessage.MassMessageSelectFriendsEvent
import com.weiyoubot.client.feature.massmessage.view.MassMessageEditMvpViewTypePrivate
import com.weiyoubot.client.model.apikt.ApiClient
import com.weiyoubot.client.model.bean.massmessage.MassMessageDetailDataTypePrivate
import com.weiyoubot.client.model.bean.massmessage.MassMessageDetailTypePrivate
import com.weiyoubot.client.model.loader.OnDataLoadListener
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe
import org.json.JSONException

/**
 * Created by root on 6/27/17.
 */
class MassMessageEditPresenterTypePrivate : BaseLcePresenter<MassMessageDetailTypePrivate, MassMessageEditMvpViewTypePrivate>() {
    override fun loadData(pullToRefresh: Boolean, params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        ApiClient.requestPrivateMassMessageDetail(params, listener)
    }

    fun saveMassMessage(isAdd: Boolean, massMessageDetailData: MassMessageDetailDataTypePrivate) {
        val listener = object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached { view ->
                    view.saveMassMessageSuccess()
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached { view ->
                    view.saveMassMessageFailed()
                    UIUtils.showFailedToast(R.string.mass_message_save_failed, errorMessage)
                }
            }
        }
        try {
            if (isAdd) {
                // 新建
                ApiClient.savePrivateMassMessage(massMessageDetailData, listener)
            } else {
                // 编辑
                ApiClient.modifyPrivateMassMessage(massMessageDetailData, listener)
            }
        } catch (e: JSONException) {
            e.printStackTrace()
        }
    }

    fun deleteMassMessage(massMessageDetailData: MassMessageDetailDataTypePrivate) {
        try {
            ApiClient.deleteMassMessage(massMessageDetailData.mmid, 0, 1, object : OnDataLoadListener {
                override fun onDataLoaded(data: Any) {
                    ifViewAttached { view ->
                        view.deleteMassMessageSuccess(massMessageDetailData)
                    }
                }

                override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                    ifViewAttached {
                        UIUtils.showFailedToast(R.string.mass_message_delete_failed, errorMessage)
                    }
                }
            })
        } catch (e: JSONException) {
            e.printStackTrace()
        }
    }


    override fun attachView(view: MassMessageEditMvpViewTypePrivate) {
        super.attachView(view)
        EventBus.getDefault().register(this)
    }

    override fun detachView() {
        super.detachView()
        EventBus.getDefault().unregister(this)
    }


    @Subscribe
    fun onEvent(event: MassMessageSelectFriendsEvent) {
        ifViewAttached {
            it.updateMassMessageFriends(event.MassMessageFriendData)
        }
    }
}
