package com.weiyoubot.client.feature.massmessage.presenter

import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.BaseLcePresenter
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.feature.massmessage.MassMessageEditSuccessEvent
import com.weiyoubot.client.feature.massmessage.view.MassMessageRecordMvpViewTypePrivate
import com.weiyoubot.client.model.apikt.ApiClient
import com.weiyoubot.client.model.bean.massmessage.MassMessageRecordDataTypePrivate
import com.weiyoubot.client.model.bean.massmessage.MassMessageRecordTypePrivate
import com.weiyoubot.client.model.loader.OnDataLoadListener
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe
import org.json.JSONException

/**
 * Created by root on 6/27/17.
 */
class MassMessageRecordPresenterTypePrivate : BaseLcePresenter<MassMessageRecordTypePrivate, MassMessageRecordMvpViewTypePrivate>() {
    override fun loadData(pullToRefresh: Boolean, params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        ApiClient.requestPrivateMassMessageRecord(params, listener)
    }

    fun resendMassMessage(mmid: String, timestamp: Long) {
        try {
            ApiClient.resendPrivateMassMessage(mmid, timestamp, object : OnDataLoadListener {
                override fun onDataLoaded(data: Any) {
                    ifViewAttached { view ->
                        view.resendMassMessageSuccess()
                    }
                }

                override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                    ifViewAttached {
                        UIUtils.showFailedToast(R.string.mass_message_resend_failed, errorMessage)
                    }
                }
            })
        } catch (e: JSONException) {
            e.printStackTrace()
        }
    }

    fun deleteMassMessage(massMessageListData: MassMessageRecordDataTypePrivate, timestamp: Long, type: Int, rid: String) {
        try {
            ApiClient.deletePrivateMassMessage(massMessageListData.mmid, timestamp, type, rid, object : OnDataLoadListener {
                override fun onDataLoaded(data: Any) {
                    ifViewAttached { view ->
                        view.deleteMassMessageSuccess(massMessageListData)
                    }
                }

                override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                    ifViewAttached {
                        UIUtils.showFailedToast(R.string.mass_message_delete_failed, errorMessage)
                    }
                }
            })
        } catch (e: JSONException) {
            e.printStackTrace()
        }
    }

    override fun attachView(view: MassMessageRecordMvpViewTypePrivate) {
        super.attachView(view)
        EventBus.getDefault().register(this)
    }

    override fun detachView() {
        super.detachView()
        EventBus.getDefault().unregister(this)
    }

    @Suppress("UNUSED_PARAMETER")
    @Subscribe
    fun onEvent(event: MassMessageEditSuccessEvent) {
        ifViewAttached { view ->
            view.loadData(true)
        }
    }
}
