package com.weiyoubot.client.feature.massmessage.view

import android.content.Intent
import android.os.Bundle
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import butterknife.BindView
import butterknife.ButterKnife
import butterknife.Unbinder
import com.scwang.smartrefresh.layout.SmartRefreshLayout
import com.scwang.smartrefresh.layout.footer.BallPulseFooter
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.fragment.BaseLceFragment
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.view.SmartRefreshLayoutHeader
import com.weiyoubot.client.feature.massmessage.MassMessageConstant
import com.weiyoubot.client.feature.massmessage.adapter.MassMessageListAdapter
import com.weiyoubot.client.feature.massmessage.presenter.MassMessageListPresenterAbstract
import com.weiyoubot.client.feature.massmessage.presenter.MassMessageListPresenterTypeGroup
import com.weiyoubot.client.feature.massmessage.presenter.MassMessageListPresenterTypePrivate
import com.weiyoubot.client.model.api.ApiParamKeys
import com.weiyoubot.client.model.bean.massmessage.MassMessageList
import com.weiyoubot.client.model.bean.massmessage.MassMessageListData
import java.util.*

/**
 * Created by pgao on 2017/12/7.
 */

class MassMessageListFragment : BaseLceFragment<SmartRefreshLayout, MassMessageList, MassMessageListMvpView, MassMessageListPresenterAbstract>(), MassMessageListMvpView, MassMessageListAdapter.MassMessageListListener {
    private var mLastMid: String? = null
    private lateinit var massMessageListAdapter: MassMessageListAdapter
    private var mMassMessageSettings: MassMessageList = MassMessageList()
    private lateinit var unbinder: Unbinder
    private var mMassType = MassMessageConstant.MASS_TYPE_GROUP
    private var mRid: String = ""
    private var mCount: Int = 2

    @BindView(R.id.mass_message_list)
    lateinit var mMassMessageList: RecyclerView

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        val view = inflater.inflate(R.layout.mass_message_list_fragment, container, false)
        unbinder = ButterKnife.bind(this, view)
        return view
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        arguments?.let {
            mMassType = it.getInt(MassMessageConstant.INTENT_KEY_MASS_TYPE, MassMessageConstant.MASS_TYPE_GROUP)
            mRid = it.getString(MassMessageConstant.INTENT_KEY_RID)
        }
        contentView.setRefreshHeader(SmartRefreshLayoutHeader(context))
        val footer = BallPulseFooter(context!!)
        footer.setAnimatingColor(Utils.getColor(R.color.common_blue_color))
        contentView.setRefreshFooter(footer)
        contentView.setOnRefreshListener {
            mLastMid = null
            loadData(true)
        }
        contentView.setOnLoadMoreListener { loadData(true) }

        massMessageListAdapter = MassMessageListAdapter(context!!, this)
        mMassMessageList.layoutManager = LinearLayoutManager(context)
        mMassMessageList.adapter = massMessageListAdapter

        loadData(false)
    }

    override fun createPresenter(): MassMessageListPresenterAbstract {
        arguments?.let {
            if (it.getInt(MassMessageConstant.INTENT_KEY_MASS_TYPE, MassMessageConstant.MASS_TYPE_GROUP) == MassMessageConstant.MASS_TYPE_PRIVATE) {
                val privatePresenter = MassMessageListPresenterTypePrivate()
                privatePresenter.mRid = it.getString(MassMessageConstant.INTENT_KEY_RID)
                return privatePresenter
            }
        }
        return MassMessageListPresenterTypeGroup()
    }

    override fun setData(data: MassMessageList) {
        contentView.finishRefresh()
        contentView.finishLoadMore()
        val massMessageCount = data.data.size
        mCount=data.max_mass_content_count;
        if (massMessageCount > 0) {
            if (mLastMid == null) {
                mMassMessageSettings.data.clear()
            }
            mLastMid = data.data[massMessageCount - 1].mmid
            contentView.setEnableLoadMore(true)
        } else {
            contentView.setEnableLoadMore(false)
        }
        mMassMessageSettings.data.addAll(data.data)
        massMessageListAdapter.data = mMassMessageSettings
        massMessageListAdapter.notifyDataSetChanged()
    }

    override fun loadData(pullToRefresh: Boolean) {
        val params = mutableMapOf<String, Any>()
        params[ApiParamKeys.COUNT] = 10
        mLastMid?.let { it ->
            params[ApiParamKeys.MMID] = it
        }
        if (mMassType == MassMessageConstant.MASS_TYPE_PRIVATE) {
            params[ApiParamKeys.RID] = mRid
        }
        presenter.loadData(pullToRefresh, params)
    }

    override fun addNewMassMessage() {
        val intent = Intent(context, MassMessageRecordEditActivity::class.java)
        intent.putExtra(MassMessageConstant.INTENT_KEY_MASS_TYPE, mMassType)
        intent.putExtra(MassMessageConstant.INTENT_KEY_RID, mRid)
        intent.putExtra(MassMessageConstant.MAX_COUNT, mCount)
        startActivity(intent)
    }

    override fun onSwitchOnOff(massMessageListData: MassMessageListData) {
        val status = if (massMessageListData.status == 0) 1 else 0
        presenter.switchOnOffMassMessage(massMessageListData, status)
    }

    override fun onEdit(massMessageListData: MassMessageListData) {
        val intent = Intent(context, MassMessageRecordEditActivity::class.java)
        intent.putExtra(MassMessageConstant.INTENT_KEY_MASS_MMID, massMessageListData.mmid)
        intent.putExtra(MassMessageConstant.INTENT_KEY_MASS_TYPE, mMassType)
        intent.putExtra(MassMessageConstant.INTENT_KEY_RID, mRid)
        intent.putExtra(MassMessageConstant.MAX_COUNT, mCount)
        startActivity(intent)
    }

    override fun onDelete(massMessageListData: MassMessageListData) {
        presenter.deleteMassMessage(massMessageListData)
    }

    override fun deleteMassMessageSuccess(mmid: String) {
        val datas = ArrayList<MassMessageListData>()
        for (data in mMassMessageSettings.data) {
            if (!TextUtils.equals(data.mmid, mmid)) {
                datas.add(data)
            }
        }
        mMassMessageSettings.data = datas
        massMessageListAdapter.data = mMassMessageSettings
        massMessageListAdapter.notifyDataSetChanged()
    }

    override fun switchOnOffMassMessageSuccess(massMessageListData: MassMessageListData, status: Int) {
        for (data in mMassMessageSettings.data) {
            if (data.mmid === massMessageListData.mmid) {
                data.status = status
            }
        }
        massMessageListAdapter.notifyDataSetChanged()
    }

    override fun clearLastMid() {
        mLastMid = null
    }

    override fun onDestroyView() {
        super.onDestroyView()
        unbinder.unbind()
    }
}
