package com.weiyoubot.client.feature.massmessage.view

import android.annotation.SuppressLint
import android.app.DatePickerDialog
import android.content.Intent
import android.os.Bundle
import android.support.v7.app.AlertDialog
import android.support.v7.widget.RecyclerView
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.RadioGroup
import android.widget.TextView
import butterknife.BindView
import butterknife.ButterKnife
import butterknife.OnClick
import butterknife.Unbinder
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.fragment.BaseLceFragment
import com.weiyoubot.client.common.utils.DateUtils
import com.weiyoubot.client.common.view.recyclerviewmanager.FullyLinearLayoutManager
import com.weiyoubot.client.feature.massmessage.MassMessageConstant
import com.weiyoubot.client.feature.massmessage.adapter.MassMessageRecordAdapterTypePrivate
import com.weiyoubot.client.feature.massmessage.presenter.MassMessageRecordPresenterTypePrivate
import com.weiyoubot.client.model.api.ApiParamKeys
import com.weiyoubot.client.model.bean.massmessage.MassMessageRecordDataTypePrivate
import com.weiyoubot.client.model.bean.massmessage.MassMessageRecordTypePrivate
import java.text.ParseException
import java.text.SimpleDateFormat
import java.util.*

/**
 * Created by root on 6/27/17.
 */
class MassMessageRecordFragmentTypePrivate : BaseLceFragment<RecyclerView, MassMessageRecordTypePrivate, MassMessageRecordMvpViewTypePrivate, MassMessageRecordPresenterTypePrivate>(),
        MassMessageRecordMvpViewTypePrivate, MassMessageRecordAdapterTypePrivate.MassMessageRecordListener {

    private lateinit var mMassMessageSettingsTypePrivate: MassMessageRecordTypePrivate
    private lateinit var mAdapter: MassMessageRecordAdapterTypePrivate
    private lateinit var mRid: String

    private var mTimeInMillis: Long = 0

    private lateinit var unbinder: Unbinder

    @BindView(R.id.day)
    lateinit var mDay: TextView

    private val day: String
        get() = mDay.text.toString()

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        val view = inflater.inflate(R.layout.mass_message_record_fragment, container, false)
        unbinder = ButterKnife.bind(this, view)
        return view
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        mRid = arguments!!.getString(MassMessageConstant.INTENT_KEY_RID)
        mAdapter = MassMessageRecordAdapterTypePrivate(context!!, this)
        contentView.layoutManager = FullyLinearLayoutManager(activity)
        contentView.adapter = mAdapter

        mTimeInMillis = DateUtils.getToadyTimeInMillis()
        updateDay()
    }

    private fun updateDay() {
        val newDay = DateUtils.formatDate("yyyy-MM-dd", mTimeInMillis)
        if (!TextUtils.equals(day, newDay)) {
            mDay.text = newDay
            loadData(false)
        }
    }

    override fun createPresenter(): MassMessageRecordPresenterTypePrivate {
        return MassMessageRecordPresenterTypePrivate()
    }

    override fun loadData(pullToRefresh: Boolean) {
        val params = HashMap<String, Any>()
        try {
            val timestamp = SimpleDateFormat("yyyy-MM-dd", Locale.getDefault()).parse(day).time / 1000
            params[ApiParamKeys.TIME] = timestamp
            params[ApiParamKeys.RID] = mRid
        } catch (e: ParseException) {
            e.printStackTrace()
        }
        presenter.loadData(pullToRefresh, params)
    }

    override fun setData(data: MassMessageRecordTypePrivate) {
        mMassMessageSettingsTypePrivate = data
        mAdapter.data = mMassMessageSettingsTypePrivate
        mAdapter.notifyDataSetChanged()
    }

    @OnClick(R.id.prev_day, R.id.calendar, R.id.next_day)
    fun onClick(view: View) {
        when (view.id) {
            R.id.prev_day -> {
                mTimeInMillis -= DateUtils.ONE_DAY_MILLISECONDS
                updateDay()
            }
            R.id.calendar -> {
                val calendar = DateUtils.getCalendar()
                calendar.timeInMillis = mTimeInMillis
                DatePickerDialog(activity!!, DatePickerDialog.OnDateSetListener { _, year, monthOfYear, dayOfMonth ->
                    calendar.set(Calendar.YEAR, year)
                    calendar.set(Calendar.MONTH, monthOfYear)
                    calendar.set(Calendar.DAY_OF_MONTH, dayOfMonth)
                    mTimeInMillis = calendar.timeInMillis
                    updateDay()
                }, calendar.get(Calendar.YEAR), calendar.get(Calendar.MONTH), calendar.get(Calendar.DAY_OF_MONTH)).show()
            }
            R.id.next_day -> {
                mTimeInMillis += DateUtils.ONE_DAY_MILLISECONDS
                updateDay()
            }
        }
    }

    override fun edit(massMessageListData: MassMessageRecordDataTypePrivate) {
        val intent = Intent(activity, MassMessageRecordEditActivity::class.java)
        intent.putExtra(MassMessageConstant.INTENT_KEY_MASS_MMID, massMessageListData.mmid)
        intent.putExtra(MassMessageConstant.INTENT_KEY_MASS_TYPE, MassMessageConstant.MASS_TYPE_PRIVATE)
        intent.putExtra(MassMessageConstant.INTENT_KEY_RID, mRid)
        startActivity(intent)
    }

    override fun refresh(massMessageListData: MassMessageRecordDataTypePrivate) {
        loadData(true)
    }

    override fun resend(massMessageListData: MassMessageRecordDataTypePrivate) {
        try {
            val timestamp = SimpleDateFormat("yyyy-MM-dd", Locale.getDefault()).parse(day).time / 1000
            presenter.resendMassMessage(massMessageListData.mmid, timestamp)
        } catch (e: ParseException) {
            e.printStackTrace()
        }

    }

    override fun resendMassMessageSuccess() {
        loadData(true)
    }

    @SuppressLint("InflateParams")
    override fun delete(massMessageListData: MassMessageRecordDataTypePrivate) {
        if (massMessageListData.repeat == 0) {
            // 非重复消息
            AlertDialog.Builder(activity!!).setTitle(R.string.dialog_title).setMessage(R.string.delete_confirm).setPositiveButton(R.string.ok) { _, _ ->
                try {
                    val timestamp = SimpleDateFormat("yyyy-MM-dd", Locale.getDefault()).parse(day).time / 1000
                    presenter.deleteMassMessage(massMessageListData, timestamp, 0, mRid)
                } catch (e: ParseException) {
                    e.printStackTrace()
                }
            }.setNegativeButton(R.string.cancel, null).show()
        } else {
            // 重复消息
            val view = LayoutInflater.from(activity).inflate(R.layout.mass_message_repeat_delete_dialog_view, null)
            val radioGroup = view.findViewById<View>(R.id.radio_group) as RadioGroup
            radioGroup.check(R.id.delete_one)
            AlertDialog.Builder(activity!!).setView(view).setPositiveButton(R.string.ok) { _, _ ->
                try {
                    val type = if (radioGroup.checkedRadioButtonId == R.id.delete_one) 0 else 1
                    val timestamp = SimpleDateFormat("yyyy-MM-dd", Locale.getDefault()).parse(day).time / 1000
                    presenter.deleteMassMessage(massMessageListData, timestamp, type, mRid)
                } catch (e: ParseException) {
                    e.printStackTrace()
                }
            }.setNegativeButton(R.string.cancel, null).show()
        }
    }

    override fun deleteMassMessageSuccess(massMessageListData: MassMessageRecordDataTypePrivate) {
        mMassMessageSettingsTypePrivate.data.remove(massMessageListData)
        mAdapter.notifyDataSetChanged()
    }

    override fun onDestroyView() {
        super.onDestroyView()
        unbinder.unbind()
    }
}
