package com.weiyoubot.client.feature.massmessage.view

import android.os.Bundle
import android.view.View
import android.view.View.GONE
import android.view.View.VISIBLE
import android.widget.ExpandableListView
import android.widget.RadioGroup
import android.widget.TextView
import butterknife.BindView
import butterknife.ButterKnife
import butterknife.OnClick
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.activity.BaseLceActivity
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.view.ClearableEditText
import com.weiyoubot.client.feature.massmessage.MassMessageConstant
import com.weiyoubot.client.feature.massmessage.MassMessageSelectFriendsEvent
import com.weiyoubot.client.feature.massmessage.adapter.MassMessageSelectFriendsGroupingAdapter
import com.weiyoubot.client.feature.massmessage.adapter.MassMessageSelectFriendsLabelAdapter
import com.weiyoubot.client.feature.massmessage.presenter.MassMessageSelectFriendsPresenter
import com.weiyoubot.client.model.api.ApiParamKeys
import com.weiyoubot.client.model.bean.massmessage.MassMessageFriend
import com.weiyoubot.client.model.bean.massmessage.MassMessageFriendData
import com.weiyoubot.client.model.bean.massmessage.MassMessageFriendGrouping
import org.greenrobot.eventbus.EventBus
import java.util.*

/**
 * Created by root on 10/31/16.
 */
class MassMessageSelectFriendsActivity : BaseLceActivity<ExpandableListView, MassMessageFriend, MassMessageSelectFriendsMvpView, MassMessageSelectFriendsPresenter>(),
        MassMessageSelectFriendsMvpView, RadioGroup.OnCheckedChangeListener, SelectChangedListener, ClearableEditText.TextClearedListener {
    private lateinit var mRid: String
    private lateinit var mMmid: String
    private var mFriendListType = MassMessageConstant.MASS_PRIVATE_FRIENDS_MODE_GROUPING
    private var mSelectedFriends: MutableList<String> = mutableListOf()
    private var mSelectedInit = false
    private lateinit var mGroupingAdapter: MassMessageSelectFriendsGroupingAdapter
    private lateinit var mLabelAdapter: MassMessageSelectFriendsLabelAdapter
    private lateinit var mSearchAdapter: MassMessageSelectFriendsGroupingAdapter
    private var mMaxSelectCount = 1000

    @BindView(R.id.friend_name_input)
    lateinit var mFriendNameInput: ClearableEditText
    @BindView(R.id.trigger_type_friends)
    lateinit var mFriendsTypeGroup: RadioGroup
    @BindView(R.id.selected_count)
    lateinit var mSelectedCount: TextView

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.mass_message_private_select_friends)
        ButterKnife.bind(this)

        mRid = intent.getStringExtra(MassMessageConstant.INTENT_KEY_RID)
        mMmid = intent.getStringExtra(MassMessageConstant.INTENT_KEY_MASS_MMID)
        mFriendListType = intent.getIntExtra(MassMessageConstant.INTENT_KEY_FRIENDS_MODE, MassMessageConstant.MASS_PRIVATE_FRIENDS_MODE_GROUPING)
        mSelectedFriends = intent.getStringArrayListExtra(MassMessageConstant.INTENT_KEY_SELCTED_FRIENDS)
        mSelectedInit = intent.getBooleanExtra(MassMessageConstant.INTENT_KEY_SELCTED_INIT, false)
        mGroupingAdapter = MassMessageSelectFriendsGroupingAdapter(this, this)
        mLabelAdapter = MassMessageSelectFriendsLabelAdapter(this, this)
        mSearchAdapter = MassMessageSelectFriendsGroupingAdapter(this, this)
        contentView.setAdapter(if (mFriendListType == MassMessageConstant.MASS_PRIVATE_FRIENDS_MODE_GROUPING) mGroupingAdapter else mLabelAdapter)
        mFriendNameInput.setTextClearedListener(this)
        loadData(false)
    }

    override fun loadData(pullToRefresh: Boolean) {
        val params = HashMap<String, Any>()
        params[ApiParamKeys.RID] = mRid
        params[ApiParamKeys.MMID] = mMmid
        params[ApiParamKeys.TYPE] = MassMessageConstant.MASS_PRIVATE_FRIENDS_MODE_ALL
        presenter.loadData(false, params)
    }


    override fun setData(data: MassMessageFriend) {
        mFriendsTypeGroup.check(if (mFriendListType == MassMessageConstant.MASS_PRIVATE_FRIENDS_MODE_GROUPING) R.id.type_grouping else R.id.type_label)
        mFriendsTypeGroup.setOnCheckedChangeListener(this)
        if (mSelectedFriends.size > 0 || mSelectedInit) {
            for (group in data.data.friendGrouping) {
                for (contact in group.list) {
                    contact.status = if (mSelectedFriends.contains(contact.cid)) 1 else 0
                }
            }
            for (label in data.data.friendLabelClass) {
                for (contact in label.list) {
                    contact.status = if (mSelectedFriends.contains(contact.cid)) 1 else 0
                }
            }
        } else {
            for (group in data.data.friendLabelClass) {
                for (contact in group.list) {
                    if (contact.status == 1) {
                        mSelectedFriends.add(contact.cid)
                    }
                }
            }
        }
        mGroupingAdapter.data = data.data.friendGrouping
        mLabelAdapter.data = data.data.friendLabelClass
        if (mFriendListType == MassMessageConstant.MASS_PRIVATE_FRIENDS_MODE_GROUPING) {
            mGroupingAdapter.notifyDataSetChanged()
        } else {
            mLabelAdapter.notifyDataSetChanged()
        }
        mSelectedCount.text = Utils.getString(R.string.mass_message_select_friends_tips, mSelectedFriends.size)
        mMaxSelectCount = data.maxSelectedNum
    }

    override fun createPresenter(): MassMessageSelectFriendsPresenter {
        return MassMessageSelectFriendsPresenter()
    }

    @OnClick(R.id.back, R.id.search, R.id.confirm)
    fun onClick(view: View) {
        when (view.id) {
            R.id.back -> finish()
            R.id.confirm -> {
                val massMessageFriendData = MassMessageFriendData()
                massMessageFriendData.friendListType = mFriendListType
                massMessageFriendData.friendGrouping = mGroupingAdapter.data
                massMessageFriendData.friendLabelClass = mLabelAdapter.data
                EventBus.getDefault().post(MassMessageSelectFriendsEvent(massMessageFriendData))
                finish()
            }
            R.id.search -> {
                if (mFriendNameInput.text.trim().isNotEmpty()) {
                    mFriendsTypeGroup.visibility = GONE
                    mSearchAdapter.data = mutableListOf(MassMessageFriendGrouping(groupingNum = -1))
                    for (group in mGroupingAdapter.data) {
                        for (contact in group.list) {
                            if (contact.name.indexOf(mFriendNameInput.text.toString()) >= 0) {
                                mSearchAdapter.data[0].list.add(contact)
                            }
                        }
                    }
                    contentView.setAdapter(mSearchAdapter)
                    mSearchAdapter.notifyDataSetChanged()
                    contentView.expandGroup(0)
                }
            }
        }
    }

    private fun updateSelected() {
        for (item in mGroupingAdapter.data) {
            for (contact in item.list) {
                contact.status = if (mSelectedFriends.contains(contact.cid)) 1 else 0
            }
        }
        for (item in mLabelAdapter.data) {
            for (contact in item.list) {
                contact.status = if (mSelectedFriends.contains(contact.cid)) 1 else 0
            }
        }
        for (item in mSearchAdapter.data) {
            for (contact in item.list) {
                contact.status = if (mSelectedFriends.contains(contact.cid)) 1 else 0
            }
        }
    }

    override fun onCheckedChanged(group: RadioGroup?, checkedId: Int) {
        if (checkedId == R.id.type_grouping) {
            mFriendListType = MassMessageConstant.MASS_PRIVATE_FRIENDS_MODE_GROUPING
            contentView.setAdapter(mGroupingAdapter)
            mGroupingAdapter.notifyDataSetChanged()
        } else {
            mFriendListType = MassMessageConstant.MASS_PRIVATE_FRIENDS_MODE_LABEL
            contentView.setAdapter(mLabelAdapter)
            mLabelAdapter.notifyDataSetChanged()
        }
    }

    override fun onSelectChanged(contactIds: MutableList<String>, isSelected: Boolean) {
        if (isSelected) {
            mSelectedFriends.addAll(contactIds)
            mSelectedFriends = (mSelectedFriends.distinct()).toMutableList()
            if (mSelectedFriends.size >= mMaxSelectCount) {
                mSelectedFriends = (mSelectedFriends.take(mMaxSelectCount)).toMutableList()
            }
        } else {
            mSelectedFriends.removeAll(contactIds)
        }
        mSelectedCount.text = Utils.getString(R.string.mass_message_select_friends_tips, mSelectedFriends.size)
        updateSelected()
        if (mFriendListType == MassMessageConstant.MASS_PRIVATE_FRIENDS_MODE_GROUPING) {
            mGroupingAdapter.notifyDataSetChanged()
            mSearchAdapter.notifyDataSetChanged()
        } else {
            mLabelAdapter.notifyDataSetChanged()
        }
    }


    override fun changeGroupExpand(groupId: Int, isExpand: Boolean) {
        if (isExpand) {
            contentView.expandGroup(groupId)
        } else {
            contentView.collapseGroup(groupId)
        }
    }

    override fun onClear() {
        mFriendsTypeGroup.visibility = VISIBLE
        if (mFriendListType == MassMessageConstant.MASS_PRIVATE_FRIENDS_MODE_GROUPING) {
            contentView.setAdapter(mGroupingAdapter)
            mGroupingAdapter.notifyDataSetChanged()
        } else {
            contentView.setAdapter(mLabelAdapter)
            mLabelAdapter.notifyDataSetChanged()
        }
    }
}

interface SelectChangedListener {
    fun onSelectChanged(contactIds: MutableList<String>, isSelected: Boolean)
    fun changeGroupExpand(groupId: Int, isExpand: Boolean)
}
