package com.weiyoubot.client.feature.material.video.adapter

import android.annotation.SuppressLint
import android.content.Context
import android.text.TextUtils
import android.util.TypedValue
import android.view.Gravity
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup.LayoutParams.MATCH_PARENT
import android.widget.LinearLayout
import android.widget.LinearLayout.LayoutParams
import android.widget.TextView
import com.hannesdorfmann.annotatedadapter.annotation.ViewField
import com.hannesdorfmann.annotatedadapter.annotation.ViewType
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.AnnotatedAdapter
import com.weiyoubot.client.common.utils.DateUtils
import com.weiyoubot.client.common.utils.ImageUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.feature.material.video.MaterialVideoListener
import com.weiyoubot.client.model.bean.material.MaterialData
import kotlinx.android.synthetic.main.material_action_item_view.view.*
import kotlinx.android.synthetic.main.material_video_item_view.view.*

/**
 * Created by root on 11/8/16.
 */
class MaterialTempVideoTableAdapter(context: Context, private val mMaterialVideoListener: MaterialVideoListener) : AnnotatedAdapter<List<MaterialData>>(context), MaterialTempVideoTableAdapterBinder, View.OnClickListener {
    companion object {
        @ViewType(
                layout = R.layout.table_row_view,
                views = [
                    ViewField(id = R.id.table_row_view, name = "tableRowView", type = LinearLayout::class)
                ])
        const val VIEW_TYPE_ROW = 0
    }

    override lateinit var data: List<MaterialData>
    private val mItemPadding = Utils.getDimen(R.dimen.x10)

    override fun bindViewHolder(vh: MaterialTempVideoTableAdapterHolders.VIEW_TYPE_ROWViewHolder, position: Int) {
        vh.tableRowView.removeAllViews()
        val weightListTemp = intArrayOf(4, 3, 4, 2)
        if (position == 0) {
            val headerTextIds = intArrayOf(R.string.material_video, R.string.material_size, R.string.material_time, R.string.material_operation)
            for (i in 0..3) {
                val textView = createTableItemView(true)
                textView.setText(headerTextIds[i])
                vh.tableRowView.addView(textView, LayoutParams(0, MATCH_PARENT, weightListTemp[i].toFloat()))
            }
        } else {
            if (Utils.isListEmpty(data)) {
                val textView = createTableItemView(false)
                textView.setText(R.string.data_empty)
                vh.tableRowView.addView(textView, LayoutParams(0, MATCH_PARENT, 1f))
            } else {
                val mate = data[position - 1]
                vh.tableRowView.addView(createTableVideoItemView(mate), LayoutParams(0, MATCH_PARENT, weightListTemp[0].toFloat()))
                val videoSizeView = createTableItemView(false)
                videoSizeView.text = Utils.getStorage(mate.mate.length)
                vh.tableRowView.addView(videoSizeView, LayoutParams(0, MATCH_PARENT, weightListTemp[1].toFloat()))
                val videoTimeView = createTableItemView(false)
                videoTimeView.text = DateUtils.formatDate("yyyy/MM/dd", mate.mate.time * 1000)
                vh.tableRowView.addView(videoTimeView, LayoutParams(0, MATCH_PARENT, weightListTemp[2].toFloat()))
                vh.tableRowView.addView(createTableActionItemView(mate), LayoutParams(0, MATCH_PARENT, weightListTemp[3].toFloat()))
            }
        }
    }

    override fun getItemCount(): Int {
        return if (Utils.isListEmpty(data)) 2 else Utils.getListCount(data) + 1
    }

    private fun createTableItemView(isHeader: Boolean): TextView {
        val textView = TextView(mContext)
        textView.setBackgroundResource(if (isHeader) R.drawable.rect_solid_ee_stroke_e0_bg else R.drawable.rect_solid_ff_stroke_e0_bg)
        textView.setTextColor(Utils.getColor(if (isHeader) R.color.common_color_40 else R.color.common_color_9a))
        textView.setTextSize(TypedValue.COMPLEX_UNIT_PX, Utils.getDimen(R.dimen.x24).toFloat())
        textView.setPadding(mItemPadding, mItemPadding, mItemPadding, mItemPadding)
        textView.gravity = Gravity.CENTER
        textView.setSingleLine()
        textView.ellipsize = TextUtils.TruncateAt.END
        return textView
    }

    @SuppressLint("InflateParams")
    private fun createTableVideoItemView(mate: MaterialData): View {
        val view = LayoutInflater.from(mContext).inflate(R.layout.material_video_item_view, null)
        ImageUtils.setImage(mContext, view.video_image, mate.mate.thumb)
        view.play.tag = mate
        view.play.setOnClickListener(this)
        val padding = Utils.getDimen(R.dimen.x16)
        view.setPadding(padding, padding, padding, padding)
        return view
    }

    @SuppressLint("InflateParams")
    private fun createTableActionItemView(mate: MaterialData): View {
        val view = LayoutInflater.from(mContext).inflate(R.layout.material_action_item_view, null)
        view.fav.tag = mate
        view.fav.setOnClickListener(this)
        view.delete.tag = mate
        view.delete.setOnClickListener(this)
        return view
    }

    override fun onClick(v: View) {
        val mate = v.tag as MaterialData
        when (v.id) {
            R.id.fav -> mMaterialVideoListener.favMaterial(mate)
            R.id.delete -> mMaterialVideoListener.deleteMaterial(mate)
            R.id.play -> mMaterialVideoListener.playVideo(mate)
        }
    }
}
