package com.weiyoubot.client.feature.material.video.presenter

import android.annotation.SuppressLint
import android.content.Context
import android.content.DialogInterface
import android.support.v7.app.AlertDialog
import android.view.LayoutInflater
import android.view.View
import android.widget.EditText
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.BaseLcePresenter
import com.weiyoubot.client.common.utils.UIUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.feature.material.MaterialHelper
import com.weiyoubot.client.feature.material.video.view.MaterialVideoMvpView
import com.weiyoubot.client.model.apikt.ApiClient
import com.weiyoubot.client.model.bean.material.Material
import com.weiyoubot.client.model.bean.material.MaterialData
import com.weiyoubot.client.model.bean.material.MaterialName
import com.weiyoubot.client.model.loader.OnDataLoadListener
import kotlinx.android.synthetic.main.modify_material_name.view.*
import org.json.JSONException

/**
 * Created by root on 11/15/16.
 */
class MaterialVideoPresenter : BaseLcePresenter<Material, MaterialVideoMvpView>() {
    override fun loadData(pullToRefresh: Boolean, params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        MaterialHelper.loadMaterial(params, listener)
    }

    @SuppressLint("InflateParams")
    fun saveTempVideoMaterial(context: Context, tempMate: MaterialData) {
        val view = LayoutInflater.from(context).inflate(R.layout.modify_material_name, null)
        val editText = view.findViewById<View>(R.id.edit_name) as EditText
        editText.setText(tempMate.mate.title)
        editText.setSelection(editText.length())
        editText.setHint(R.string.material_video_name_title)
        AlertDialog.Builder(context).setView(view).setTitle(Utils.getString(R.string.material_video_name_title)).setPositiveButton(R.string.ok, DialogInterface.OnClickListener { _, _ ->
            if (editText.length() == 0) {
                UIUtils.showToast(R.string.material_rename_tips)
                return@OnClickListener
            }
            val materialName = MaterialName()
            materialName.mid = tempMate.mid
            materialName.name = view.edit_name.text.toString()
            val materialNames = ArrayList<MaterialName>()
            materialNames.add(materialName)
            try {
                ApiClient.renameMaterialVideo(materialNames, object : OnDataLoadListener {
                    override fun onDataLoaded(data: Any) {
                        ApiClient.addMaterialVideo(tempMate.mid, object : OnDataLoadListener {
                            override fun onDataLoaded(data: Any) {
                                ifViewAttached {
                                    it.loadData(true)
                                }
                            }

                            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                                ifViewAttached {
                                    UIUtils.showFailedToast(R.string.material_video_attach_add_failed, errorMessage)
                                }
                            }
                        })
                    }

                    override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                        UIUtils.showToast(R.string.material_video_rename_failed)
                    }
                })
            } catch (e: JSONException) {
                e.printStackTrace()
            }
        }).setNegativeButton(R.string.cancel, null).setCancelable(false).show()
    }

    @SuppressLint("InflateParams")
    fun renameVideo(context: Context, mate: MaterialData) {
        val view = LayoutInflater.from(context).inflate(R.layout.modify_material_name, null)
        view.edit_name.setText(mate.mate.title)
        view.edit_name.setSelection(view.edit_name.length())
        view.edit_name.setHint(R.string.material_video_name_title)
        AlertDialog.Builder(context).setView(view).setTitle(Utils.getString(R.string.material_video_name_title))
                .setPositiveButton(R.string.ok, DialogInterface.OnClickListener { _, _ ->
                    if (view.edit_name.length() == 0) {
                        UIUtils.showToast(R.string.material_rename_tips)
                        return@OnClickListener
                    }
                    val materialName = MaterialName()
                    materialName.mid = mate.mid
                    materialName.name = view.edit_name.text.toString()
                    val materialNames = ArrayList<MaterialName>()
                    materialNames.add(materialName)
                    try {
                        ApiClient.renameMaterialVideo(materialNames, object : OnDataLoadListener {
                            override fun onDataLoaded(data: Any) {
                                ifViewAttached {
                                    it.loadData(false)
                                    UIUtils.showToast(R.string.material_video_rename_success)
                                }
                            }

                            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                                ifViewAttached {
                                    UIUtils.showToast(R.string.material_video_rename_failed)
                                }
                            }
                        })
                    } catch (e: JSONException) {
                        e.printStackTrace()
                    }
                }).setNegativeButton(R.string.cancel, null).setCancelable(false).show()
    }

    fun deleteVideoMaterial(context: Context, mate: MaterialData) {
        MaterialHelper.deleteMaterial(context, mate.mid, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached {
                    it.loadData(true)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached {
                    UIUtils.showFailedToast(R.string.material_video_delete_failed, errorMessage)
                }
            }
        })
    }

    fun deleteUsedVideo(context: Context, tempMate: MaterialData) {
        MaterialHelper.deleteUsedMaterial(context, tempMate.mid, object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                ifViewAttached {
                    it.loadData(true)
                }
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                ifViewAttached {
                    UIUtils.showFailedToast(R.string.material_video_delete_failed, errorMessage)
                }
            }
        })
    }
}
