package com.weiyoubot.client.feature.material.video.view

import android.content.Intent
import android.net.Uri
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ScrollView
import com.weiyoubot.client.R
import com.weiyoubot.client.basekt.fragment.BaseLceFragment
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.view.recyclerviewmanager.FullyLinearLayoutManager
import com.weiyoubot.client.feature.material.MaterialConstant
import com.weiyoubot.client.feature.material.video.MaterialVideoListener
import com.weiyoubot.client.feature.material.video.adapter.MaterialSavedVideoTableAdapter
import com.weiyoubot.client.feature.material.video.adapter.MaterialTempVideoTableAdapter
import com.weiyoubot.client.feature.material.video.presenter.MaterialVideoPresenter
import com.weiyoubot.client.model.api.ApiParamKeys
import com.weiyoubot.client.model.bean.material.Material
import com.weiyoubot.client.model.bean.material.MaterialData
import kotlinx.android.synthetic.main.material_video_fragment.*
import kotlinx.android.synthetic.main.menu_fragment.*
import java.util.*


/**
 * Created by root on 11/14/16.
 */
class MaterialVideoFragment : BaseLceFragment<ScrollView, Material, MaterialVideoMvpView, MaterialVideoPresenter>(), MaterialVideoMvpView, MaterialVideoListener {
    private val mVoiceTempMaterials = mutableListOf<MaterialData>()
    private val mVoiceSavedMaterials = mutableListOf<MaterialData>()
    private lateinit var mTempTableAdapter: MaterialTempVideoTableAdapter
    private lateinit var mSavedTableAdapter: MaterialSavedVideoTableAdapter

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        return inflater.inflate(R.layout.material_video_fragment, container, false)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        val addDrawableSize = Utils.getDimen(R.dimen.x24)
        val addDrawable = Utils.getDrawable(R.drawable.refresh_blue)
        addDrawable.setBounds(0, 0, addDrawableSize, addDrawableSize)
        video_list_temp_refresh.setCompoundDrawables(addDrawable, null, null, null)
        video_list_temp_refresh.setOnClickListener {
            loadData(true)
        }

        mTempTableAdapter = MaterialTempVideoTableAdapter(context, this)
        video_list_temp.layoutManager = FullyLinearLayoutManager(activity)
        video_list_temp.adapter = mTempTableAdapter

        mSavedTableAdapter = MaterialSavedVideoTableAdapter(context, this)
        video_list_saved.layoutManager = FullyLinearLayoutManager(activity)
        video_list_saved.adapter = mSavedTableAdapter
        loadData(false)
    }

    override fun createPresenter(): MaterialVideoPresenter {
        return MaterialVideoPresenter()
    }

    override fun loadData(pullToRefresh: Boolean) {
        val params = HashMap<String, Any>()
        params[ApiParamKeys.MTYPE] = ApiParamKeys.MTYPE_VALUE_VIDEO
        presenter.loadData(pullToRefresh, params)
    }

    override fun setData(data: Material) {
        mVoiceTempMaterials.clear()
        mVoiceSavedMaterials.clear()
        for (materialData in data.data) {
            if (materialData.type == MaterialConstant.MATERTIAL_TYPE_TEMP) {
                mVoiceTempMaterials.add(materialData)
            } else if (materialData.type == MaterialConstant.MATERTIAL_TYPE_SAVED) {
                mVoiceSavedMaterials.add(materialData)
            }
        }
        mTempTableAdapter.data = mVoiceTempMaterials
        mTempTableAdapter.notifyDataSetChanged()
        mSavedTableAdapter.data = mVoiceSavedMaterials
        mSavedTableAdapter.notifyDataSetChanged()
        saved_video_tips.text = Utils.getString(R.string.material_video_save_tips, data.config.maxVideoCount)
    }

    override fun favMaterial(mate: MaterialData) {
        presenter.saveTempVideoMaterial(context, mate)
    }

    override fun deleteMaterial(mate: MaterialData) {
        if (mate.needAlert == 1) {
            presenter.deleteUsedVideo(context, mate)
        } else {
            presenter.deleteVideoMaterial(context, mate)
        }
    }

    override fun playVideo(mate: MaterialData) {
        val intent = Intent(Intent.ACTION_VIEW)
        intent.setDataAndType(Uri.parse(mate.mate.url), "video/mp4")
        startActivity(intent)
    }

    override fun renameVoice(mate: MaterialData) {
        presenter.renameVideo(context, mate)
    }
}
