package com.weiyoubot.client.feature.robots.view

import android.content.Intent
import android.os.Bundle
import android.support.v7.app.AlertDialog
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.View.GONE
import android.view.ViewGroup
import android.widget.AdapterView
import android.widget.LinearLayout.LayoutParams
import com.weiyoubot.client.R
import com.weiyoubot.client.base.fragment.BaseFragment
import com.weiyoubot.client.common.utils.PreferenceUtils
import com.weiyoubot.client.common.utils.Utils
import com.weiyoubot.client.common.utils.makeHtmlString
import com.weiyoubot.client.common.utils.setTextHTML
import com.weiyoubot.client.feature.account.PaymentConstant
import com.weiyoubot.client.feature.account.view.PaymentActivity
import com.weiyoubot.client.feature.main.UserDataConstant
import com.weiyoubot.client.feature.main.UserDataHelper
import com.weiyoubot.client.feature.robotprivate.bean.RobotPrivate
import com.weiyoubot.client.feature.robots.RobotConstant
import com.weiyoubot.client.feature.robots.adapter.RobotsAdapter
import com.weiyoubot.client.model.apikt.ApiClient
import com.weiyoubot.client.model.bean.robotprivate.PersonFuncConfig
import com.weiyoubot.client.model.bean.robotprivate.PersonFuncConfigData
import com.weiyoubot.client.model.bean.robots.RobotData
import com.weiyoubot.client.model.loader.OnDataLoadListener
import kotlinx.android.synthetic.main.robots_private_fragment.*
import java.util.*

/**
 * Created by root on 5/9/17.
 */
class RobotsPrivateFragment : BaseFragment(), AdapterView.OnItemSelectedListener {

    private var mRid: String? = null
    private var mPrivateFuncConfig = PersonFuncConfigData()

    internal var listener: UserDataHelper.RobotInfoChangedListener = UserDataHelper.RobotInfoChangedListener {
        initView()
        initTrialView()
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        return inflater.inflate(R.layout.robots_private_fragment, container, false)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        UserDataHelper.setRobotInfoChangedListener(listener)
        initView()
        initTrialView()
        requestPrivateFuncConfig()
    }

    private fun requestPrivateFuncConfig() {
        ApiClient.requestPersonFuncConfig(object : OnDataLoadListener {
            override fun onDataLoaded(data: Any) {
                mPrivateFuncConfig = (data as PersonFuncConfig).data
                initView()
            }

            override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {

            }
        })
    }

    private fun initView() {
        if (trial_view == null) {
            return
        }
        var robotCount = 0
        mRid = null
        val robotDatas = UserDataHelper.getUserRobots()
        if (robotDatas != null) {
            robotCount = Utils.getListCount(robotDatas)
        }

        when {
            robotCount == 0 -> {
                trial_view.visibility = View.GONE
                robots.visibility = View.GONE
            }
            robotCount == 1 -> {
                trial_view.visibility = View.VISIBLE
                robots.visibility = View.GONE
                mRid = robotDatas[0].robot.rid
                robot_text.text = getText(robotDatas[0])
            }
            Utils.getListCount(robotDatas) > 1 -> {
                trial_view.visibility = View.VISIBLE
                robots.visibility = View.VISIBLE
                robot_text.visibility = GONE
                robot_spinner.visibility = View.VISIBLE
                robot_spinner.adapter = RobotsAdapter(context, robotDatas)
                robot_spinner.onItemSelectedListener = this
                val selectedIndex = getSelectedIndex(robotDatas, PreferenceUtils.getSelectedRobotId())
                robot_spinner.setSelection(selectedIndex)
                robot_text.text = robotDatas[selectedIndex].robot.nickname
                mRid = robotDatas[selectedIndex].robot.rid
            }
        }

        val ids = resources.getIntArray(R.array.robot_private_ids)
        val iconIds = Utils.getResIdsFromArray(R.array.robot_private_icons)
        val titleIds = Utils.getResIdsFromArray(R.array.robot_private_titles)
        val descriptionIds = Utils.getResIdsFromArray(R.array.robot_private_descriptions)
        val tipsIds = Utils.getResIdsFromArray(R.array.robot_private_tips)
        val sampleIds = Utils.getResIdsFromArray(R.array.robot_private_samples)
        val itemHeight = Utils.getDimen(R.dimen.x200)
        content.removeAllViews()
        for (i in ids.indices) {
            val robotPrivate = RobotPrivate(ids[i], iconIds[i], titleIds[i], descriptionIds[i], tipsIds[i], sampleIds[i])
            val itemView = RobotsPrivateItemView(context)
            itemView.bindView(mRid, robotPrivate)
            val params = LayoutParams(LayoutParams.MATCH_PARENT, itemHeight)
            params.bottomMargin = Utils.getDimen(R.dimen.card_content_padding)
            content.addView(itemView, params)

            if (i == 4 && mPrivateFuncConfig.disableMass == 1) {
                itemView.setOnClickListener {
                    AlertDialog.Builder(context)
                            .setTitle(R.string.dialog_title)
                            .setMessage(makeHtmlString(mPrivateFuncConfig.disableMassMsg))
                            .setPositiveButton(R.string.ok, null)
                            .show()
                }
            }
        }
    }

    private fun initTrialView() {
        when (UserDataHelper.getRobotPayStatus(mRid)) {
            UserDataConstant.ROBOT_PERM_FREE -> {
                val trialLeftDays = UserDataHelper.getTrialLeftDays()
                trial_text?.setTextHTML(Utils.getString(R.string.trial_left_days, trialLeftDays))
                buy_now?.text = Utils.getString(R.string.payment_buy_now)
            }
            UserDataConstant.ROBOT_PERM_PAYED -> {
                trial_text?.text = Utils.getString(R.string.private_robot_perm_deadline, UserDataHelper.getPrivateRobotPermDeadline(UserDataHelper.getRobotFromRid(mRid)))
                buy_now?.text = Utils.getString(R.string.payment_renew)
            }
            UserDataConstant.ROBOT_PERM_EXPIRED -> {
                trial_text?.text = Utils.getString(R.string.perm_name_expired)
                buy_now?.text = Utils.getString(R.string.payment_buy_now)
            }
            else -> {
                trial_text?.setTextHTML(Utils.getString(R.string.trial_finished))
                buy_now?.text = Utils.getString(R.string.payment_buy_now)
            }
        }
        buy_now?.setOnClickListener {
            val intent = Intent(activity, PaymentActivity::class.java)
            intent.putExtra(UserDataConstant.INTENT_KEY_PERM_ID, UserDataConstant.PERM_ROBOT_PRIVATE_ALL)
            val rids = ArrayList<String>()
            rids.add(mRid!!)
            intent.putStringArrayListExtra(PaymentConstant.INTENT_KEY_RIDS, rids)
            startActivity(intent)
        }
    }

    override fun onItemSelected(parent: AdapterView<*>, view: View?, position: Int, id: Long) {
        if (view == null) return
        val robotData = robot_spinner.selectedItem as RobotData
        mRid = robotData.robot.rid
        PreferenceUtils.setSelectedRobotId(robotData.robot.rid)
        initTrialView()
        for (index in 0 until content.childCount) {
            val nextChild = content.getChildAt(index) as RobotsPrivateItemView
            nextChild.updateRid(mRid)
        }
    }

    override fun onNothingSelected(parent: AdapterView<*>) {

    }

    private fun getSelectedIndex(robotDatas: List<RobotData>, rid: String): Int {
        val count = Utils.getListCount(robotDatas)
        for (i in 0 until count) {
            val robotData = robotDatas[i]
            if (TextUtils.equals(robotData.robot.rid, rid)) {
                return i
            }
        }
        // 没找到则默认选择第一个
        return 0
    }

    private fun getText(robotData: RobotData): String {
        val status = Utils.getString(if (robotData.robot.status == RobotConstant.STATUS_ONLINE) R.string.robot_status_online else R.string.robot_status_offline)
        return status + " " + robotData.robot.nickname
    }
}
