package com.weiyoubot.client.model.apikt

import com.google.gson.Gson
import com.weiyoubot.client.common.utils.PreferenceUtils
import com.weiyoubot.client.feature.main.UserDataHelper
import com.weiyoubot.client.model.bean.StatusResult
import com.weiyoubot.client.model.bean.complaint.exit.ComplaintExit
import com.weiyoubot.client.model.bean.complaint.exit.Exit
import com.weiyoubot.client.model.bean.complaint.latest.ComplaintLatest
import com.weiyoubot.client.model.bean.complaint.latest.Latest
import com.weiyoubot.client.model.bean.complaint.suspect.ComplaintSuspect
import com.weiyoubot.client.model.bean.massmessage.*
import com.weiyoubot.client.model.bean.material.MaterialName
import com.weiyoubot.client.model.bean.member.all.MemberAll
import com.weiyoubot.client.model.bean.member.all.ModifyLevel
import com.weiyoubot.client.model.bean.member.inactive.MemberInactive
import com.weiyoubot.client.model.bean.member.inviter.MemberInviter
import com.weiyoubot.client.model.bean.robotprivate.PersonFuncConfig
import com.weiyoubot.client.model.bean.settings.DiagnosticSend
import com.weiyoubot.client.model.bean.statistics.all.StatisticsAll
import com.weiyoubot.client.model.bean.statistics.history.StatisticsHistory
import com.weiyoubot.client.model.loader.OnDataLoadListener
import io.reactivex.Observable
import okhttp3.MediaType
import okhttp3.RequestBody
import org.json.JSONArray
import org.json.JSONException
import org.json.JSONObject
import retrofit2.http.Body
import retrofit2.http.GET
import retrofit2.http.POST
import retrofit2.http.QueryMap

//@Suppress("unused")
object ApiClient : BaseApiClient() {
    private val sIPadService: ApiIpadService = createRetrofit(defaultIPadApiHost).create<ApiClient.ApiIpadService>(ApiClient.ApiIpadService::class.java)

    private const val IPAD_USER_DATA_API = "/wyzs/api/v1/ipad/userdata"

    private const val IPAD_ROBOTS_API = "/wyzs/api/v1/ipad/robot/info"
    private const val IPAD_ROBOTS_DELETE_API = "/wyzs/api/v1/ipad/robot/delete"
    private const val IPAD_ROBOT_CREATE_API = "/wyzs/api/v1/ipad/robot/create"
    private const val IPAD_ROBOT_START_API = "/wyzs/api/v1/ipad/robot/start"
    private const val IPAD_ROBOT_STOP_API = "/wyzs/api/v1/ipad/robot/stop"
    private const val IPAD_ROBOTS_STATUS_API = "/wyzs/api/v1/ipad/robot/status"
    private const val IPAD_ROBOT_PROFILE_API = "/wyzs/api/v1/ipad/robotcfg/get"
    private const val IPAD_ROBOT_PROFILE_SAVE_API = "/wyzs/api/v1/ipad/robotcfg/update"

    private const val IPAD_GROUPS_API = "/wyzs/api/v1/ipad/groups"
    private const val IPAD_GROUPS_ADD_API = "/wyzs/api/v1/ipad/group/management"
    private const val IPAD_GROUPS_DELETE_API = "/wyzs/api/v1/ipad/group/delete"

    private const val IPAD_ROBOT_PRIVATE_1_API = "/wyzs/api/v1/ipad/robot/verify_friend/get"
    private const val IPAD_ROBOT_PRIVATE_1_MODIFY_API = "/wyzs/api/v1/ipad/robot/verify_friend/set"

    private const val IPAD_ROBOT_PRIVATE_4_API = "/wyzs/api/v1/ipad/robot/add_member/list"
    private const val IPAD_ROBOT_PRIVATE_4_SAVE_API = "/wyzs/api/v1/ipad/robot/add_member/save"
    private const val IPAD_ROBOT_PRIVATE_4_MODIFY_API = "/wyzs/api/v1/ipad/robot/add_member/update"
    private const val IPAD_ROBOT_PRIVATE_4_DELETE_API = "/wyzs/api/v1/ipad/robot/add_member/remove"

    private const val IPAD_ROBOT_PRIVATE_2_API = "/wyzs/api/v1/ipad/robot/auto_reply/list"
    private const val IPAD_ROBOT_PRIVATE_2_SAVE_API = "/wyzs/api/v1/ipad/robot/auto_reply/save"
    private const val IPAD_ROBOT_PRIVATE_2_MODIFY_API = "/wyzs/api/v1/ipad/robot/auto_reply/update"
    private const val IPAD_ROBOT_PRIVATE_2_DELETE_API = "/wyzs/api/v1/ipad/robot/auto_reply/remove"
    private const val IPAD_ROBOT_PRIVATE_2_TIME_API = "/wyzs/api/v1/ipad/robot/auto_reply/time/get"
    private const val IPAD_ROBOT_PRIVATE_2_TIME_SET_API = "/wyzs/api/v1/ipad/robot/auto_reply/time/set"
    private const val IPAD_ROBOT_PRIVATE_2_FRIEND_STATUS_API = "/wyzs/api/v1/ipad/robot/auto_reply/new_friend_status/get"
    private const val IPAD_ROBOT_PRIVATE_2_FRIEND_STATUS_SET_API = "/wyzs/api/v1/ipad/robot/auto_reply/new_friend_status/set"
    private const val IPAD_ROBOT_PRIVATE_2_FRIEND_API = "/wyzs/api/v1/ipad/robot/friend/list"
    private const val IPAD_ROBOT_PRIVATE_2_FRIEND_SAVE_API = "/wyzs/api/v1/ipad/robot/friend/auto_reply/save"

    private const val IPAD_ROBOT_PRIVATE_0_CONFIG_GET_API = "/wyzs/api/v1/ipad/robot/add_group_members/get"
    private const val IPAD_ROBOT_PRIVATE_0_SWITCH_GROUP_API = "/wyzs/api/v1/ipad/robot/add_group_members/switch"
    private const val IPAD_ROBOT_PRIVATE_0_ADD_GROUPS_API = "/wyzs/api/v1/ipad/robot/add_group_members/add_group"
    private const val IPAD_ROBOT_PRIVATE_0_DELETE_GROUP_API = "/wyzs/api/v1/ipad/robot/add_group_members/delete_group"
    private const val IPAD_ROBOT_PRIVATE_0_GROUPS_API = "/wyzs/api/v1/ipad/robot/add_group_members/groups"
    private const val IPAD_ROBOT_PRIVATE_0_UPDATE_VERIFY_TEXT_API = "/wyzs/api/v1/ipad/robot/add_group_members/update_verify_text"

    private const val IPAD_GROUP_GROUPING_API = "/wyzs/api/v1/ipad/group/grouping/list"
    private const val IPAD_GROUP_GROUPING_SAVE_API = "/wyzs/api/v1/ipad/group/grouping/add"
    private const val IPAD_GROUP_GROUPING_MODIFY_API = "/wyzs/api/v1/ipad/group/grouping/update"
    private const val IPAD_GROUP_GROUPING_DELETE_API = "/wyzs/api/v1/ipad/group/grouping/remove"

    private const val IPAD_MATERIAL_API = "/wyzs/api/v1/ipad/material/list"
    private const val IPAD_MATERIAL_ADD_TEXT_API = "/wyzs/api/v1/ipad/material/add"
    private const val IPAD_MATERIAL_MODIFY_TEXT_API = "/wyzs/api/v1/ipad/material/update"
    private const val IPAD_MATERIAL_ADD_PIC_API = "/wyzs/api/v1/ipad/material/add_pic"
    private const val IPAD_MATERIAL_DELETE_API = "/wyzs/api/v1/ipad/material/remove"
    private const val IPAD_MATERIAL_ADD_APP_MSG = "/wyzs/api/v1/ipad/material/add_appmsg"
    private const val IPAD_MATERIAL_ADD_ATTACH = "/wyzs/api/v1/ipad/material/add_attach"
    private const val IPAD_MATERIAL_RENAME_PIC = "/wyzs/api/v1/ipad/material/rename_pic"
    private const val IPAD_MATERIAL_ADD_VOICE = "/wyzs/api/v1/ipad/material/add_voice"
    private const val IPAD_MATERIAL_RENAME_VOICE = "/wyzs/api/v1/ipad/material/rename_voice"
    private const val IPAD_MATERIAL_ADD_VIDEO = "/wyzs/api/v1/ipad/material/add_video"
    private const val IPAD_MATERIAL_RENAME_VIDEO = "/wyzs/api/v1/ipad/material/rename_video"

    private const val IPAD_MASS_MESSAGE_API = "/wyzs/api/v2/ipad/massmessage/list"
    private const val IPAD_MASS_MESSAGE_DETAIL_API = "/wyzs/api/v1/ipad/massmessage/detail"
    private const val IPAD_MASS_MESSAGE_GROUP_API = "/wyzs/api/v1/ipad/groups/get"
    private const val IPAD_MASS_MESSAGE_SAVE_API = "/wyzs/api/v1/ipad/massmessage/save"
    private const val IPAD_MASS_MESSAGE_MODIFY_API = "/wyzs/api/v1/ipad/massmessage/update"
    private const val IPAD_MASS_MESSAGE_RESEND_API = "/wyzs/api/v2/ipad/massmessage/send"
    private const val IPAD_MASS_MESSAGE_DELETE_API = "/wyzs/api/v2/ipad/massmessage/delete"
    private const val IPAD_MASS_MESSAGE_LIST_API = "/wyzs/api/v1/ipad/massmessage/settings"
    private const val IPAD_MASS_MESSAGE_STATUS_SET_API = "/wyzs/api/v1/ipad/massmessage/status/set"

    private const val IPAD_VERIFY_CODE_API = "/wyzs/api/v1/ipad/subscription"

    private const val IPAD_STATISTICS_ALL_API = "/wyzs/api/v1/ipad/group/statistics/all"
    private const val IPAD_STATISTICS_HISTORY_API = "/wyzs/api/v2/ipad/group/statistics/history"

    private const val IPAD_MEMBER_INACTIVE_API = "/wyzs/api/v1/ipad/group/statistics/inactivemember"
    private const val IPAD_MEMBER_INVITER_API = "/wyzs/api/v1/ipad/inviter"
    private const val IPAD_MEMBER_ALL_API = "/wyzs/api/v1/ipad/group/member"
    private const val IPAD_MEMBER_DELETE_API = "/wyzs/api/v1/ipad/group/deletemember"
    private const val IPAD_MEMBER_LEVEL_API = "/wyzs/api/v1/ipad/group/member/level"

    private const val IPAD_AUTO_REPLY_API = "/wyzs/api/v1/ipad/auto_reply/list"
    private const val IPAD_AUTO_REPLY_SAVE_API = "/wyzs/api/v1/ipad/auto_reply/save"
    private const val IPAD_AUTO_REPLY_MODIFY_API = "/wyzs/api/v1/ipad/auto_reply/update"
    private const val IPAD_AUTO_REPLY_DELETE_API = "/wyzs/api/v1/ipad/auto_reply/remove"

    private const val IPAD_TIMED_NOTICE_API = "/wyzs/api/v1/ipad/timednotice/list"
    private const val IPAD_TIMED_NOTICE_SAVE_API = "/wyzs/api/v1/ipad/timednotice/save"
    private const val IPAD_TIMED_NOTICE_MODIFY_API = "/wyzs/api/v1/ipad/timednotice/update"
    private const val IPAD_TIMED_NOTICE_DELETE_API = "/wyzs/api/v1/ipad/timednotice/remove"

    private const val IPAD_CHECK_IN_API = "/wyzs/api/v1/ipad/checkin/list"
    private const val IPAD_CHECK_IN_DETAIL_API = "/wyzs/api/v1/ipad/checkin/detail"
    private const val IPAD_CHECK_IN_SAVE_API = "/wyzs/api/v1/ipad/checkin/save"
    private const val IPAD_CHECK_IN_MODIFY_API = "/wyzs/api/v1/ipad/checkin/update"
    private const val IPAD_CHECK_IN_DELETE_API = "/wyzs/api/v1/ipad/checkin/remove"

    private const val IPAD_GROUP_TOPIC_API = "/wyzs/api/v1/ipad/gtalk/list"
    private const val IPAD_GROUP_TOPIC_DETAIL_API = "/wyzs/api/v1/ipad/gtalk/detail"
    private const val IPAD_GROUP_TOPIC_MESSAGES_API = "/wyzs/api/v1/ipad/message/list"
    private const val IPAD_GROUP_TOPIC_SAVE_API = "/wyzs/api/v1/ipad/gtalk/save"
    private const val IPAD_GROUP_TOPIC_REMOVE_API = "/wyzs/api/v1/ipad/gtalk/remove"
    private const val IPAD_GROUP_TOPIC_SETTINGS_API = "/wyzs/api/v1/ipad/gtalk/settings/get"
    private const val IPAD_GROUP_TOPIC_SETTINGS_SAVE_API = "/wyzs/api/v1/ipad/gtalk/settings/set"

    private const val IPAD_GROUP_FILE_API = "/wyzs/api/v1/ipad/groupfile/list"
    private const val IPAD_GROUP_FILE_SWITCH_API = "/wyzs/api/v1/ipad/groupfile/on_off"
    private const val IPAD_GROUP_FILE_DELETE_API = "/wyzs/api/v1/ipad/groupfile/remove"

    private const val IPAD_COMPLAINT_SUSPECT_API = "/wyzs/api/v1/ipad/complaint/suspect"
    private const val IPAD_COMPLAINT_EXIT_API = "/wyzs/api/v1/ipad/complaint/exitlist"
    private const val IPAD_COMPLAINT_LATEST_API = "/wyzs/api/v1/ipad/complaint/latest"
    private const val IPAD_COMPLAINT_EXIT_COMPLAINT_API = "/wyzs/api/v1/ipad/complaint/exit_complaint"
    private const val IPAD_COMPLAINT_EXIT_REPEAL_API = "/wyzs/api/v1/ipad/complaint/exit_repeal"
    private const val IPAD_COMPLAINT_LATEST_COMPLAINT_API = "/wyzs/api/v1/ipad/complaint/re_repeal"
    private const val IPAD_COMPLAINT_LATEST_REPEAL_API = "/wyzs/api/v1/ipad/complaint/repeal"
    private const val IPAD_COMPLAINT_ON_OFF_API = "/wyzs/api/v1/ipad/complaint/on_off"

    private const val IPAD_KICK_OUT_SETTINGS_API = "/wyzs/api/v1/ipad/group/kickout/setting"
    private const val IPAD_KICK_OUT_SETTINGS_SAVE_API = "/wyzs/api/v1/ipad/group/kickout/setting/save"
    private const val IPAD_KICK_OUT_MEMBERS_API = "/wyzs/api/v1/ipad/group/kickoutmember"
    private const val IPAD_KICK_OUT_BLACKLIST_LIST_API = "wyzs/api/v1/ipad/group/blacklist"
    private const val IPAD_KICK_OUT_BLACKLIST_DELETE_API = "wyzs/api/v1/ipad/group/blacklist/delete_one"
    private const val IPAD_KICK_OUT_BLACKLIST_ADD_API = "wyzs/api/v1/ipad/group/blacklist/add"

    private const val IPAD_DIAGNOSTIC_SEND_GET_API = "/wyzs/api/v1/ipad/group/setting/morning/status/get"
    private const val IPAD_DIAGNOSTIC_SEND_SET_API = "/wyzs/api/v1/ipad/group/setting/morning/status/set"
    private const val IPAD_SMART_CHAT_GET_API = "/wyzs/api/v1/ipad/group/setting/smartchat/get"
    private const val IPAD_SMART_CHAT_SET_API = "/wyzs/api/v1/ipad/group/setting/smartchat/set"

    private const val IPAD_REPLY_SYNC_API = "/wyzs/api/v1/ipad/mgroup_sync/save"
    private const val IPAD_MULTI_GROUP_SYNC_API = "/wyzs/api/v1/ipad/mgroup_sync/sync"
    private const val IPAD_MULTI_GROUP_SYNC_GROUPS_API = "/wyzs/api/v1/ipad/mgroup_sync/groups"

    private const val IPAD_OPEN_VIP_API = "/wyzs/api/v1/ipad/group/permission/set"

    private const val IPAD_ACCOUNT_PAUSE_API = "/wyzs/api/v1/ipad/user/account/close"
    private const val IPAD_ACCOUNT_RESUME_API = "/wyzs/api/v1/ipad/user/account/start"

    private const val IPAD_MIGRATION_IPAD_GROUP_API = "/wyzs/api/v1/ipad/group/migration"

    private const val IPAD_REPLY_NUM_CONFIG_API = "/wyzs/api/v1/ipad/reply_num/config"

    private const val IPAD_ALIVE_CONFIG_API = "/wyzs/api/v1/ipad/alive/config"

    private const val IPAD_CARD_LIST_API = "/wyzs/api/v1/ipad/card/list"
    private const val IPAD_CARD_RESENT_USED_API = "/wyzs/api/v1/ipad/card/recent_used"
    private const val IPAD_CARD_RESENT_USED_REMOVE_API = "/wyzs/api/v1/ipad/card/recent_used/remove"

    private const val IPAD_PRIVATE_MASS_STA_LIST = "/wyzs/api/v2/ipad/private/massmsgsta/list"
    private const val IPAD_PRIVATE_MASS_MSG_SAVE = "/wyzs/api/v1/ipad/private/massmessage/save"
    private const val IPAD_PRIVATE_MASS_MSG_UPDATE = "/wyzs/api/v1/ipad/private/massmessage/update"
    private const val IPAD_PRIVATE_MASS_MSG_SETTINGS = "/wyzs/api/v1/ipad/private/massmessage/settings"
    private const val IPAD_PRIVATE_MASS_MSG_DETAIL = "/wyzs/api/v1/ipad/private/massmessage/detail"
    private const val IPAD_PRIVATE_MASS_MSG_STATUS_SET = "/wyzs/api/v1/ipad/private/massmessage/status/set"
    private const val IPAD_PRIVATE_MASS_MSG_DELETE = "/wyzs/api/v2/ipad/private/massmessage/delete"
    private const val IPAD_PRIVATE_MASS_MSG_SEND = "/wyzs/api/v1/ipad/private/massmessage/send"
    private const val IPAD_PRIVATE_MASS_FRIENDS_GET = "/wyzs/api/v1/ipad/mass/friends/get"

    private const val IPAD_PERSON_FUNC_CONFIG = "/wyzs/api/v1/ipad/person_fun/config"

    interface ApiIpadService {
        @GET(IPAD_MEMBER_INACTIVE_API)
        fun requestMemberInactive(@QueryMap params: MutableMap<String, Any>): Observable<MemberInactive>

        @GET(IPAD_MEMBER_INVITER_API)
        fun requestMemberInviter(@QueryMap params: MutableMap<String, Any>): Observable<MemberInviter>

        @GET(IPAD_MEMBER_ALL_API)
        fun requestMemberAll(@QueryMap params: MutableMap<String, Any>): Observable<MemberAll>

        @POST(IPAD_MEMBER_DELETE_API)
        fun deleteMembers(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @POST(IPAD_MEMBER_LEVEL_API)
        fun modifyMemberLevel(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<ModifyLevel>

        @GET(IPAD_STATISTICS_ALL_API)
        fun requestStatisticsAll(@QueryMap params: MutableMap<String, Any>): Observable<StatisticsAll>

        @GET(IPAD_STATISTICS_HISTORY_API)
        fun requestStatisticsHistory(@QueryMap params: MutableMap<String, Any>): Observable<StatisticsHistory>

        @GET(IPAD_DIAGNOSTIC_SEND_GET_API)
        fun requestDiagnosticSend(@QueryMap params: MutableMap<String, Any>): Observable<DiagnosticSend>

        @POST(IPAD_DIAGNOSTIC_SEND_SET_API)
        fun setDiagnosticSend(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @GET(IPAD_COMPLAINT_SUSPECT_API)
        fun requestComplaintSuspect(@QueryMap params: MutableMap<String, Any>): Observable<ComplaintSuspect>

        @GET(IPAD_COMPLAINT_EXIT_API)
        fun requestComplaintExit(@QueryMap params: MutableMap<String, Any>): Observable<ComplaintExit>

        @GET(IPAD_COMPLAINT_LATEST_API)
        fun requestComplaintLatest(@QueryMap params: MutableMap<String, Any>): Observable<ComplaintLatest>

        @POST(IPAD_COMPLAINT_EXIT_COMPLAINT_API)
        fun exitComplaint(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @POST(IPAD_COMPLAINT_EXIT_REPEAL_API)
        fun exitRepeal(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @POST(IPAD_COMPLAINT_LATEST_COMPLAINT_API)
        fun latestComplaint(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @POST(IPAD_COMPLAINT_LATEST_REPEAL_API)
        fun latestRepeal(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @POST(IPAD_COMPLAINT_ON_OFF_API)
        fun switchComplaint(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @GET(IPAD_MASS_MESSAGE_API)
        fun requestMassMessage(@QueryMap params: MutableMap<String, Any>): Observable<MassMessageRecordTypeGroup>

        @GET(IPAD_MASS_MESSAGE_DETAIL_API)
        fun requestMassMessageDetail(@QueryMap params: MutableMap<String, Any>): Observable<MassMessageDetailTypeGroup>

        @GET(IPAD_MASS_MESSAGE_GROUP_API)
        fun requestMassMessageGroup(@QueryMap params: MutableMap<String, Any>): Observable<MassMessageGroup>

        @POST(IPAD_MASS_MESSAGE_SAVE_API)
        fun saveMassMessage(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @POST(IPAD_MASS_MESSAGE_MODIFY_API)
        fun modifyMassMessage(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @POST(IPAD_MASS_MESSAGE_RESEND_API)
        fun resendMassMessage(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @POST(IPAD_MASS_MESSAGE_DELETE_API)
        fun deleteMassMessage(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @GET(IPAD_MASS_MESSAGE_LIST_API)
        fun listMassMessage(@QueryMap params: MutableMap<String, Any>): Observable<MassMessageList>

        @POST(IPAD_MASS_MESSAGE_STATUS_SET_API)
        fun switchStatusMassMessage(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @GET(IPAD_PRIVATE_MASS_MSG_SETTINGS)
        fun listPrivateMassMessage(@QueryMap params: MutableMap<String, Any>): Observable<MassMessageList>

        @GET(IPAD_PRIVATE_MASS_FRIENDS_GET)
        fun getFriendsMassMessage(@QueryMap params: MutableMap<String, Any>): Observable<MassMessageFriend>

        @POST(IPAD_PRIVATE_MASS_MSG_DELETE)
        fun deletePrivateMassMessage(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @POST(IPAD_PRIVATE_MASS_MSG_STATUS_SET)
        fun switchStatusPrivateMassMessage(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @GET(IPAD_PRIVATE_MASS_MSG_DETAIL)
        fun requestPrivateMassMessageDetail(@QueryMap params: MutableMap<String, Any>): Observable<MassMessageDetailTypePrivate>

        @POST(IPAD_PRIVATE_MASS_MSG_SAVE)
        fun savePrivateMassMessage(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @POST(IPAD_PRIVATE_MASS_MSG_UPDATE)
        fun modifyPrivateMassMessage(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @GET(IPAD_PRIVATE_MASS_STA_LIST)
        fun requestPrivateMassMessageRecord(@QueryMap params: MutableMap<String, Any>): Observable<MassMessageRecordTypePrivate>

        @POST(IPAD_PRIVATE_MASS_MSG_SEND)
        fun resendPrivateMassMessage(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @POST(IPAD_MATERIAL_RENAME_VIDEO)
        fun renameMaterialVideo(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @POST(IPAD_MATERIAL_ADD_VIDEO)
        fun addMaterialVideo(@QueryMap params: MutableMap<String, Any>, @Body body: RequestBody): Observable<StatusResult>

        @GET(IPAD_PERSON_FUNC_CONFIG)
        fun requestPersonFuncConfig(@QueryMap params: MutableMap<String, Any>): Observable<PersonFuncConfig>
    }

    fun requestMemberInactive(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        params.putAll(commonParams)
        params[com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestMemberInactive(params), listener)
    }

    fun requestMemberInviter(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        params.putAll(commonParams)
        params[com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestMemberInviter(params), listener)
    }

    fun requestMemberAll(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        params.putAll(commonParams)
        params[com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestMemberAll(params), listener)
    }

    @Throws(JSONException::class)
    fun deleteMembers(gid: String, usernames: List<String>, entry: String, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.GID, gid)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.USERNAMES, JSONArray(Gson().toJson(usernames)))
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ENTRY, entry)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.deleteMembers(commonParams, body), listener)
    }

    @Throws(JSONException::class)
    fun modifyMemberLevel(gid: String, username: String, level: Int, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.GID, gid)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.USERNAME, username)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.LEVEL, level)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.modifyMemberLevel(commonParams, body), listener)
    }

    fun requestStatisticsAll(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        params.putAll(commonParams)
        params[ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestStatisticsAll(params), listener)
    }

    fun requestStatisticsHistory(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        params.putAll(commonParams)
        params[ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestStatisticsHistory(params), listener)
    }

    fun requestDiagnosticSend(gid: String, listener: OnDataLoadListener) {
        val params = commonParams
        params[ApiParamKeys.GID] = gid
        params[ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestDiagnosticSend(params), listener)
    }

    @Throws(JSONException::class)
    fun setDiagnosticSend(gid: String, status: Int, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(ApiParamKeys.GID, gid)
        jsonObject.put(ApiParamKeys.STATUS, status)
        jsonObject.put(ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.setDiagnosticSend(commonParams, body), listener)
    }

    fun requestComplaintSuspect(gid: String, listener: OnDataLoadListener) {
        val params = commonParams
        params[ApiParamKeys.GID] = gid
        params[ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestComplaintSuspect(params), listener)
    }

    fun requestComplaintExit(gid: String, day: Int, listener: OnDataLoadListener) {
        val params = commonParams
        params[ApiParamKeys.GID] = gid
        params[ApiParamKeys.DAY] = day
        params[ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestComplaintExit(params), listener)
    }

    fun requestComplaintLatest(gid: String, listener: OnDataLoadListener) {
        val params = commonParams
        params[ApiParamKeys.GID] = gid
        params[ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestComplaintLatest(params), listener)
    }

    @Throws(JSONException::class)
    fun exitComplaint(gid: String, exit: Exit, listener: OnDataLoadListener) {
        val jsonObject = JSONObject(Gson().toJson(exit))
        jsonObject.put(ApiParamKeys.GID, gid)
        jsonObject.put(ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.exitComplaint(commonParams, body), listener)
    }

    @Throws(JSONException::class)
    fun exitRepeal(gid: String, exit: Exit, listener: OnDataLoadListener) {
        val jsonObject = JSONObject(Gson().toJson(exit))
        jsonObject.put(ApiParamKeys.GID, gid)
        jsonObject.put(ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.exitRepeal(commonParams, body), listener)
    }

    @Throws(JSONException::class)
    fun latestComplaint(gid: String, latest: Latest, listener: OnDataLoadListener) {
        val jsonObject = JSONObject(Gson().toJson(latest))
        jsonObject.put(ApiParamKeys.GID, gid)
        jsonObject.put(ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.latestComplaint(commonParams, body), listener)
    }

    @Throws(JSONException::class)
    fun latestRepeal(gid: String, latest: Latest, listener: OnDataLoadListener) {
        val jsonObject = JSONObject(Gson().toJson(latest))
        jsonObject.put(ApiParamKeys.GID, gid)
        jsonObject.put(ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.latestRepeal(commonParams, body), listener)
    }

    @Throws(JSONException::class)
    fun switchComplaint(gid: String, status: Int, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(ApiParamKeys.GID, gid)
        jsonObject.put(ApiParamKeys.STATUS, status)
        jsonObject.put(ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.switchComplaint(commonParams, body), listener)
    }

    fun requestMassMessage(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        params.putAll(commonParams)
        params[com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestMassMessage(params), listener)
    }

    fun requestMassMessageDetail(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        params.putAll(commonParams)
        params[com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestMassMessageDetail(params), listener)
    }

    fun requestMassMessageGroup(listener: OnDataLoadListener) {
        val params = commonParams
        params[com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestMassMessageGroup(params), listener)
    }

    @Throws(JSONException::class)
    fun saveMassMessage(massMessageDetailData: MassMessageDetailDataTypeGroup, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.DATA, JSONObject(Gson().toJson(massMessageDetailData)))
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.saveMassMessage(commonParams, body), listener)
    }

    @Throws(JSONException::class)
    fun modifyMassMessage(massMessageDetailData: MassMessageDetailDataTypeGroup, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.DATA, JSONObject(Gson().toJson(massMessageDetailData)))
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.modifyMassMessage(commonParams, body), listener)
    }

    @Throws(JSONException::class)
    fun resendMassMessage(mmid: String, timestamp: Long, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.MMID, mmid)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.TIME, timestamp)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.resendMassMessage(commonParams, body), listener)
    }

    @Throws(JSONException::class)
    fun deleteMassMessage(mmid: String, timestamp: Long, type: Int, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.MMID, mmid)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.TIME, timestamp)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.TYPE, type)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.deleteMassMessage(commonParams, body), listener)
    }

    fun listMassMessage(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        params.putAll(commonParams)
        params[com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.listMassMessage(params), listener)
    }

    @Throws(JSONException::class)
    fun switchStatusMassMessage(mmid: String, status: Int, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.MMID, mmid)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.STATUS, status)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.switchStatusMassMessage(commonParams, body), listener)
    }

    fun listPrivateMassMessage(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        params.putAll(commonParams)
        params[com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.listPrivateMassMessage(params), listener)
    }

    fun getFriendsMassMessage(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        params.putAll(commonParams)
        params[com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.getFriendsMassMessage(params), listener)
    }

    @Throws(JSONException::class)
    fun deletePrivateMassMessage(mmid: String, timestamp: Long, type: Int, rid: String, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.MMID, mmid)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.TIME, timestamp)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.TYPE, type)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.RID, rid)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.deletePrivateMassMessage(commonParams, body), listener)
    }

    @Throws(JSONException::class)
    fun switchStatusPrivateMassMessage(mmid: String, status: Int, rid: String, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.MMID, mmid)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.STATUS, status)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.RID, rid)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.switchStatusPrivateMassMessage(commonParams, body), listener)
    }

    fun requestPrivateMassMessageDetail(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        params.putAll(commonParams)
        params[com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestPrivateMassMessageDetail(params), listener)
    }

    @Throws(JSONException::class)
    fun savePrivateMassMessage(massMessageDetailData: MassMessageDetailDataTypePrivate, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.DATA, JSONObject(Gson().toJson(massMessageDetailData)))
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.savePrivateMassMessage(commonParams, body), listener)
    }

    @Throws(JSONException::class)
    fun modifyPrivateMassMessage(massMessageDetailData: MassMessageDetailDataTypePrivate, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.DATA, JSONObject(Gson().toJson(massMessageDetailData)))
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.modifyPrivateMassMessage(commonParams, body), listener)
    }

    fun requestPrivateMassMessageRecord(params: MutableMap<String, Any>, listener: OnDataLoadListener) {
        params.putAll(commonParams)
        params[com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestPrivateMassMessageRecord(params), listener)
    }

    @Throws(JSONException::class)
    fun resendPrivateMassMessage(mmid: String, timestamp: Long, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.MMID, mmid)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.TIME, timestamp)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.resendPrivateMassMessage(commonParams, body), listener)
    }

    @Throws(JSONException::class)
    fun renameMaterialVideo(materialNameList: MutableList<MaterialName>, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.DATA, JSONArray(Gson().toJson(materialNameList)))
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.renameMaterialVideo(commonParams, body), listener)
    }

    @Throws(JSONException::class)
    fun addMaterialVideo(mid: String, listener: OnDataLoadListener) {
        val jsonObject = JSONObject()
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.MID, mid)
        jsonObject.put(com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN, PreferenceUtils.getAccessToken())
        val body = RequestBody.create(MediaType.parse("application/json;charset=utf-8"), jsonObject.toString())
        subscribe(sIPadService.addMaterialVideo(commonParams, body), listener)
    }

    fun requestPersonFuncConfig(listener: OnDataLoadListener) {
        val params = mutableMapOf<String, Any>()
        params[com.weiyoubot.client.model.api.ApiParamKeys.ACCESS_TOKEN] = PreferenceUtils.getAccessToken()
        subscribe(sIPadService.requestPersonFuncConfig(params), listener)
    }
}