package com.weiyoubot.client.model.apikt

import android.os.Build
import com.weiyoubot.client.R
import com.weiyoubot.client.common.utils.*
import com.weiyoubot.client.feature.login.LoginConstant
import com.weiyoubot.client.feature.login.LoginHelper
import com.weiyoubot.client.feature.main.UserDataHelper
import com.weiyoubot.client.model.api.BaseApiClient
import com.weiyoubot.client.model.bean.PaymentStatusResult
import com.weiyoubot.client.model.bean.StatusResult
import com.weiyoubot.client.model.bean.login.LoginResult
import com.weiyoubot.client.model.loader.OnDataLoadListener
import io.reactivex.Observable
import io.reactivex.Observer
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.disposables.Disposable
import io.reactivex.schedulers.Schedulers
import okhttp3.OkHttpClient
import retrofit2.Retrofit
import retrofit2.adapter.rxjava2.RxJava2CallAdapterFactory
import retrofit2.converter.gson.GsonConverterFactory
import java.util.*

open class BaseApiClient {
    internal val DEFAULT_API_HOST = BaseApiClient.DEFAULT_API_HOST
    internal val defaultIPadApiHost = BaseApiClient.DEFAULT_IPAD_API_HOST
    internal val PAY_API_HOST = BaseApiClient.PAY_API_HOST
    internal val CUSTOMER_API_HOST = BaseApiClient.CUSTOMER_API_HOST

    internal val commonParams: MutableMap<String, Any>
        get() {
            val params = HashMap<String, Any>()
            params[ApiParamKeys.ACCOUNT] = UserDataHelper.getUserNickName()
            params[ApiParamKeys.DEVICE_MODEL] = Build.MODEL
            params[ApiParamKeys.CHANNEL] = PackageUtils.getChannel()
            params[ApiParamKeys.OS_VERSION] = Build.VERSION.RELEASE
            params[ApiParamKeys.RESOLUTION] = UIUtils.screenWidth().toString() + "*" + UIUtils.screenHeight()
            params[ApiParamKeys.PLATFORM] = "android"
            params[ApiParamKeys.PN] = PackageUtils.getPackageName()
            params[ApiParamKeys.VN] = PackageUtils.getVersionName()
            params[ApiParamKeys.VC] = PackageUtils.getVersionCode()
            params[ApiParamKeys.NETWORK] = NetworkUtils.getNetworkType()
            return params
        }

    internal fun createRetrofit(apiHost: String): Retrofit {
        return Retrofit.Builder()
                .baseUrl(apiHost)
                .client(OkHttpClient.Builder().addInterceptor(SaveCookiesInterceptor()).build())
                .addConverterFactory(GsonConverterFactory.create())
                .addCallAdapterFactory(RxJava2CallAdapterFactory.create())
                .build()
    }

    internal fun subscribe(observable: Observable<*>, listener: OnDataLoadListener) {
        observable.subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe(ApiObserver(listener))
    }

    private class ApiObserver internal constructor(private val mListener: OnDataLoadListener) : Observer<Any> {

        override fun onError(e: Throwable) {
            e.printStackTrace()
            mListener.onDataLoadFailed(false, -1, e.message ?: "")
        }

        override fun onComplete() {

        }

        override fun onSubscribe(d: Disposable) {

        }

        override fun onNext(o: Any) {
            var resultStatus = -1
            var resultErrCode = -1
            var resultMsg: String? = ""
            if (o is StatusResult) {
                resultStatus = o.sta
                resultErrCode = o.errcode
                resultMsg = o.msg
            } else if (o is PaymentStatusResult) {
                resultStatus = o.status
                resultMsg = o.msg
            }
            if (resultStatus == 0) {
                mListener.onDataLoaded(o)
            } else {
                if (resultErrCode == 4001) {
                    // 当token过期时尝试后台重新登录
                    val phoneNum = PreferenceUtils.getPhoneNum()
                    val cryptPassword = PreferenceUtils.getCryptPassword()
                    LoginHelper.loginWy(phoneNum, cryptPassword, object : OnDataLoadListener {
                        override fun onDataLoaded(data: Any) {
                            // 成功后更新loginResult
                            val loginResult = data as LoginResult
                            LoginHelper.saveLoginResult(loginResult)
                            mListener.onDataLoadFailed(true, 4001, "")
                        }

                        override fun onDataLoadFailed(isServerError: Boolean, errorCode: Int, errorMessage: String) {
                            // 否则退出回到登录界面重新登录
                            UIUtils.showToast(R.string.re_login)
                            PreferenceUtils.saveAccessToken("")
                            LaunchUtils.startLoginActivity(LoginConstant.TYPE_LOGIN)
                        }
                    })
                } else {
                    mListener.onDataLoadFailed(true, resultErrCode, resultMsg ?: "")
                }
            }
        }
    }
}
